/* Generated by Cython 0.26.1 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "cymysql.charset",
        "sources": [
            "cymysql/charset.py"
        ]
    },
    "module_name": "cymysql.charset"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_26_1"
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x03030000 || (PY_MAJOR_VERSION == 2 && PY_VERSION_HEX >= 0x02070000)
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX < 0x030700A0 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject **args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #ifdef __cplusplus
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough) || (defined(__GNUC__) && defined(__attribute__))
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__cymysql__charset
#define __PYX_HAVE_API__cymysql__charset
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER) && defined (_M_X64)
    #define __Pyx_sst_abs(value) _abs64(value)
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "cymysql/charset.py",
  "cymysql/charset.pxd",
  "stringsource",
};

/*--- Type declarations ---*/
struct __pyx_obj_7cymysql_7charset_Charset;
struct __pyx_obj_7cymysql_7charset_Charsets;

/* "cymysql/charset.pxd":3
 * import cython
 * 
 * cdef class Charset(object):             # <<<<<<<<<<<<<<
 *     cdef public int id
 *     cdef public str name, collation
 */
struct __pyx_obj_7cymysql_7charset_Charset {
  PyObject_HEAD
  int id;
  PyObject *name;
  PyObject *collation;
  int is_default;
};


/* "cymysql/charset.pxd":8
 *     cdef public bint is_default
 * 
 * cdef class Charsets(object):             # <<<<<<<<<<<<<<
 *     cdef dict _by_id
 *     cdef add(self, Charset c)
 */
struct __pyx_obj_7cymysql_7charset_Charsets {
  PyObject_HEAD
  struct __pyx_vtabstruct_7cymysql_7charset_Charsets *__pyx_vtab;
  PyObject *_by_id;
};



/* "cymysql/charset.py":7
 * 
 * 
 * class Charsets(object):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         self._by_id = {}
 */

struct __pyx_vtabstruct_7cymysql_7charset_Charsets {
  PyObject *(*add)(struct __pyx_obj_7cymysql_7charset_Charsets *, struct __pyx_obj_7cymysql_7charset_Charset *);
  PyObject *(*by_name)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*by_id)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7cymysql_7charset_Charsets *__pyx_vtabptr_7cymysql_7charset_Charsets;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* py_dict_values.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    ((likely((cfunc)->func)) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
             ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
              (PY_VERSION_HEX >= 0x030600B1 && (cfunc)->flag == METH_FASTCALL ?\
                (PY_VERSION_HEX >= 0x030700A0 ?\
                    (*(__Pyx_PyCFunctionFast)(cfunc)->func)(self, &PyTuple_GET_ITEM(__pyx_empty_tuple, 0), 0) :\
                    (*(__Pyx_PyCFunctionFastWithKeywords)(cfunc)->func)(self, &PyTuple_GET_ITEM(__pyx_empty_tuple, 0), 0, NULL)) :\
              (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
                    (*(__Pyx_PyCFunctionFastWithKeywords)(cfunc)->func)(self, &PyTuple_GET_ITEM(__pyx_empty_tuple, 0), 0, NULL) :\
                    __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = PyThreadState_GET();
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CLineInTraceback.proto */
static int __Pyx_CLineForTraceback(int c_line);

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_7cymysql_7charset_8Charsets_add(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c); /* proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'cymysql.charset' */
static PyTypeObject *__pyx_ptype_7cymysql_7charset_Charset = 0;
static PyTypeObject *__pyx_ptype_7cymysql_7charset_Charsets = 0;
static struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_7cymysql_7charset__charsets = 0;
static PyObject *__pyx_f_7cymysql_7charset___pyx_unpickle_Charset__set_state(struct __pyx_obj_7cymysql_7charset_Charset *, PyObject *); /*proto*/
static PyObject *__pyx_f_7cymysql_7charset___pyx_unpickle_Charsets__set_state(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "cymysql.charset"
int __pyx_module_is_main_cymysql__charset = 0;

/* Implementation of 'cymysql.charset' */
static const char __pyx_k_id[] = "id";
static const char __pyx_k_Yes[] = "Yes";
static const char __pyx_k__14[] = "";
static const char __pyx_k_gbk[] = "gbk";
static const char __pyx_k_hp8[] = "hp8";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_big5[] = "big5";
static const char __pyx_k_dec8[] = "dec8";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_sjis[] = "sjis";
static const char __pyx_k_swe7[] = "swe7";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_ucs2[] = "ucs2";
static const char __pyx_k_ujis[] = "ujis";
static const char __pyx_k_utf8[] = "utf8";
static const char __pyx_k_ascii[] = "ascii";
static const char __pyx_k_by_id[] = "by_id";
static const char __pyx_k_cp850[] = "cp850";
static const char __pyx_k_cp852[] = "cp852";
static const char __pyx_k_cp866[] = "cp866";
static const char __pyx_k_cp932[] = "cp932";
static const char __pyx_k_euckr[] = "euckr";
static const char __pyx_k_greek[] = "greek";
static const char __pyx_k_koi8r[] = "koi8r";
static const char __pyx_k_koi8u[] = "koi8u";
static const char __pyx_k_macce[] = "macce";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_utf16[] = "utf16";
static const char __pyx_k_utf32[] = "utf32";
static const char __pyx_k_binary[] = "binary";
static const char __pyx_k_cp1250[] = "cp1250";
static const char __pyx_k_cp1251[] = "cp1251";
static const char __pyx_k_cp1256[] = "cp1256";
static const char __pyx_k_cp1257[] = "cp1257";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_gb2312[] = "gb2312";
static const char __pyx_k_hebrew[] = "hebrew";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_latin1[] = "latin1";
static const char __pyx_k_latin2[] = "latin2";
static const char __pyx_k_latin5[] = "latin5";
static const char __pyx_k_latin7[] = "latin7";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_tis620[] = "tis620";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_by_name[] = "by_name";
static const char __pyx_k_eucjpms[] = "eucjpms";
static const char __pyx_k_gb18030[] = "gb18030";
static const char __pyx_k_gbk_bin[] = "gbk_bin";
static const char __pyx_k_geostd8[] = "geostd8";
static const char __pyx_k_hp8_bin[] = "hp8_bin";
static const char __pyx_k_keybcs2[] = "keybcs2";
static const char __pyx_k_utf16le[] = "utf16le";
static const char __pyx_k_utf8mb4[] = "utf8mb4";
static const char __pyx_k_armscii8[] = "armscii8";
static const char __pyx_k_big5_bin[] = "big5_bin";
static const char __pyx_k_charsets[] = "_charsets";
static const char __pyx_k_dec8_bin[] = "dec8_bin";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_macroman[] = "macroman";
static const char __pyx_k_pyx_capi[] = "__pyx_capi__";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_sjis_bin[] = "sjis_bin";
static const char __pyx_k_swe7_bin[] = "swe7_bin";
static const char __pyx_k_ucs2_bin[] = "ucs2_bin";
static const char __pyx_k_ujis_bin[] = "ujis_bin";
static const char __pyx_k_utf8_bin[] = "utf8_bin";
static const char __pyx_k_ascii_bin[] = "ascii_bin";
static const char __pyx_k_collation[] = "collation";
static const char __pyx_k_cp850_bin[] = "cp850_bin";
static const char __pyx_k_cp852_bin[] = "cp852_bin";
static const char __pyx_k_cp866_bin[] = "cp866_bin";
static const char __pyx_k_cp932_bin[] = "cp932_bin";
static const char __pyx_k_euckr_bin[] = "euckr_bin";
static const char __pyx_k_greek_bin[] = "greek_bin";
static const char __pyx_k_koi8r_bin[] = "koi8r_bin";
static const char __pyx_k_koi8u_bin[] = "koi8u_bin";
static const char __pyx_k_macce_bin[] = "macce_bin";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_utf16_bin[] = "utf16_bin";
static const char __pyx_k_utf32_bin[] = "utf32_bin";
static const char __pyx_k_cp1250_bin[] = "cp1250_bin";
static const char __pyx_k_cp1251_bin[] = "cp1251_bin";
static const char __pyx_k_cp1256_bin[] = "cp1256_bin";
static const char __pyx_k_cp1257_bin[] = "cp1257_bin";
static const char __pyx_k_gb2312_bin[] = "gb2312_bin";
static const char __pyx_k_hebrew_bin[] = "hebrew_bin";
static const char __pyx_k_is_default[] = "is_default";
static const char __pyx_k_latin1_bin[] = "latin1_bin";
static const char __pyx_k_latin2_bin[] = "latin2_bin";
static const char __pyx_k_latin5_bin[] = "latin5_bin";
static const char __pyx_k_latin7_bin[] = "latin7_bin";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_tis620_bin[] = "tis620_bin";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_eucjpms_bin[] = "eucjpms_bin";
static const char __pyx_k_gb18030_bin[] = "gb18030_bin";
static const char __pyx_k_geostd8_bin[] = "geostd8_bin";
static const char __pyx_k_keybcs2_bin[] = "keybcs2_bin";
static const char __pyx_k_utf16le_bin[] = "utf16le_bin";
static const char __pyx_k_utf8mb4_bin[] = "utf8mb4_bin";
static const char __pyx_k_armscii8_bin[] = "armscii8_bin";
static const char __pyx_k_macroman_bin[] = "macroman_bin";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_charset_by_id[] = "charset_by_id";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_ucs2_czech_ci[] = "ucs2_czech_ci";
static const char __pyx_k_ucs2_roman_ci[] = "ucs2_roman_ci";
static const char __pyx_k_utf8_czech_ci[] = "utf8_czech_ci";
static const char __pyx_k_utf8_roman_ci[] = "utf8_roman_ci";
static const char __pyx_k_Charsets_by_id[] = "Charsets.by_id";
static const char __pyx_k_gbk_chinese_ci[] = "gbk_chinese_ci";
static const char __pyx_k_hp8_english_ci[] = "hp8_english_ci";
static const char __pyx_k_tis620_thai_ci[] = "tis620_thai_ci";
static const char __pyx_k_ucs2_danish_ci[] = "ucs2_danish_ci";
static const char __pyx_k_ucs2_polish_ci[] = "ucs2_polish_ci";
static const char __pyx_k_ucs2_slovak_ci[] = "ucs2_slovak_ci";
static const char __pyx_k_utf16_czech_ci[] = "utf16_czech_ci";
static const char __pyx_k_utf16_roman_ci[] = "utf16_roman_ci";
static const char __pyx_k_utf32_czech_ci[] = "utf32_czech_ci";
static const char __pyx_k_utf32_roman_ci[] = "utf32_roman_ci";
static const char __pyx_k_utf8_danish_ci[] = "utf8_danish_ci";
static const char __pyx_k_utf8_polish_ci[] = "utf8_polish_ci";
static const char __pyx_k_utf8_slovak_ci[] = "utf8_slovak_ci";
static const char __pyx_k_big5_chinese_ci[] = "big5_chinese_ci";
static const char __pyx_k_charset_by_name[] = "charset_by_name";
static const char __pyx_k_cp1250_czech_cs[] = "cp1250_czech_cs";
static const char __pyx_k_cymysql_charset[] = "cymysql.charset";
static const char __pyx_k_dec8_swedish_ci[] = "dec8_swedish_ci";
static const char __pyx_k_euckr_korean_ci[] = "euckr_korean_ci";
static const char __pyx_k_latin2_czech_cs[] = "latin2_czech_cs";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_swe7_swedish_ci[] = "swe7_swedish_ci";
static const char __pyx_k_ucs2_general_ci[] = "ucs2_general_ci";
static const char __pyx_k_ucs2_german2_ci[] = "ucs2_german2_ci";
static const char __pyx_k_ucs2_latvian_ci[] = "ucs2_latvian_ci";
static const char __pyx_k_ucs2_persian_ci[] = "ucs2_persian_ci";
static const char __pyx_k_ucs2_sinhala_ci[] = "ucs2_sinhala_ci";
static const char __pyx_k_ucs2_spanish_ci[] = "ucs2_spanish_ci";
static const char __pyx_k_ucs2_swedish_ci[] = "ucs2_swedish_ci";
static const char __pyx_k_ucs2_turkish_ci[] = "ucs2_turkish_ci";
static const char __pyx_k_ucs2_unicode_ci[] = "ucs2_unicode_ci";
static const char __pyx_k_utf16_danish_ci[] = "utf16_danish_ci";
static const char __pyx_k_utf16_polish_ci[] = "utf16_polish_ci";
static const char __pyx_k_utf16_slovak_ci[] = "utf16_slovak_ci";
static const char __pyx_k_utf32_danish_ci[] = "utf32_danish_ci";
static const char __pyx_k_utf32_polish_ci[] = "utf32_polish_ci";
static const char __pyx_k_utf32_slovak_ci[] = "utf32_slovak_ci";
static const char __pyx_k_utf8_general_ci[] = "utf8_general_ci";
static const char __pyx_k_utf8_german2_ci[] = "utf8_german2_ci";
static const char __pyx_k_utf8_latvian_ci[] = "utf8_latvian_ci";
static const char __pyx_k_utf8_persian_ci[] = "utf8_persian_ci";
static const char __pyx_k_utf8_sinhala_ci[] = "utf8_sinhala_ci";
static const char __pyx_k_utf8_spanish_ci[] = "utf8_spanish_ci";
static const char __pyx_k_utf8_swedish_ci[] = "utf8_swedish_ci";
static const char __pyx_k_utf8_tolower_ci[] = "utf8_tolower_ci";
static const char __pyx_k_utf8_turkish_ci[] = "utf8_turkish_ci";
static const char __pyx_k_utf8_unicode_ci[] = "utf8_unicode_ci";
static const char __pyx_k_Charsets_by_name[] = "Charsets.by_name";
static const char __pyx_k_ascii_general_ci[] = "ascii_general_ci";
static const char __pyx_k_cp1250_polish_ci[] = "cp1250_polish_ci";
static const char __pyx_k_cp850_general_ci[] = "cp850_general_ci";
static const char __pyx_k_cp852_general_ci[] = "cp852_general_ci";
static const char __pyx_k_cp866_general_ci[] = "cp866_general_ci";
static const char __pyx_k_greek_general_ci[] = "greek_general_ci";
static const char __pyx_k_koi8r_general_ci[] = "koi8r_general_ci";
static const char __pyx_k_koi8u_general_ci[] = "koi8u_general_ci";
static const char __pyx_k_latin1_danish_ci[] = "latin1_danish_ci";
static const char __pyx_k_macce_general_ci[] = "macce_general_ci";
static const char __pyx_k_sjis_japanese_ci[] = "sjis_japanese_ci";
static const char __pyx_k_ucs2_croatian_ci[] = "ucs2_croatian_ci";
static const char __pyx_k_ucs2_estonian_ci[] = "ucs2_estonian_ci";
static const char __pyx_k_ucs2_romanian_ci[] = "ucs2_romanian_ci";
static const char __pyx_k_ucs2_spanish2_ci[] = "ucs2_spanish2_ci";
static const char __pyx_k_ujis_japanese_ci[] = "ujis_japanese_ci";
static const char __pyx_k_utf16_general_ci[] = "utf16_general_ci";
static const char __pyx_k_utf16_german2_ci[] = "utf16_german2_ci";
static const char __pyx_k_utf16_latvian_ci[] = "utf16_latvian_ci";
static const char __pyx_k_utf16_persian_ci[] = "utf16_persian_ci";
static const char __pyx_k_utf16_sinhala_ci[] = "utf16_sinhala_ci";
static const char __pyx_k_utf16_spanish_ci[] = "utf16_spanish_ci";
static const char __pyx_k_utf16_swedish_ci[] = "utf16_swedish_ci";
static const char __pyx_k_utf16_turkish_ci[] = "utf16_turkish_ci";
static const char __pyx_k_utf16_unicode_ci[] = "utf16_unicode_ci";
static const char __pyx_k_utf32_general_ci[] = "utf32_general_ci";
static const char __pyx_k_utf32_german2_ci[] = "utf32_german2_ci";
static const char __pyx_k_utf32_latvian_ci[] = "utf32_latvian_ci";
static const char __pyx_k_utf32_persian_ci[] = "utf32_persian_ci";
static const char __pyx_k_utf32_sinhala_ci[] = "utf32_sinhala_ci";
static const char __pyx_k_utf32_spanish_ci[] = "utf32_spanish_ci";
static const char __pyx_k_utf32_swedish_ci[] = "utf32_swedish_ci";
static const char __pyx_k_utf32_turkish_ci[] = "utf32_turkish_ci";
static const char __pyx_k_utf32_unicode_ci[] = "utf32_unicode_ci";
static const char __pyx_k_utf8_croatian_ci[] = "utf8_croatian_ci";
static const char __pyx_k_utf8_estonian_ci[] = "utf8_estonian_ci";
static const char __pyx_k_utf8_romanian_ci[] = "utf8_romanian_ci";
static const char __pyx_k_utf8_spanish2_ci[] = "utf8_spanish2_ci";
static const char __pyx_k_utf8mb4_czech_ci[] = "utf8mb4_czech_ci";
static const char __pyx_k_utf8mb4_roman_ci[] = "utf8mb4_roman_ci";
static const char __pyx_k_cp1250_general_ci[] = "cp1250_general_ci";
static const char __pyx_k_cp1251_general_ci[] = "cp1251_general_ci";
static const char __pyx_k_cp1251_general_cs[] = "cp1251_general_cs";
static const char __pyx_k_cp1256_general_ci[] = "cp1256_general_ci";
static const char __pyx_k_cp1257_general_ci[] = "cp1257_general_ci";
static const char __pyx_k_cp932_japanese_ci[] = "cp932_japanese_ci";
static const char __pyx_k_gb2312_chinese_ci[] = "gb2312_chinese_ci";
static const char __pyx_k_hebrew_general_ci[] = "hebrew_general_ci";
static const char __pyx_k_latin1_general_ci[] = "latin1_general_ci";
static const char __pyx_k_latin1_general_cs[] = "latin1_general_cs";
static const char __pyx_k_latin1_german1_ci[] = "latin1_german1_ci";
static const char __pyx_k_latin1_german2_ci[] = "latin1_german2_ci";
static const char __pyx_k_latin1_spanish_ci[] = "latin1_spanish_ci";
static const char __pyx_k_latin1_swedish_ci[] = "latin1_swedish_ci";
static const char __pyx_k_latin2_general_ci[] = "latin2_general_ci";
static const char __pyx_k_latin5_turkish_ci[] = "latin5_turkish_ci";
static const char __pyx_k_latin7_general_ci[] = "latin7_general_ci";
static const char __pyx_k_latin7_general_cs[] = "latin7_general_cs";
static const char __pyx_k_ucs2_esperanto_ci[] = "ucs2_esperanto_ci";
static const char __pyx_k_ucs2_hungarian_ci[] = "ucs2_hungarian_ci";
static const char __pyx_k_ucs2_icelandic_ci[] = "ucs2_icelandic_ci";
static const char __pyx_k_ucs2_slovenian_ci[] = "ucs2_slovenian_ci";
static const char __pyx_k_utf16_croatian_ci[] = "utf16_croatian_ci";
static const char __pyx_k_utf16_estonian_ci[] = "utf16_estonian_ci";
static const char __pyx_k_utf16_romanian_ci[] = "utf16_romanian_ci";
static const char __pyx_k_utf16_spanish2_ci[] = "utf16_spanish2_ci";
static const char __pyx_k_utf32_croatian_ci[] = "utf32_croatian_ci";
static const char __pyx_k_utf32_estonian_ci[] = "utf32_estonian_ci";
static const char __pyx_k_utf32_romanian_ci[] = "utf32_romanian_ci";
static const char __pyx_k_utf32_spanish2_ci[] = "utf32_spanish2_ci";
static const char __pyx_k_utf8_esperanto_ci[] = "utf8_esperanto_ci";
static const char __pyx_k_utf8_hungarian_ci[] = "utf8_hungarian_ci";
static const char __pyx_k_utf8_icelandic_ci[] = "utf8_icelandic_ci";
static const char __pyx_k_utf8_slovenian_ci[] = "utf8_slovenian_ci";
static const char __pyx_k_utf8mb4_danish_ci[] = "utf8mb4_danish_ci";
static const char __pyx_k_utf8mb4_polish_ci[] = "utf8mb4_polish_ci";
static const char __pyx_k_utf8mb4_slovak_ci[] = "utf8mb4_slovak_ci";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_cp1250_croatian_ci[] = "cp1250_croatian_ci";
static const char __pyx_k_cymysql_charset_py[] = "cymysql/charset.py";
static const char __pyx_k_gb18030_chinese_ci[] = "gb18030_chinese_ci";
static const char __pyx_k_geostd8_general_ci[] = "geostd8_general_ci";
static const char __pyx_k_keybcs2_general_ci[] = "keybcs2_general_ci";
static const char __pyx_k_latin2_croatian_ci[] = "latin2_croatian_ci";
static const char __pyx_k_latin7_estonian_cs[] = "latin7_estonian_cs";
static const char __pyx_k_ucs2_lithuanian_ci[] = "ucs2_lithuanian_ci";
static const char __pyx_k_ucs2_vietnamese_ci[] = "ucs2_vietnamese_ci";
static const char __pyx_k_utf16_esperanto_ci[] = "utf16_esperanto_ci";
static const char __pyx_k_utf16_hungarian_ci[] = "utf16_hungarian_ci";
static const char __pyx_k_utf16_icelandic_ci[] = "utf16_icelandic_ci";
static const char __pyx_k_utf16_slovenian_ci[] = "utf16_slovenian_ci";
static const char __pyx_k_utf16le_general_ci[] = "utf16le_general_ci";
static const char __pyx_k_utf32_esperanto_ci[] = "utf32_esperanto_ci";
static const char __pyx_k_utf32_hungarian_ci[] = "utf32_hungarian_ci";
static const char __pyx_k_utf32_icelandic_ci[] = "utf32_icelandic_ci";
static const char __pyx_k_utf32_slovenian_ci[] = "utf32_slovenian_ci";
static const char __pyx_k_utf8_lithuanian_ci[] = "utf8_lithuanian_ci";
static const char __pyx_k_utf8_vietnamese_ci[] = "utf8_vietnamese_ci";
static const char __pyx_k_utf8mb4_0900_ai_ci[] = "utf8mb4_0900_ai_ci";
static const char __pyx_k_utf8mb4_0900_as_ci[] = "utf8mb4_0900_as_ci";
static const char __pyx_k_utf8mb4_0900_as_cs[] = "utf8mb4_0900_as_cs";
static const char __pyx_k_utf8mb4_general_ci[] = "utf8mb4_general_ci";
static const char __pyx_k_utf8mb4_german2_ci[] = "utf8mb4_german2_ci";
static const char __pyx_k_utf8mb4_latvian_ci[] = "utf8mb4_latvian_ci";
static const char __pyx_k_utf8mb4_persian_ci[] = "utf8mb4_persian_ci";
static const char __pyx_k_utf8mb4_sinhala_ci[] = "utf8mb4_sinhala_ci";
static const char __pyx_k_utf8mb4_spanish_ci[] = "utf8mb4_spanish_ci";
static const char __pyx_k_utf8mb4_swedish_ci[] = "utf8mb4_swedish_ci";
static const char __pyx_k_utf8mb4_turkish_ci[] = "utf8mb4_turkish_ci";
static const char __pyx_k_utf8mb4_unicode_ci[] = "utf8mb4_unicode_ci";
static const char __pyx_k_armscii8_general_ci[] = "armscii8_general_ci";
static const char __pyx_k_cp1251_bulgarian_ci[] = "cp1251_bulgarian_ci";
static const char __pyx_k_cp1251_ukrainian_ci[] = "cp1251_ukrainian_ci";
static const char __pyx_k_eucjpms_japanese_ci[] = "eucjpms_japanese_ci";
static const char __pyx_k_latin2_hungarian_ci[] = "latin2_hungarian_ci";
static const char __pyx_k_macroman_general_ci[] = "macroman_general_ci";
static const char __pyx_k_ucs2_unicode_520_ci[] = "ucs2_unicode_520_ci";
static const char __pyx_k_utf16_lithuanian_ci[] = "utf16_lithuanian_ci";
static const char __pyx_k_utf16_vietnamese_ci[] = "utf16_vietnamese_ci";
static const char __pyx_k_utf32_lithuanian_ci[] = "utf32_lithuanian_ci";
static const char __pyx_k_utf32_vietnamese_ci[] = "utf32_vietnamese_ci";
static const char __pyx_k_utf8_unicode_520_ci[] = "utf8_unicode_520_ci";
static const char __pyx_k_utf8mb4_croatian_ci[] = "utf8mb4_croatian_ci";
static const char __pyx_k_utf8mb4_estonian_ci[] = "utf8mb4_estonian_ci";
static const char __pyx_k_utf8mb4_romanian_ci[] = "utf8mb4_romanian_ci";
static const char __pyx_k_utf8mb4_spanish2_ci[] = "utf8mb4_spanish2_ci";
static const char __pyx_k_cp1257_lithuanian_ci[] = "cp1257_lithuanian_ci";
static const char __pyx_k_pyx_unpickle_Charset[] = "__pyx_unpickle_Charset";
static const char __pyx_k_utf16_unicode_520_ci[] = "utf16_unicode_520_ci";
static const char __pyx_k_utf32_unicode_520_ci[] = "utf32_unicode_520_ci";
static const char __pyx_k_utf8mb4_esperanto_ci[] = "utf8mb4_esperanto_ci";
static const char __pyx_k_utf8mb4_hungarian_ci[] = "utf8mb4_hungarian_ci";
static const char __pyx_k_utf8mb4_icelandic_ci[] = "utf8mb4_icelandic_ci";
static const char __pyx_k_utf8mb4_slovenian_ci[] = "utf8mb4_slovenian_ci";
static const char __pyx_k_pyx_unpickle_Charsets[] = "__pyx_unpickle_Charsets";
static const char __pyx_k_utf8mb4_cs_0900_ai_ci[] = "utf8mb4_cs_0900_ai_ci";
static const char __pyx_k_utf8mb4_cs_0900_as_cs[] = "utf8mb4_cs_0900_as_cs";
static const char __pyx_k_utf8mb4_da_0900_ai_ci[] = "utf8mb4_da_0900_ai_ci";
static const char __pyx_k_utf8mb4_da_0900_as_cs[] = "utf8mb4_da_0900_as_cs";
static const char __pyx_k_utf8mb4_eo_0900_ai_ci[] = "utf8mb4_eo_0900_ai_ci";
static const char __pyx_k_utf8mb4_eo_0900_as_cs[] = "utf8mb4_eo_0900_as_cs";
static const char __pyx_k_utf8mb4_es_0900_ai_ci[] = "utf8mb4_es_0900_ai_ci";
static const char __pyx_k_utf8mb4_es_0900_as_cs[] = "utf8mb4_es_0900_as_cs";
static const char __pyx_k_utf8mb4_et_0900_ai_ci[] = "utf8mb4_et_0900_ai_ci";
static const char __pyx_k_utf8mb4_et_0900_as_cs[] = "utf8mb4_et_0900_as_cs";
static const char __pyx_k_utf8mb4_hr_0900_ai_ci[] = "utf8mb4_hr_0900_ai_ci";
static const char __pyx_k_utf8mb4_hr_0900_as_cs[] = "utf8mb4_hr_0900_as_cs";
static const char __pyx_k_utf8mb4_hu_0900_ai_ci[] = "utf8mb4_hu_0900_ai_ci";
static const char __pyx_k_utf8mb4_hu_0900_as_cs[] = "utf8mb4_hu_0900_as_cs";
static const char __pyx_k_utf8mb4_is_0900_ai_ci[] = "utf8mb4_is_0900_ai_ci";
static const char __pyx_k_utf8mb4_is_0900_as_cs[] = "utf8mb4_is_0900_as_cs";
static const char __pyx_k_utf8mb4_ja_0900_as_cs[] = "utf8mb4_ja_0900_as_cs";
static const char __pyx_k_utf8mb4_la_0900_ai_ci[] = "utf8mb4_la_0900_ai_ci";
static const char __pyx_k_utf8mb4_la_0900_as_cs[] = "utf8mb4_la_0900_as_cs";
static const char __pyx_k_utf8mb4_lithuanian_ci[] = "utf8mb4_lithuanian_ci";
static const char __pyx_k_utf8mb4_lt_0900_ai_ci[] = "utf8mb4_lt_0900_ai_ci";
static const char __pyx_k_utf8mb4_lt_0900_as_cs[] = "utf8mb4_lt_0900_as_cs";
static const char __pyx_k_utf8mb4_lv_0900_ai_ci[] = "utf8mb4_lv_0900_ai_ci";
static const char __pyx_k_utf8mb4_lv_0900_as_cs[] = "utf8mb4_lv_0900_as_cs";
static const char __pyx_k_utf8mb4_pl_0900_ai_ci[] = "utf8mb4_pl_0900_ai_ci";
static const char __pyx_k_utf8mb4_pl_0900_as_cs[] = "utf8mb4_pl_0900_as_cs";
static const char __pyx_k_utf8mb4_ro_0900_ai_ci[] = "utf8mb4_ro_0900_ai_ci";
static const char __pyx_k_utf8mb4_ro_0900_as_cs[] = "utf8mb4_ro_0900_as_cs";
static const char __pyx_k_utf8mb4_ru_0900_ai_ci[] = "utf8mb4_ru_0900_ai_ci";
static const char __pyx_k_utf8mb4_ru_0900_as_cs[] = "utf8mb4_ru_0900_as_cs";
static const char __pyx_k_utf8mb4_sk_0900_ai_ci[] = "utf8mb4_sk_0900_ai_ci";
static const char __pyx_k_utf8mb4_sk_0900_as_cs[] = "utf8mb4_sk_0900_as_cs";
static const char __pyx_k_utf8mb4_sl_0900_ai_ci[] = "utf8mb4_sl_0900_ai_ci";
static const char __pyx_k_utf8mb4_sl_0900_as_cs[] = "utf8mb4_sl_0900_as_cs";
static const char __pyx_k_utf8mb4_sv_0900_ai_ci[] = "utf8mb4_sv_0900_ai_ci";
static const char __pyx_k_utf8mb4_sv_0900_as_cs[] = "utf8mb4_sv_0900_as_cs";
static const char __pyx_k_utf8mb4_tr_0900_ai_ci[] = "utf8mb4_tr_0900_ai_ci";
static const char __pyx_k_utf8mb4_tr_0900_as_cs[] = "utf8mb4_tr_0900_as_cs";
static const char __pyx_k_utf8mb4_vi_0900_ai_ci[] = "utf8mb4_vi_0900_ai_ci";
static const char __pyx_k_utf8mb4_vi_0900_as_cs[] = "utf8mb4_vi_0900_as_cs";
static const char __pyx_k_utf8mb4_vietnamese_ci[] = "utf8mb4_vietnamese_ci";
static const char __pyx_k_gb18030_unicode_520_ci[] = "gb18030_unicode_520_ci";
static const char __pyx_k_utf8mb4_unicode_520_ci[] = "utf8mb4_unicode_520_ci";
static const char __pyx_k_Charset___reduce_cython[] = "Charset.__reduce_cython__";
static const char __pyx_k_Charsets___reduce_cython[] = "Charsets.__reduce_cython__";
static const char __pyx_k_ucs2_general_mysql500_ci[] = "ucs2_general_mysql500_ci";
static const char __pyx_k_utf8_general_mysql500_ci[] = "utf8_general_mysql500_ci";
static const char __pyx_k_utf8mb4_de_pb_0900_ai_ci[] = "utf8mb4_de_pb_0900_ai_ci";
static const char __pyx_k_utf8mb4_de_pb_0900_as_cs[] = "utf8mb4_de_pb_0900_as_cs";
static const char __pyx_k_utf8mb4_ja_0900_as_cs_ks[] = "utf8mb4_ja_0900_as_cs_ks";
static const char __pyx_k_Charset___setstate_cython[] = "Charset.__setstate_cython__";
static const char __pyx_k_Charsets___setstate_cython[] = "Charsets.__setstate_cython__";
static const char __pyx_k_utf8mb4_es_trad_0900_ai_ci[] = "utf8mb4_es_trad_0900_ai_ci";
static const char __pyx_k_utf8mb4_es_trad_0900_as_cs[] = "utf8mb4_es_trad_0900_as_cs";
static const char __pyx_k_Incompatible_checksums_s_vs_0x5f[] = "Incompatible checksums (%s vs 0x5fb43bd = (_by_id))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x77[] = "Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))";
static PyObject *__pyx_n_s_Charset___reduce_cython;
static PyObject *__pyx_n_s_Charset___setstate_cython;
static PyObject *__pyx_n_s_Charsets___reduce_cython;
static PyObject *__pyx_n_s_Charsets___setstate_cython;
static PyObject *__pyx_n_s_Charsets_by_id;
static PyObject *__pyx_n_s_Charsets_by_name;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x5f;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x77;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_Yes;
static PyObject *__pyx_kp_s__14;
static PyObject *__pyx_n_s_armscii8;
static PyObject *__pyx_n_s_armscii8_bin;
static PyObject *__pyx_n_s_armscii8_general_ci;
static PyObject *__pyx_n_s_ascii;
static PyObject *__pyx_n_s_ascii_bin;
static PyObject *__pyx_n_s_ascii_general_ci;
static PyObject *__pyx_n_s_big5;
static PyObject *__pyx_n_s_big5_bin;
static PyObject *__pyx_n_s_big5_chinese_ci;
static PyObject *__pyx_n_s_binary;
static PyObject *__pyx_n_s_by_id;
static PyObject *__pyx_n_s_by_name;
static PyObject *__pyx_n_s_charset_by_id;
static PyObject *__pyx_n_s_charset_by_name;
static PyObject *__pyx_n_s_charsets;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_collation;
static PyObject *__pyx_n_s_cp1250;
static PyObject *__pyx_n_s_cp1250_bin;
static PyObject *__pyx_n_s_cp1250_croatian_ci;
static PyObject *__pyx_n_s_cp1250_czech_cs;
static PyObject *__pyx_n_s_cp1250_general_ci;
static PyObject *__pyx_n_s_cp1250_polish_ci;
static PyObject *__pyx_n_s_cp1251;
static PyObject *__pyx_n_s_cp1251_bin;
static PyObject *__pyx_n_s_cp1251_bulgarian_ci;
static PyObject *__pyx_n_s_cp1251_general_ci;
static PyObject *__pyx_n_s_cp1251_general_cs;
static PyObject *__pyx_n_s_cp1251_ukrainian_ci;
static PyObject *__pyx_n_s_cp1256;
static PyObject *__pyx_n_s_cp1256_bin;
static PyObject *__pyx_n_s_cp1256_general_ci;
static PyObject *__pyx_n_s_cp1257;
static PyObject *__pyx_n_s_cp1257_bin;
static PyObject *__pyx_n_s_cp1257_general_ci;
static PyObject *__pyx_n_s_cp1257_lithuanian_ci;
static PyObject *__pyx_n_s_cp850;
static PyObject *__pyx_n_s_cp850_bin;
static PyObject *__pyx_n_s_cp850_general_ci;
static PyObject *__pyx_n_s_cp852;
static PyObject *__pyx_n_s_cp852_bin;
static PyObject *__pyx_n_s_cp852_general_ci;
static PyObject *__pyx_n_s_cp866;
static PyObject *__pyx_n_s_cp866_bin;
static PyObject *__pyx_n_s_cp866_general_ci;
static PyObject *__pyx_n_s_cp932;
static PyObject *__pyx_n_s_cp932_bin;
static PyObject *__pyx_n_s_cp932_japanese_ci;
static PyObject *__pyx_n_s_cymysql_charset;
static PyObject *__pyx_kp_s_cymysql_charset_py;
static PyObject *__pyx_n_s_dec8;
static PyObject *__pyx_n_s_dec8_bin;
static PyObject *__pyx_n_s_dec8_swedish_ci;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_dict_2;
static PyObject *__pyx_n_s_eucjpms;
static PyObject *__pyx_n_s_eucjpms_bin;
static PyObject *__pyx_n_s_eucjpms_japanese_ci;
static PyObject *__pyx_n_s_euckr;
static PyObject *__pyx_n_s_euckr_bin;
static PyObject *__pyx_n_s_euckr_korean_ci;
static PyObject *__pyx_n_s_gb18030;
static PyObject *__pyx_n_s_gb18030_bin;
static PyObject *__pyx_n_s_gb18030_chinese_ci;
static PyObject *__pyx_n_s_gb18030_unicode_520_ci;
static PyObject *__pyx_n_s_gb2312;
static PyObject *__pyx_n_s_gb2312_bin;
static PyObject *__pyx_n_s_gb2312_chinese_ci;
static PyObject *__pyx_n_s_gbk;
static PyObject *__pyx_n_s_gbk_bin;
static PyObject *__pyx_n_s_gbk_chinese_ci;
static PyObject *__pyx_n_s_geostd8;
static PyObject *__pyx_n_s_geostd8_bin;
static PyObject *__pyx_n_s_geostd8_general_ci;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_greek;
static PyObject *__pyx_n_s_greek_bin;
static PyObject *__pyx_n_s_greek_general_ci;
static PyObject *__pyx_n_s_hebrew;
static PyObject *__pyx_n_s_hebrew_bin;
static PyObject *__pyx_n_s_hebrew_general_ci;
static PyObject *__pyx_n_s_hp8;
static PyObject *__pyx_n_s_hp8_bin;
static PyObject *__pyx_n_s_hp8_english_ci;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_is_default;
static PyObject *__pyx_n_s_keybcs2;
static PyObject *__pyx_n_s_keybcs2_bin;
static PyObject *__pyx_n_s_keybcs2_general_ci;
static PyObject *__pyx_n_s_koi8r;
static PyObject *__pyx_n_s_koi8r_bin;
static PyObject *__pyx_n_s_koi8r_general_ci;
static PyObject *__pyx_n_s_koi8u;
static PyObject *__pyx_n_s_koi8u_bin;
static PyObject *__pyx_n_s_koi8u_general_ci;
static PyObject *__pyx_n_s_latin1;
static PyObject *__pyx_n_s_latin1_bin;
static PyObject *__pyx_n_s_latin1_danish_ci;
static PyObject *__pyx_n_s_latin1_general_ci;
static PyObject *__pyx_n_s_latin1_general_cs;
static PyObject *__pyx_n_s_latin1_german1_ci;
static PyObject *__pyx_n_s_latin1_german2_ci;
static PyObject *__pyx_n_s_latin1_spanish_ci;
static PyObject *__pyx_n_s_latin1_swedish_ci;
static PyObject *__pyx_n_s_latin2;
static PyObject *__pyx_n_s_latin2_bin;
static PyObject *__pyx_n_s_latin2_croatian_ci;
static PyObject *__pyx_n_s_latin2_czech_cs;
static PyObject *__pyx_n_s_latin2_general_ci;
static PyObject *__pyx_n_s_latin2_hungarian_ci;
static PyObject *__pyx_n_s_latin5;
static PyObject *__pyx_n_s_latin5_bin;
static PyObject *__pyx_n_s_latin5_turkish_ci;
static PyObject *__pyx_n_s_latin7;
static PyObject *__pyx_n_s_latin7_bin;
static PyObject *__pyx_n_s_latin7_estonian_cs;
static PyObject *__pyx_n_s_latin7_general_ci;
static PyObject *__pyx_n_s_latin7_general_cs;
static PyObject *__pyx_n_s_macce;
static PyObject *__pyx_n_s_macce_bin;
static PyObject *__pyx_n_s_macce_general_ci;
static PyObject *__pyx_n_s_macroman;
static PyObject *__pyx_n_s_macroman_bin;
static PyObject *__pyx_n_s_macroman_general_ci;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_capi;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_Charset;
static PyObject *__pyx_n_s_pyx_unpickle_Charsets;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_sjis;
static PyObject *__pyx_n_s_sjis_bin;
static PyObject *__pyx_n_s_sjis_japanese_ci;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_swe7;
static PyObject *__pyx_n_s_swe7_bin;
static PyObject *__pyx_n_s_swe7_swedish_ci;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_tis620;
static PyObject *__pyx_n_s_tis620_bin;
static PyObject *__pyx_n_s_tis620_thai_ci;
static PyObject *__pyx_n_s_ucs2;
static PyObject *__pyx_n_s_ucs2_bin;
static PyObject *__pyx_n_s_ucs2_croatian_ci;
static PyObject *__pyx_n_s_ucs2_czech_ci;
static PyObject *__pyx_n_s_ucs2_danish_ci;
static PyObject *__pyx_n_s_ucs2_esperanto_ci;
static PyObject *__pyx_n_s_ucs2_estonian_ci;
static PyObject *__pyx_n_s_ucs2_general_ci;
static PyObject *__pyx_n_s_ucs2_general_mysql500_ci;
static PyObject *__pyx_n_s_ucs2_german2_ci;
static PyObject *__pyx_n_s_ucs2_hungarian_ci;
static PyObject *__pyx_n_s_ucs2_icelandic_ci;
static PyObject *__pyx_n_s_ucs2_latvian_ci;
static PyObject *__pyx_n_s_ucs2_lithuanian_ci;
static PyObject *__pyx_n_s_ucs2_persian_ci;
static PyObject *__pyx_n_s_ucs2_polish_ci;
static PyObject *__pyx_n_s_ucs2_roman_ci;
static PyObject *__pyx_n_s_ucs2_romanian_ci;
static PyObject *__pyx_n_s_ucs2_sinhala_ci;
static PyObject *__pyx_n_s_ucs2_slovak_ci;
static PyObject *__pyx_n_s_ucs2_slovenian_ci;
static PyObject *__pyx_n_s_ucs2_spanish2_ci;
static PyObject *__pyx_n_s_ucs2_spanish_ci;
static PyObject *__pyx_n_s_ucs2_swedish_ci;
static PyObject *__pyx_n_s_ucs2_turkish_ci;
static PyObject *__pyx_n_s_ucs2_unicode_520_ci;
static PyObject *__pyx_n_s_ucs2_unicode_ci;
static PyObject *__pyx_n_s_ucs2_vietnamese_ci;
static PyObject *__pyx_n_s_ujis;
static PyObject *__pyx_n_s_ujis_bin;
static PyObject *__pyx_n_s_ujis_japanese_ci;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_use_setstate;
static PyObject *__pyx_n_s_utf16;
static PyObject *__pyx_n_s_utf16_bin;
static PyObject *__pyx_n_s_utf16_croatian_ci;
static PyObject *__pyx_n_s_utf16_czech_ci;
static PyObject *__pyx_n_s_utf16_danish_ci;
static PyObject *__pyx_n_s_utf16_esperanto_ci;
static PyObject *__pyx_n_s_utf16_estonian_ci;
static PyObject *__pyx_n_s_utf16_general_ci;
static PyObject *__pyx_n_s_utf16_german2_ci;
static PyObject *__pyx_n_s_utf16_hungarian_ci;
static PyObject *__pyx_n_s_utf16_icelandic_ci;
static PyObject *__pyx_n_s_utf16_latvian_ci;
static PyObject *__pyx_n_s_utf16_lithuanian_ci;
static PyObject *__pyx_n_s_utf16_persian_ci;
static PyObject *__pyx_n_s_utf16_polish_ci;
static PyObject *__pyx_n_s_utf16_roman_ci;
static PyObject *__pyx_n_s_utf16_romanian_ci;
static PyObject *__pyx_n_s_utf16_sinhala_ci;
static PyObject *__pyx_n_s_utf16_slovak_ci;
static PyObject *__pyx_n_s_utf16_slovenian_ci;
static PyObject *__pyx_n_s_utf16_spanish2_ci;
static PyObject *__pyx_n_s_utf16_spanish_ci;
static PyObject *__pyx_n_s_utf16_swedish_ci;
static PyObject *__pyx_n_s_utf16_turkish_ci;
static PyObject *__pyx_n_s_utf16_unicode_520_ci;
static PyObject *__pyx_n_s_utf16_unicode_ci;
static PyObject *__pyx_n_s_utf16_vietnamese_ci;
static PyObject *__pyx_n_s_utf16le;
static PyObject *__pyx_n_s_utf16le_bin;
static PyObject *__pyx_n_s_utf16le_general_ci;
static PyObject *__pyx_n_s_utf32;
static PyObject *__pyx_n_s_utf32_bin;
static PyObject *__pyx_n_s_utf32_croatian_ci;
static PyObject *__pyx_n_s_utf32_czech_ci;
static PyObject *__pyx_n_s_utf32_danish_ci;
static PyObject *__pyx_n_s_utf32_esperanto_ci;
static PyObject *__pyx_n_s_utf32_estonian_ci;
static PyObject *__pyx_n_s_utf32_general_ci;
static PyObject *__pyx_n_s_utf32_german2_ci;
static PyObject *__pyx_n_s_utf32_hungarian_ci;
static PyObject *__pyx_n_s_utf32_icelandic_ci;
static PyObject *__pyx_n_s_utf32_latvian_ci;
static PyObject *__pyx_n_s_utf32_lithuanian_ci;
static PyObject *__pyx_n_s_utf32_persian_ci;
static PyObject *__pyx_n_s_utf32_polish_ci;
static PyObject *__pyx_n_s_utf32_roman_ci;
static PyObject *__pyx_n_s_utf32_romanian_ci;
static PyObject *__pyx_n_s_utf32_sinhala_ci;
static PyObject *__pyx_n_s_utf32_slovak_ci;
static PyObject *__pyx_n_s_utf32_slovenian_ci;
static PyObject *__pyx_n_s_utf32_spanish2_ci;
static PyObject *__pyx_n_s_utf32_spanish_ci;
static PyObject *__pyx_n_s_utf32_swedish_ci;
static PyObject *__pyx_n_s_utf32_turkish_ci;
static PyObject *__pyx_n_s_utf32_unicode_520_ci;
static PyObject *__pyx_n_s_utf32_unicode_ci;
static PyObject *__pyx_n_s_utf32_vietnamese_ci;
static PyObject *__pyx_n_s_utf8;
static PyObject *__pyx_n_s_utf8_bin;
static PyObject *__pyx_n_s_utf8_croatian_ci;
static PyObject *__pyx_n_s_utf8_czech_ci;
static PyObject *__pyx_n_s_utf8_danish_ci;
static PyObject *__pyx_n_s_utf8_esperanto_ci;
static PyObject *__pyx_n_s_utf8_estonian_ci;
static PyObject *__pyx_n_s_utf8_general_ci;
static PyObject *__pyx_n_s_utf8_general_mysql500_ci;
static PyObject *__pyx_n_s_utf8_german2_ci;
static PyObject *__pyx_n_s_utf8_hungarian_ci;
static PyObject *__pyx_n_s_utf8_icelandic_ci;
static PyObject *__pyx_n_s_utf8_latvian_ci;
static PyObject *__pyx_n_s_utf8_lithuanian_ci;
static PyObject *__pyx_n_s_utf8_persian_ci;
static PyObject *__pyx_n_s_utf8_polish_ci;
static PyObject *__pyx_n_s_utf8_roman_ci;
static PyObject *__pyx_n_s_utf8_romanian_ci;
static PyObject *__pyx_n_s_utf8_sinhala_ci;
static PyObject *__pyx_n_s_utf8_slovak_ci;
static PyObject *__pyx_n_s_utf8_slovenian_ci;
static PyObject *__pyx_n_s_utf8_spanish2_ci;
static PyObject *__pyx_n_s_utf8_spanish_ci;
static PyObject *__pyx_n_s_utf8_swedish_ci;
static PyObject *__pyx_n_s_utf8_tolower_ci;
static PyObject *__pyx_n_s_utf8_turkish_ci;
static PyObject *__pyx_n_s_utf8_unicode_520_ci;
static PyObject *__pyx_n_s_utf8_unicode_ci;
static PyObject *__pyx_n_s_utf8_vietnamese_ci;
static PyObject *__pyx_n_s_utf8mb4;
static PyObject *__pyx_n_s_utf8mb4_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_0900_as_ci;
static PyObject *__pyx_n_s_utf8mb4_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_bin;
static PyObject *__pyx_n_s_utf8mb4_croatian_ci;
static PyObject *__pyx_n_s_utf8mb4_cs_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_cs_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_czech_ci;
static PyObject *__pyx_n_s_utf8mb4_da_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_da_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_danish_ci;
static PyObject *__pyx_n_s_utf8mb4_de_pb_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_de_pb_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_eo_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_eo_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_es_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_es_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_es_trad_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_es_trad_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_esperanto_ci;
static PyObject *__pyx_n_s_utf8mb4_estonian_ci;
static PyObject *__pyx_n_s_utf8mb4_et_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_et_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_general_ci;
static PyObject *__pyx_n_s_utf8mb4_german2_ci;
static PyObject *__pyx_n_s_utf8mb4_hr_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_hr_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_hu_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_hu_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_hungarian_ci;
static PyObject *__pyx_n_s_utf8mb4_icelandic_ci;
static PyObject *__pyx_n_s_utf8mb4_is_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_is_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_ja_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_ja_0900_as_cs_ks;
static PyObject *__pyx_n_s_utf8mb4_la_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_la_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_latvian_ci;
static PyObject *__pyx_n_s_utf8mb4_lithuanian_ci;
static PyObject *__pyx_n_s_utf8mb4_lt_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_lt_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_lv_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_lv_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_persian_ci;
static PyObject *__pyx_n_s_utf8mb4_pl_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_pl_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_polish_ci;
static PyObject *__pyx_n_s_utf8mb4_ro_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_ro_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_roman_ci;
static PyObject *__pyx_n_s_utf8mb4_romanian_ci;
static PyObject *__pyx_n_s_utf8mb4_ru_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_ru_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_sinhala_ci;
static PyObject *__pyx_n_s_utf8mb4_sk_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_sk_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_sl_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_sl_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_slovak_ci;
static PyObject *__pyx_n_s_utf8mb4_slovenian_ci;
static PyObject *__pyx_n_s_utf8mb4_spanish2_ci;
static PyObject *__pyx_n_s_utf8mb4_spanish_ci;
static PyObject *__pyx_n_s_utf8mb4_sv_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_sv_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_swedish_ci;
static PyObject *__pyx_n_s_utf8mb4_tr_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_tr_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_turkish_ci;
static PyObject *__pyx_n_s_utf8mb4_unicode_520_ci;
static PyObject *__pyx_n_s_utf8mb4_unicode_ci;
static PyObject *__pyx_n_s_utf8mb4_vi_0900_ai_ci;
static PyObject *__pyx_n_s_utf8mb4_vi_0900_as_cs;
static PyObject *__pyx_n_s_utf8mb4_vietnamese_ci;
static PyObject *__pyx_n_s_values;
static int __pyx_pf_7cymysql_7charset_7Charset___init__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2id___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4name___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_9collation___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2__reduce_cython__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4__setstate_cython__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7cymysql_7charset_8Charsets___init__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_2by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_4by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_6__reduce_cython__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_8__setstate_cython__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset___pyx_unpickle_Charset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_2__pyx_unpickle_Charsets(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_7cymysql_7charset_Charset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7cymysql_7charset_Charsets(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values = {0, &__pyx_n_s_values, 0, 0, 0};
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_9;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_11;
static PyObject *__pyx_int_12;
static PyObject *__pyx_int_13;
static PyObject *__pyx_int_14;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_19;
static PyObject *__pyx_int_20;
static PyObject *__pyx_int_21;
static PyObject *__pyx_int_22;
static PyObject *__pyx_int_23;
static PyObject *__pyx_int_24;
static PyObject *__pyx_int_25;
static PyObject *__pyx_int_26;
static PyObject *__pyx_int_27;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_29;
static PyObject *__pyx_int_30;
static PyObject *__pyx_int_31;
static PyObject *__pyx_int_32;
static PyObject *__pyx_int_33;
static PyObject *__pyx_int_34;
static PyObject *__pyx_int_35;
static PyObject *__pyx_int_36;
static PyObject *__pyx_int_37;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_39;
static PyObject *__pyx_int_40;
static PyObject *__pyx_int_41;
static PyObject *__pyx_int_42;
static PyObject *__pyx_int_43;
static PyObject *__pyx_int_44;
static PyObject *__pyx_int_45;
static PyObject *__pyx_int_46;
static PyObject *__pyx_int_47;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_49;
static PyObject *__pyx_int_50;
static PyObject *__pyx_int_51;
static PyObject *__pyx_int_52;
static PyObject *__pyx_int_53;
static PyObject *__pyx_int_54;
static PyObject *__pyx_int_55;
static PyObject *__pyx_int_56;
static PyObject *__pyx_int_57;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_59;
static PyObject *__pyx_int_60;
static PyObject *__pyx_int_61;
static PyObject *__pyx_int_62;
static PyObject *__pyx_int_63;
static PyObject *__pyx_int_64;
static PyObject *__pyx_int_65;
static PyObject *__pyx_int_66;
static PyObject *__pyx_int_67;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_69;
static PyObject *__pyx_int_70;
static PyObject *__pyx_int_71;
static PyObject *__pyx_int_72;
static PyObject *__pyx_int_73;
static PyObject *__pyx_int_74;
static PyObject *__pyx_int_75;
static PyObject *__pyx_int_76;
static PyObject *__pyx_int_77;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_79;
static PyObject *__pyx_int_80;
static PyObject *__pyx_int_81;
static PyObject *__pyx_int_82;
static PyObject *__pyx_int_83;
static PyObject *__pyx_int_84;
static PyObject *__pyx_int_85;
static PyObject *__pyx_int_86;
static PyObject *__pyx_int_87;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_89;
static PyObject *__pyx_int_90;
static PyObject *__pyx_int_91;
static PyObject *__pyx_int_92;
static PyObject *__pyx_int_93;
static PyObject *__pyx_int_94;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_96;
static PyObject *__pyx_int_97;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_99;
static PyObject *__pyx_int_101;
static PyObject *__pyx_int_102;
static PyObject *__pyx_int_103;
static PyObject *__pyx_int_104;
static PyObject *__pyx_int_105;
static PyObject *__pyx_int_106;
static PyObject *__pyx_int_107;
static PyObject *__pyx_int_108;
static PyObject *__pyx_int_109;
static PyObject *__pyx_int_110;
static PyObject *__pyx_int_111;
static PyObject *__pyx_int_112;
static PyObject *__pyx_int_113;
static PyObject *__pyx_int_114;
static PyObject *__pyx_int_115;
static PyObject *__pyx_int_116;
static PyObject *__pyx_int_117;
static PyObject *__pyx_int_118;
static PyObject *__pyx_int_119;
static PyObject *__pyx_int_120;
static PyObject *__pyx_int_121;
static PyObject *__pyx_int_122;
static PyObject *__pyx_int_123;
static PyObject *__pyx_int_124;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_129;
static PyObject *__pyx_int_130;
static PyObject *__pyx_int_131;
static PyObject *__pyx_int_132;
static PyObject *__pyx_int_133;
static PyObject *__pyx_int_134;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_136;
static PyObject *__pyx_int_137;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_139;
static PyObject *__pyx_int_140;
static PyObject *__pyx_int_141;
static PyObject *__pyx_int_142;
static PyObject *__pyx_int_143;
static PyObject *__pyx_int_144;
static PyObject *__pyx_int_145;
static PyObject *__pyx_int_146;
static PyObject *__pyx_int_147;
static PyObject *__pyx_int_148;
static PyObject *__pyx_int_149;
static PyObject *__pyx_int_150;
static PyObject *__pyx_int_151;
static PyObject *__pyx_int_159;
static PyObject *__pyx_int_160;
static PyObject *__pyx_int_161;
static PyObject *__pyx_int_162;
static PyObject *__pyx_int_163;
static PyObject *__pyx_int_164;
static PyObject *__pyx_int_165;
static PyObject *__pyx_int_166;
static PyObject *__pyx_int_167;
static PyObject *__pyx_int_168;
static PyObject *__pyx_int_169;
static PyObject *__pyx_int_170;
static PyObject *__pyx_int_171;
static PyObject *__pyx_int_172;
static PyObject *__pyx_int_173;
static PyObject *__pyx_int_174;
static PyObject *__pyx_int_175;
static PyObject *__pyx_int_176;
static PyObject *__pyx_int_177;
static PyObject *__pyx_int_178;
static PyObject *__pyx_int_179;
static PyObject *__pyx_int_180;
static PyObject *__pyx_int_181;
static PyObject *__pyx_int_182;
static PyObject *__pyx_int_183;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_193;
static PyObject *__pyx_int_194;
static PyObject *__pyx_int_195;
static PyObject *__pyx_int_196;
static PyObject *__pyx_int_197;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_199;
static PyObject *__pyx_int_200;
static PyObject *__pyx_int_201;
static PyObject *__pyx_int_202;
static PyObject *__pyx_int_203;
static PyObject *__pyx_int_204;
static PyObject *__pyx_int_205;
static PyObject *__pyx_int_206;
static PyObject *__pyx_int_207;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_209;
static PyObject *__pyx_int_210;
static PyObject *__pyx_int_211;
static PyObject *__pyx_int_212;
static PyObject *__pyx_int_213;
static PyObject *__pyx_int_214;
static PyObject *__pyx_int_215;
static PyObject *__pyx_int_223;
static PyObject *__pyx_int_224;
static PyObject *__pyx_int_225;
static PyObject *__pyx_int_226;
static PyObject *__pyx_int_227;
static PyObject *__pyx_int_228;
static PyObject *__pyx_int_229;
static PyObject *__pyx_int_230;
static PyObject *__pyx_int_231;
static PyObject *__pyx_int_232;
static PyObject *__pyx_int_233;
static PyObject *__pyx_int_234;
static PyObject *__pyx_int_235;
static PyObject *__pyx_int_236;
static PyObject *__pyx_int_237;
static PyObject *__pyx_int_238;
static PyObject *__pyx_int_239;
static PyObject *__pyx_int_240;
static PyObject *__pyx_int_241;
static PyObject *__pyx_int_242;
static PyObject *__pyx_int_243;
static PyObject *__pyx_int_244;
static PyObject *__pyx_int_245;
static PyObject *__pyx_int_246;
static PyObject *__pyx_int_247;
static PyObject *__pyx_int_248;
static PyObject *__pyx_int_249;
static PyObject *__pyx_int_250;
static PyObject *__pyx_int_255;
static PyObject *__pyx_int_256;
static PyObject *__pyx_int_257;
static PyObject *__pyx_int_258;
static PyObject *__pyx_int_259;
static PyObject *__pyx_int_260;
static PyObject *__pyx_int_261;
static PyObject *__pyx_int_262;
static PyObject *__pyx_int_263;
static PyObject *__pyx_int_264;
static PyObject *__pyx_int_265;
static PyObject *__pyx_int_266;
static PyObject *__pyx_int_267;
static PyObject *__pyx_int_268;
static PyObject *__pyx_int_269;
static PyObject *__pyx_int_270;
static PyObject *__pyx_int_271;
static PyObject *__pyx_int_273;
static PyObject *__pyx_int_274;
static PyObject *__pyx_int_275;
static PyObject *__pyx_int_277;
static PyObject *__pyx_int_278;
static PyObject *__pyx_int_279;
static PyObject *__pyx_int_280;
static PyObject *__pyx_int_281;
static PyObject *__pyx_int_282;
static PyObject *__pyx_int_283;
static PyObject *__pyx_int_284;
static PyObject *__pyx_int_285;
static PyObject *__pyx_int_286;
static PyObject *__pyx_int_287;
static PyObject *__pyx_int_288;
static PyObject *__pyx_int_289;
static PyObject *__pyx_int_290;
static PyObject *__pyx_int_291;
static PyObject *__pyx_int_292;
static PyObject *__pyx_int_293;
static PyObject *__pyx_int_294;
static PyObject *__pyx_int_296;
static PyObject *__pyx_int_297;
static PyObject *__pyx_int_298;
static PyObject *__pyx_int_300;
static PyObject *__pyx_int_303;
static PyObject *__pyx_int_304;
static PyObject *__pyx_int_305;
static PyObject *__pyx_int_306;
static PyObject *__pyx_int_307;
static PyObject *__pyx_int_100352957;
static PyObject *__pyx_int_125328330;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__96;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_codeobj__2;
static PyObject *__pyx_codeobj__4;
static PyObject *__pyx_codeobj__6;
static PyObject *__pyx_codeobj__8;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__102;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__109;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_tuple__112;
static PyObject *__pyx_tuple__113;
static PyObject *__pyx_tuple__114;
static PyObject *__pyx_tuple__115;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__119;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__122;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__124;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_tuple__126;
static PyObject *__pyx_tuple__127;
static PyObject *__pyx_tuple__128;
static PyObject *__pyx_tuple__129;
static PyObject *__pyx_tuple__130;
static PyObject *__pyx_tuple__131;
static PyObject *__pyx_tuple__132;
static PyObject *__pyx_tuple__133;
static PyObject *__pyx_tuple__134;
static PyObject *__pyx_tuple__135;
static PyObject *__pyx_tuple__136;
static PyObject *__pyx_tuple__137;
static PyObject *__pyx_tuple__138;
static PyObject *__pyx_tuple__139;
static PyObject *__pyx_tuple__140;
static PyObject *__pyx_tuple__141;
static PyObject *__pyx_tuple__142;
static PyObject *__pyx_tuple__143;
static PyObject *__pyx_tuple__144;
static PyObject *__pyx_tuple__145;
static PyObject *__pyx_tuple__146;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__148;
static PyObject *__pyx_tuple__149;
static PyObject *__pyx_tuple__150;
static PyObject *__pyx_tuple__151;
static PyObject *__pyx_tuple__152;
static PyObject *__pyx_tuple__153;
static PyObject *__pyx_tuple__154;
static PyObject *__pyx_tuple__155;
static PyObject *__pyx_tuple__156;
static PyObject *__pyx_tuple__157;
static PyObject *__pyx_tuple__158;
static PyObject *__pyx_tuple__159;
static PyObject *__pyx_tuple__160;
static PyObject *__pyx_tuple__161;
static PyObject *__pyx_tuple__162;
static PyObject *__pyx_tuple__163;
static PyObject *__pyx_tuple__164;
static PyObject *__pyx_tuple__165;
static PyObject *__pyx_tuple__166;
static PyObject *__pyx_tuple__167;
static PyObject *__pyx_tuple__168;
static PyObject *__pyx_tuple__169;
static PyObject *__pyx_tuple__170;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__172;
static PyObject *__pyx_tuple__173;
static PyObject *__pyx_tuple__174;
static PyObject *__pyx_tuple__175;
static PyObject *__pyx_tuple__176;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__178;
static PyObject *__pyx_tuple__179;
static PyObject *__pyx_tuple__180;
static PyObject *__pyx_tuple__181;
static PyObject *__pyx_tuple__182;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__184;
static PyObject *__pyx_tuple__185;
static PyObject *__pyx_tuple__186;
static PyObject *__pyx_tuple__187;
static PyObject *__pyx_tuple__188;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__190;
static PyObject *__pyx_tuple__191;
static PyObject *__pyx_tuple__192;
static PyObject *__pyx_tuple__193;
static PyObject *__pyx_tuple__194;
static PyObject *__pyx_tuple__195;
static PyObject *__pyx_tuple__196;
static PyObject *__pyx_tuple__197;
static PyObject *__pyx_tuple__198;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__200;
static PyObject *__pyx_tuple__201;
static PyObject *__pyx_tuple__202;
static PyObject *__pyx_tuple__203;
static PyObject *__pyx_tuple__204;
static PyObject *__pyx_tuple__205;
static PyObject *__pyx_tuple__206;
static PyObject *__pyx_tuple__207;
static PyObject *__pyx_tuple__208;
static PyObject *__pyx_tuple__209;
static PyObject *__pyx_tuple__210;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__212;
static PyObject *__pyx_tuple__213;
static PyObject *__pyx_tuple__214;
static PyObject *__pyx_tuple__215;
static PyObject *__pyx_tuple__216;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__218;
static PyObject *__pyx_tuple__219;
static PyObject *__pyx_tuple__220;
static PyObject *__pyx_tuple__221;
static PyObject *__pyx_tuple__222;
static PyObject *__pyx_tuple__223;
static PyObject *__pyx_tuple__224;
static PyObject *__pyx_tuple__225;
static PyObject *__pyx_tuple__226;
static PyObject *__pyx_tuple__227;
static PyObject *__pyx_tuple__228;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__230;
static PyObject *__pyx_tuple__231;
static PyObject *__pyx_tuple__232;
static PyObject *__pyx_tuple__233;
static PyObject *__pyx_tuple__234;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__236;
static PyObject *__pyx_tuple__237;
static PyObject *__pyx_tuple__238;
static PyObject *__pyx_tuple__239;
static PyObject *__pyx_tuple__240;
static PyObject *__pyx_tuple__241;
static PyObject *__pyx_tuple__242;
static PyObject *__pyx_tuple__243;
static PyObject *__pyx_tuple__244;
static PyObject *__pyx_tuple__245;
static PyObject *__pyx_tuple__246;
static PyObject *__pyx_tuple__247;
static PyObject *__pyx_tuple__248;
static PyObject *__pyx_tuple__249;
static PyObject *__pyx_tuple__250;
static PyObject *__pyx_tuple__251;
static PyObject *__pyx_tuple__252;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__254;
static PyObject *__pyx_tuple__255;
static PyObject *__pyx_tuple__256;
static PyObject *__pyx_tuple__257;
static PyObject *__pyx_tuple__258;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__260;
static PyObject *__pyx_tuple__261;
static PyObject *__pyx_tuple__262;
static PyObject *__pyx_tuple__263;
static PyObject *__pyx_tuple__264;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__266;
static PyObject *__pyx_tuple__267;
static PyObject *__pyx_tuple__268;
static PyObject *__pyx_tuple__269;
static PyObject *__pyx_tuple__270;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__272;
static PyObject *__pyx_tuple__273;
static PyObject *__pyx_tuple__274;
static PyObject *__pyx_tuple__275;
static PyObject *__pyx_tuple__276;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__278;
static PyObject *__pyx_tuple__279;
static PyObject *__pyx_tuple__280;
static PyObject *__pyx_tuple__281;
static PyObject *__pyx_tuple__282;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__284;
static PyObject *__pyx_tuple__286;
static PyObject *__pyx_codeobj__10;
static PyObject *__pyx_codeobj__12;
static PyObject *__pyx_codeobj__285;
static PyObject *__pyx_codeobj__287;

/* "cymysql/charset.py":2
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):             # <<<<<<<<<<<<<<
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_id = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_collation = 0;
  PyObject *__pyx_v_is_default = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_id,&__pyx_n_s_name,&__pyx_n_s_collation,&__pyx_n_s_is_default,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_id)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 1); __PYX_ERR(0, 2, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_collation)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 2); __PYX_ERR(0, 2, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_is_default)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 3); __PYX_ERR(0, 2, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_id = values[0];
    __pyx_v_name = values[1];
    __pyx_v_collation = values[2];
    __pyx_v_is_default = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset___init__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), __pyx_v_id, __pyx_v_name, __pyx_v_collation, __pyx_v_is_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset___init__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charset.py":3
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation             # <<<<<<<<<<<<<<
 *         self.is_default = is_default == 'Yes'
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_id); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3, __pyx_L1_error)
  if (!(likely(PyString_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_name)->tp_name), 0))) __PYX_ERR(0, 3, __pyx_L1_error)
  __pyx_t_2 = __pyx_v_name;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyString_CheckExact(__pyx_v_collation))||((__pyx_v_collation) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_collation)->tp_name), 0))) __PYX_ERR(0, 3, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_collation;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_self->id = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cymysql/charset.py":4
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_is_default, __pyx_n_s_Yes, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->is_default = __pyx_t_4;

  /* "cymysql/charset.py":2
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):             # <<<<<<<<<<<<<<
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cymysql.charset.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":4
 * 
 * cdef class Charset(object):
 *     cdef public int id             # <<<<<<<<<<<<<<
 *     cdef public str name, collation
 *     cdef public bint is_default
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_2id___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2id___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->id); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.id.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 4, __pyx_L1_error)
  __pyx_v_self->id = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.id.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":5
 * cdef class Charset(object):
 *     cdef public int id
 *     cdef public str name, collation             # <<<<<<<<<<<<<<
 *     cdef public bint is_default
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4name___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 5, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.name.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_9collation___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->collation);
  __pyx_r = __pyx_v_self->collation;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 5, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.collation.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":6
 *     cdef public int id
 *     cdef public str name, collation
 *     cdef public bint is_default             # <<<<<<<<<<<<<<
 * 
 * cdef class Charsets(object):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_default); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.is_default.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 6, __pyx_L1_error)
  __pyx_v_self->is_default = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.is_default.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_7Charset_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_7Charset_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_2__reduce_cython__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2__reduce_cython__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  int __pyx_v_use_setstate;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v__dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->id); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->is_default); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->collation);
  __Pyx_GIVEREF(__pyx_v_self->collation);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->collation);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_self->name);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":4
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":5
 *     state = (self.collation, self.id, self.is_default, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":6
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":7
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.collation is not None or self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":5
 *     state = (self.collation, self.id, self.is_default, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":9
 *         use_setstate = True
 *     else:
 *         use_setstate = self.collation is not None or self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->collation != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->name != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    __pyx_t_5 = __pyx_t_4;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_5;
  }
  __pyx_L3:;

  /* "(tree fragment)":10
 *     else:
 *         use_setstate = self.collation is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, None), state
 *     else:
 */
  __pyx_t_5 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":11
 *         use_setstate = self.collation is not None or self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_Charset); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_125328330);
    __Pyx_GIVEREF(__pyx_int_125328330);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_125328330);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":10
 *     else:
 *         use_setstate = self.collation is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, None), state
 *     else:
 */
  }

  /* "(tree fragment)":13
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, None), state
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_Charset); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_125328330);
    __Pyx_GIVEREF(__pyx_int_125328330);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_125328330);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cymysql.charset.Charset.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_7Charset_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_7Charset_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4__setstate_cython__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4__setstate_cython__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 15, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7cymysql_7charset___pyx_unpickle_Charset__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":8
 * 
 * class Charsets(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self._by_id = {}
 * 
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_7charset_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets___init__(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_8Charsets___init__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charset.py":9
 * class Charsets(object):
 *     def __init__(self):
 *         self._by_id = {}             # <<<<<<<<<<<<<<
 * 
 *     def add(self, c):
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_by_id);
  __Pyx_DECREF(__pyx_v_self->_by_id);
  __pyx_v_self->_by_id = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/charset.py":8
 * 
 * class Charsets(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self._by_id = {}
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":11
 *         self._by_id = {}
 * 
 *     def add(self, c):             # <<<<<<<<<<<<<<
 *         self._by_id[c.id] = c
 * 
 */

static PyObject *__pyx_f_7cymysql_7charset_8Charsets_add(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("add", 0);

  /* "cymysql/charset.py":12
 * 
 *     def add(self, c):
 *         self._by_id[c.id] = c             # <<<<<<<<<<<<<<
 * 
 *     def by_name(self, name):
 */
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_c->id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyDict_SetItem(__pyx_v_self->_by_id, __pyx_t_1, ((PyObject *)__pyx_v_c)) < 0)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":11
 *         self._by_id = {}
 * 
 *     def add(self, c):             # <<<<<<<<<<<<<<
 *         self._by_id[c.id] = c
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":14
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */

static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_skip_dispatch) {
  struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("by_name", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_by_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_3by_name)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 14, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_name);
          __Pyx_GIVEREF(__pyx_v_name);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_name);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/charset.py":15
 * 
 *     def by_name(self, name):
 *         for c in self._by_id.values():             # <<<<<<<<<<<<<<
 *             if c.name == name and c.is_default:
 *                 return c
 */
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "values");
    __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_self->_by_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 15, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 15, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 15, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cymysql_7charset_Charset))))) __PYX_ERR(0, 15, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_c, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "cymysql/charset.py":16
 *     def by_name(self, name):
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    __pyx_t_9 = (__Pyx_PyString_Equals(__pyx_v_c->name, __pyx_v_name, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 16, __pyx_L1_error)
    if (__pyx_t_9) {
    } else {
      __pyx_t_8 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_9 = (__pyx_v_c->is_default != 0);
    __pyx_t_8 = __pyx_t_9;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_8) {

      /* "cymysql/charset.py":17
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 *                 return c             # <<<<<<<<<<<<<<
 * 
 *     def by_id(self, id):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_c));
      __pyx_r = ((PyObject *)__pyx_v_c);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "cymysql/charset.py":16
 *     def by_name(self, name):
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    }

    /* "cymysql/charset.py":15
 * 
 *     def by_name(self, name):
 *         for c in self._by_id.values():             # <<<<<<<<<<<<<<
 *             if c.name == name and c.is_default:
 *                 return c
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":14
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_8Charsets_3by_name = {"by_name", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_3by_name, METH_O, 0};
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("by_name (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_2by_name(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_2by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("by_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_7charset_8Charsets_by_name(__pyx_v_self, __pyx_v_name, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":19
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */

static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id); /*proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("by_id", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_by_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_5by_id)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_id); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_id};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_id};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 19, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_id);
          __Pyx_GIVEREF(__pyx_v_id);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_id);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/charset.py":20
 * 
 *     def by_id(self, id):
 *         return self._by_id[id]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_by_id, __pyx_v_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/charset.py":19
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_8Charsets_5by_id = {"by_id", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_5by_id, METH_O, 0};
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("by_id (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_4by_id(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v_id));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_4by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("by_id", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_7charset_8Charsets_by_id(__pyx_v_self, __pyx_v_id, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._by_id,)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_8Charsets_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_7__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_6__reduce_cython__(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_6__reduce_cython__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self) {
  int __pyx_v_use_setstate;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v__dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     cdef bint use_setstate
 *     state = (self._by_id,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->_by_id);
  __Pyx_GIVEREF(__pyx_v_self->_by_id);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->_by_id);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":4
 *     cdef bint use_setstate
 *     state = (self._by_id,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":5
 *     state = (self._by_id,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":6
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":7
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._by_id is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":5
 *     state = (self._by_id,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":9
 *         use_setstate = True
 *     else:
 *         use_setstate = self._by_id is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, None), state
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->_by_id != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._by_id is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":11
 *         use_setstate = self._by_id is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_Charsets); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_100352957);
    __Pyx_GIVEREF(__pyx_int_100352957);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_100352957);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._by_id is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, None), state
 *     else:
 */
  }

  /* "(tree fragment)":13
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, None), state
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_Charsets); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_100352957);
    __Pyx_GIVEREF(__pyx_int_100352957);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_100352957);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._by_id,)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charset.Charsets.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_8Charsets_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_9__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_8__setstate_cython__(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_8__setstate_cython__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 15, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7cymysql_7charset___pyx_unpickle_Charsets__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_1__pyx_unpickle_Charset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_1__pyx_unpickle_Charset = {"__pyx_unpickle_Charset", (PyCFunction)__pyx_pw_7cymysql_7charset_1__pyx_unpickle_Charset, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7cymysql_7charset_1__pyx_unpickle_Charset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charset (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charset", 1, 3, 3, 1); __PYX_ERR(2, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charset", 1, 3, 3, 2); __PYX_ERR(2, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_Charset") < 0)) __PYX_ERR(2, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charset", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_7charset___pyx_unpickle_Charset(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset___pyx_unpickle_Charset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = NULL;
  PyObject *__pyx_v___pyx_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charset", 0);

  /* "(tree fragment)":2
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x7785bca:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x7785bca) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":3
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 *     __pyx_result = Charset.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":4
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = Charset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x77, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 4, __pyx_L1_error)

    /* "(tree fragment)":2
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x7785bca:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":5
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 *     __pyx_result = Charset.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v___pyx_type);
      __Pyx_GIVEREF(__pyx_v___pyx_type);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v___pyx_type);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 *     __pyx_result = Charset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":7
 *     __pyx_result = Charset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 7, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_7cymysql_7charset___pyx_unpickle_Charset__set_state(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x7785bca = (collation, id, is_default, name))" % __pyx_checksum)
 *     __pyx_result = Charset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":8
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":9
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_7cymysql_7charset___pyx_unpickle_Charset__set_state(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charset__set_state", 0);

  /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->collation);
  __Pyx_DECREF(__pyx_v___pyx_result->collation);
  __pyx_v___pyx_result->collation = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->id = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->is_default = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyString_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":11
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 11, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(2, 11, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 4) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(2, 11, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":12
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 12, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":11
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  }

  /* "(tree fragment)":9
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charset__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Charsets(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x5fb43bd:
 *         from pickle import PickleError as __pyx_PickleError
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_3__pyx_unpickle_Charsets(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_7cymysql_7charset_3__pyx_unpickle_Charsets = {"__pyx_unpickle_Charsets", (PyCFunction)__pyx_pw_7cymysql_7charset_3__pyx_unpickle_Charsets, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7cymysql_7charset_3__pyx_unpickle_Charsets(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charsets (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charsets", 1, 3, 3, 1); __PYX_ERR(2, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charsets", 1, 3, 3, 2); __PYX_ERR(2, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_Charsets") < 0)) __PYX_ERR(2, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Charsets", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charsets", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_7charset_2__pyx_unpickle_Charsets(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_2__pyx_unpickle_Charsets(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = NULL;
  PyObject *__pyx_v___pyx_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charsets", 0);

  /* "(tree fragment)":2
 * def __pyx_unpickle_Charsets(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x5fb43bd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x5fb43bd) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":3
 * def __pyx_unpickle_Charsets(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x5fb43bd:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 *     __pyx_result = Charsets.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":4
 *     if __pyx_checksum != 0x5fb43bd:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = Charsets.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x5f, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 4, __pyx_L1_error)

    /* "(tree fragment)":2
 * def __pyx_unpickle_Charsets(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x5fb43bd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":5
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 *     __pyx_result = Charsets.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7cymysql_7charset_Charsets), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v___pyx_type);
      __Pyx_GIVEREF(__pyx_v___pyx_type);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v___pyx_type);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 *     __pyx_result = Charsets.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":7
 *     __pyx_result = Charsets.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 7, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_7cymysql_7charset___pyx_unpickle_Charsets__set_state(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x5fb43bd = (_by_id))" % __pyx_checksum)
 *     __pyx_result = Charsets.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":8
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):
 *     __pyx_result._by_id = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Charsets(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x5fb43bd:
 *         from pickle import PickleError as __pyx_PickleError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charsets", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":9
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._by_id = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_7cymysql_7charset___pyx_unpickle_Charsets__set_state(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Charsets__set_state", 0);

  /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):
 *     __pyx_result._by_id = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(2, 10, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_by_id);
  __Pyx_DECREF(__pyx_v___pyx_result->_by_id);
  __pyx_v___pyx_result->_by_id = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":11
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):
 *     __pyx_result._by_id = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 11, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(2, 11, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 1) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(2, 11, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":12
 *     __pyx_result._by_id = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 12, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":11
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):
 *     __pyx_result._by_id = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":9
 *         __pyx_unpickle_Charsets__set_state(<Charsets> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Charsets__set_state(Charsets __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._by_id = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cymysql.charset.__pyx_unpickle_Charsets__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_7cymysql_7charset_Charset(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_7charset_Charset *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_7charset_Charset *)o);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->collation = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_7charset_Charset(PyObject *o) {
  struct __pyx_obj_7cymysql_7charset_Charset *p = (struct __pyx_obj_7cymysql_7charset_Charset *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  Py_CLEAR(p->name);
  Py_CLEAR(p->collation);
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_collation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_collation(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_is_default(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_is_default(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_7cymysql_7charset_Charset[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_7Charset_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_7Charset_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_7cymysql_7charset_Charset[] = {
  {(char *)"id", __pyx_getprop_7cymysql_7charset_7Charset_id, __pyx_setprop_7cymysql_7charset_7Charset_id, (char *)0, 0},
  {(char *)"name", __pyx_getprop_7cymysql_7charset_7Charset_name, __pyx_setprop_7cymysql_7charset_7Charset_name, (char *)0, 0},
  {(char *)"collation", __pyx_getprop_7cymysql_7charset_7Charset_collation, __pyx_setprop_7cymysql_7charset_7Charset_collation, (char *)0, 0},
  {(char *)"is_default", __pyx_getprop_7cymysql_7charset_7Charset_is_default, __pyx_setprop_7cymysql_7charset_7Charset_is_default, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_7charset_Charset = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.charset.Charset", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_7charset_Charset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_7charset_Charset, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_7charset_Charset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_7cymysql_7charset_Charset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_7charset_7Charset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_7charset_Charset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_7cymysql_7charset_Charsets __pyx_vtable_7cymysql_7charset_Charsets;

static PyObject *__pyx_tp_new_7cymysql_7charset_Charsets(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_7charset_Charsets *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_7charset_Charsets *)o);
  p->__pyx_vtab = __pyx_vtabptr_7cymysql_7charset_Charsets;
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_7charset_Charsets(PyObject *o) {
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_by_id);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_7charset_Charsets(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  if (p->_by_id) {
    e = (*v)(p->_by_id, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_7charset_Charsets(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  tmp = ((PyObject*)p->_by_id);
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7cymysql_7charset_Charsets[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_7charset_Charsets = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.charset.Charsets", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_7charset_Charsets), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_7charset_Charsets, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7cymysql_7charset_Charsets, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_7charset_Charsets, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_7charset_Charsets, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_7charset_8Charsets_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_7charset_Charsets, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "charset",
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_Charset___reduce_cython, __pyx_k_Charset___reduce_cython, sizeof(__pyx_k_Charset___reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_Charset___setstate_cython, __pyx_k_Charset___setstate_cython, sizeof(__pyx_k_Charset___setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_Charsets___reduce_cython, __pyx_k_Charsets___reduce_cython, sizeof(__pyx_k_Charsets___reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_Charsets___setstate_cython, __pyx_k_Charsets___setstate_cython, sizeof(__pyx_k_Charsets___setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_Charsets_by_id, __pyx_k_Charsets_by_id, sizeof(__pyx_k_Charsets_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_Charsets_by_name, __pyx_k_Charsets_by_name, sizeof(__pyx_k_Charsets_by_name), 0, 0, 1, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x5f, __pyx_k_Incompatible_checksums_s_vs_0x5f, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x5f), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x77, __pyx_k_Incompatible_checksums_s_vs_0x77, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x77), 0, 0, 1, 0},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_Yes, __pyx_k_Yes, sizeof(__pyx_k_Yes), 0, 0, 1, 1},
  {&__pyx_kp_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 0},
  {&__pyx_n_s_armscii8, __pyx_k_armscii8, sizeof(__pyx_k_armscii8), 0, 0, 1, 1},
  {&__pyx_n_s_armscii8_bin, __pyx_k_armscii8_bin, sizeof(__pyx_k_armscii8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_armscii8_general_ci, __pyx_k_armscii8_general_ci, sizeof(__pyx_k_armscii8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ascii, __pyx_k_ascii, sizeof(__pyx_k_ascii), 0, 0, 1, 1},
  {&__pyx_n_s_ascii_bin, __pyx_k_ascii_bin, sizeof(__pyx_k_ascii_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ascii_general_ci, __pyx_k_ascii_general_ci, sizeof(__pyx_k_ascii_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_big5, __pyx_k_big5, sizeof(__pyx_k_big5), 0, 0, 1, 1},
  {&__pyx_n_s_big5_bin, __pyx_k_big5_bin, sizeof(__pyx_k_big5_bin), 0, 0, 1, 1},
  {&__pyx_n_s_big5_chinese_ci, __pyx_k_big5_chinese_ci, sizeof(__pyx_k_big5_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_binary, __pyx_k_binary, sizeof(__pyx_k_binary), 0, 0, 1, 1},
  {&__pyx_n_s_by_id, __pyx_k_by_id, sizeof(__pyx_k_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_by_name, __pyx_k_by_name, sizeof(__pyx_k_by_name), 0, 0, 1, 1},
  {&__pyx_n_s_charset_by_id, __pyx_k_charset_by_id, sizeof(__pyx_k_charset_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_charset_by_name, __pyx_k_charset_by_name, sizeof(__pyx_k_charset_by_name), 0, 0, 1, 1},
  {&__pyx_n_s_charsets, __pyx_k_charsets, sizeof(__pyx_k_charsets), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_collation, __pyx_k_collation, sizeof(__pyx_k_collation), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250, __pyx_k_cp1250, sizeof(__pyx_k_cp1250), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_bin, __pyx_k_cp1250_bin, sizeof(__pyx_k_cp1250_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_croatian_ci, __pyx_k_cp1250_croatian_ci, sizeof(__pyx_k_cp1250_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_czech_cs, __pyx_k_cp1250_czech_cs, sizeof(__pyx_k_cp1250_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_general_ci, __pyx_k_cp1250_general_ci, sizeof(__pyx_k_cp1250_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_polish_ci, __pyx_k_cp1250_polish_ci, sizeof(__pyx_k_cp1250_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251, __pyx_k_cp1251, sizeof(__pyx_k_cp1251), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_bin, __pyx_k_cp1251_bin, sizeof(__pyx_k_cp1251_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_bulgarian_ci, __pyx_k_cp1251_bulgarian_ci, sizeof(__pyx_k_cp1251_bulgarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_general_ci, __pyx_k_cp1251_general_ci, sizeof(__pyx_k_cp1251_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_general_cs, __pyx_k_cp1251_general_cs, sizeof(__pyx_k_cp1251_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_ukrainian_ci, __pyx_k_cp1251_ukrainian_ci, sizeof(__pyx_k_cp1251_ukrainian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256, __pyx_k_cp1256, sizeof(__pyx_k_cp1256), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256_bin, __pyx_k_cp1256_bin, sizeof(__pyx_k_cp1256_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256_general_ci, __pyx_k_cp1256_general_ci, sizeof(__pyx_k_cp1256_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257, __pyx_k_cp1257, sizeof(__pyx_k_cp1257), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_bin, __pyx_k_cp1257_bin, sizeof(__pyx_k_cp1257_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_general_ci, __pyx_k_cp1257_general_ci, sizeof(__pyx_k_cp1257_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_lithuanian_ci, __pyx_k_cp1257_lithuanian_ci, sizeof(__pyx_k_cp1257_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp850, __pyx_k_cp850, sizeof(__pyx_k_cp850), 0, 0, 1, 1},
  {&__pyx_n_s_cp850_bin, __pyx_k_cp850_bin, sizeof(__pyx_k_cp850_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp850_general_ci, __pyx_k_cp850_general_ci, sizeof(__pyx_k_cp850_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp852, __pyx_k_cp852, sizeof(__pyx_k_cp852), 0, 0, 1, 1},
  {&__pyx_n_s_cp852_bin, __pyx_k_cp852_bin, sizeof(__pyx_k_cp852_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp852_general_ci, __pyx_k_cp852_general_ci, sizeof(__pyx_k_cp852_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp866, __pyx_k_cp866, sizeof(__pyx_k_cp866), 0, 0, 1, 1},
  {&__pyx_n_s_cp866_bin, __pyx_k_cp866_bin, sizeof(__pyx_k_cp866_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp866_general_ci, __pyx_k_cp866_general_ci, sizeof(__pyx_k_cp866_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp932, __pyx_k_cp932, sizeof(__pyx_k_cp932), 0, 0, 1, 1},
  {&__pyx_n_s_cp932_bin, __pyx_k_cp932_bin, sizeof(__pyx_k_cp932_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp932_japanese_ci, __pyx_k_cp932_japanese_ci, sizeof(__pyx_k_cp932_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cymysql_charset, __pyx_k_cymysql_charset, sizeof(__pyx_k_cymysql_charset), 0, 0, 1, 1},
  {&__pyx_kp_s_cymysql_charset_py, __pyx_k_cymysql_charset_py, sizeof(__pyx_k_cymysql_charset_py), 0, 0, 1, 0},
  {&__pyx_n_s_dec8, __pyx_k_dec8, sizeof(__pyx_k_dec8), 0, 0, 1, 1},
  {&__pyx_n_s_dec8_bin, __pyx_k_dec8_bin, sizeof(__pyx_k_dec8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_dec8_swedish_ci, __pyx_k_dec8_swedish_ci, sizeof(__pyx_k_dec8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms, __pyx_k_eucjpms, sizeof(__pyx_k_eucjpms), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms_bin, __pyx_k_eucjpms_bin, sizeof(__pyx_k_eucjpms_bin), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms_japanese_ci, __pyx_k_eucjpms_japanese_ci, sizeof(__pyx_k_eucjpms_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_euckr, __pyx_k_euckr, sizeof(__pyx_k_euckr), 0, 0, 1, 1},
  {&__pyx_n_s_euckr_bin, __pyx_k_euckr_bin, sizeof(__pyx_k_euckr_bin), 0, 0, 1, 1},
  {&__pyx_n_s_euckr_korean_ci, __pyx_k_euckr_korean_ci, sizeof(__pyx_k_euckr_korean_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gb18030, __pyx_k_gb18030, sizeof(__pyx_k_gb18030), 0, 0, 1, 1},
  {&__pyx_n_s_gb18030_bin, __pyx_k_gb18030_bin, sizeof(__pyx_k_gb18030_bin), 0, 0, 1, 1},
  {&__pyx_n_s_gb18030_chinese_ci, __pyx_k_gb18030_chinese_ci, sizeof(__pyx_k_gb18030_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gb18030_unicode_520_ci, __pyx_k_gb18030_unicode_520_ci, sizeof(__pyx_k_gb18030_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312, __pyx_k_gb2312, sizeof(__pyx_k_gb2312), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312_bin, __pyx_k_gb2312_bin, sizeof(__pyx_k_gb2312_bin), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312_chinese_ci, __pyx_k_gb2312_chinese_ci, sizeof(__pyx_k_gb2312_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gbk, __pyx_k_gbk, sizeof(__pyx_k_gbk), 0, 0, 1, 1},
  {&__pyx_n_s_gbk_bin, __pyx_k_gbk_bin, sizeof(__pyx_k_gbk_bin), 0, 0, 1, 1},
  {&__pyx_n_s_gbk_chinese_ci, __pyx_k_gbk_chinese_ci, sizeof(__pyx_k_gbk_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8, __pyx_k_geostd8, sizeof(__pyx_k_geostd8), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8_bin, __pyx_k_geostd8_bin, sizeof(__pyx_k_geostd8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8_general_ci, __pyx_k_geostd8_general_ci, sizeof(__pyx_k_geostd8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_greek, __pyx_k_greek, sizeof(__pyx_k_greek), 0, 0, 1, 1},
  {&__pyx_n_s_greek_bin, __pyx_k_greek_bin, sizeof(__pyx_k_greek_bin), 0, 0, 1, 1},
  {&__pyx_n_s_greek_general_ci, __pyx_k_greek_general_ci, sizeof(__pyx_k_greek_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew, __pyx_k_hebrew, sizeof(__pyx_k_hebrew), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew_bin, __pyx_k_hebrew_bin, sizeof(__pyx_k_hebrew_bin), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew_general_ci, __pyx_k_hebrew_general_ci, sizeof(__pyx_k_hebrew_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_hp8, __pyx_k_hp8, sizeof(__pyx_k_hp8), 0, 0, 1, 1},
  {&__pyx_n_s_hp8_bin, __pyx_k_hp8_bin, sizeof(__pyx_k_hp8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_hp8_english_ci, __pyx_k_hp8_english_ci, sizeof(__pyx_k_hp8_english_ci), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_is_default, __pyx_k_is_default, sizeof(__pyx_k_is_default), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2, __pyx_k_keybcs2, sizeof(__pyx_k_keybcs2), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2_bin, __pyx_k_keybcs2_bin, sizeof(__pyx_k_keybcs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2_general_ci, __pyx_k_keybcs2_general_ci, sizeof(__pyx_k_keybcs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r, __pyx_k_koi8r, sizeof(__pyx_k_koi8r), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r_bin, __pyx_k_koi8r_bin, sizeof(__pyx_k_koi8r_bin), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r_general_ci, __pyx_k_koi8r_general_ci, sizeof(__pyx_k_koi8r_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u, __pyx_k_koi8u, sizeof(__pyx_k_koi8u), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u_bin, __pyx_k_koi8u_bin, sizeof(__pyx_k_koi8u_bin), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u_general_ci, __pyx_k_koi8u_general_ci, sizeof(__pyx_k_koi8u_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1, __pyx_k_latin1, sizeof(__pyx_k_latin1), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_bin, __pyx_k_latin1_bin, sizeof(__pyx_k_latin1_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_danish_ci, __pyx_k_latin1_danish_ci, sizeof(__pyx_k_latin1_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_general_ci, __pyx_k_latin1_general_ci, sizeof(__pyx_k_latin1_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_general_cs, __pyx_k_latin1_general_cs, sizeof(__pyx_k_latin1_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_german1_ci, __pyx_k_latin1_german1_ci, sizeof(__pyx_k_latin1_german1_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_german2_ci, __pyx_k_latin1_german2_ci, sizeof(__pyx_k_latin1_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_spanish_ci, __pyx_k_latin1_spanish_ci, sizeof(__pyx_k_latin1_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_swedish_ci, __pyx_k_latin1_swedish_ci, sizeof(__pyx_k_latin1_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2, __pyx_k_latin2, sizeof(__pyx_k_latin2), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_bin, __pyx_k_latin2_bin, sizeof(__pyx_k_latin2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_croatian_ci, __pyx_k_latin2_croatian_ci, sizeof(__pyx_k_latin2_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_czech_cs, __pyx_k_latin2_czech_cs, sizeof(__pyx_k_latin2_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_general_ci, __pyx_k_latin2_general_ci, sizeof(__pyx_k_latin2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_hungarian_ci, __pyx_k_latin2_hungarian_ci, sizeof(__pyx_k_latin2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin5, __pyx_k_latin5, sizeof(__pyx_k_latin5), 0, 0, 1, 1},
  {&__pyx_n_s_latin5_bin, __pyx_k_latin5_bin, sizeof(__pyx_k_latin5_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin5_turkish_ci, __pyx_k_latin5_turkish_ci, sizeof(__pyx_k_latin5_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin7, __pyx_k_latin7, sizeof(__pyx_k_latin7), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_bin, __pyx_k_latin7_bin, sizeof(__pyx_k_latin7_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_estonian_cs, __pyx_k_latin7_estonian_cs, sizeof(__pyx_k_latin7_estonian_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_general_ci, __pyx_k_latin7_general_ci, sizeof(__pyx_k_latin7_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_general_cs, __pyx_k_latin7_general_cs, sizeof(__pyx_k_latin7_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_macce, __pyx_k_macce, sizeof(__pyx_k_macce), 0, 0, 1, 1},
  {&__pyx_n_s_macce_bin, __pyx_k_macce_bin, sizeof(__pyx_k_macce_bin), 0, 0, 1, 1},
  {&__pyx_n_s_macce_general_ci, __pyx_k_macce_general_ci, sizeof(__pyx_k_macce_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_macroman, __pyx_k_macroman, sizeof(__pyx_k_macroman), 0, 0, 1, 1},
  {&__pyx_n_s_macroman_bin, __pyx_k_macroman_bin, sizeof(__pyx_k_macroman_bin), 0, 0, 1, 1},
  {&__pyx_n_s_macroman_general_ci, __pyx_k_macroman_general_ci, sizeof(__pyx_k_macroman_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_Charset, __pyx_k_pyx_unpickle_Charset, sizeof(__pyx_k_pyx_unpickle_Charset), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_Charsets, __pyx_k_pyx_unpickle_Charsets, sizeof(__pyx_k_pyx_unpickle_Charsets), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_sjis, __pyx_k_sjis, sizeof(__pyx_k_sjis), 0, 0, 1, 1},
  {&__pyx_n_s_sjis_bin, __pyx_k_sjis_bin, sizeof(__pyx_k_sjis_bin), 0, 0, 1, 1},
  {&__pyx_n_s_sjis_japanese_ci, __pyx_k_sjis_japanese_ci, sizeof(__pyx_k_sjis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_swe7, __pyx_k_swe7, sizeof(__pyx_k_swe7), 0, 0, 1, 1},
  {&__pyx_n_s_swe7_bin, __pyx_k_swe7_bin, sizeof(__pyx_k_swe7_bin), 0, 0, 1, 1},
  {&__pyx_n_s_swe7_swedish_ci, __pyx_k_swe7_swedish_ci, sizeof(__pyx_k_swe7_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_tis620, __pyx_k_tis620, sizeof(__pyx_k_tis620), 0, 0, 1, 1},
  {&__pyx_n_s_tis620_bin, __pyx_k_tis620_bin, sizeof(__pyx_k_tis620_bin), 0, 0, 1, 1},
  {&__pyx_n_s_tis620_thai_ci, __pyx_k_tis620_thai_ci, sizeof(__pyx_k_tis620_thai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2, __pyx_k_ucs2, sizeof(__pyx_k_ucs2), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_bin, __pyx_k_ucs2_bin, sizeof(__pyx_k_ucs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_croatian_ci, __pyx_k_ucs2_croatian_ci, sizeof(__pyx_k_ucs2_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_czech_ci, __pyx_k_ucs2_czech_ci, sizeof(__pyx_k_ucs2_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_danish_ci, __pyx_k_ucs2_danish_ci, sizeof(__pyx_k_ucs2_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_esperanto_ci, __pyx_k_ucs2_esperanto_ci, sizeof(__pyx_k_ucs2_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_estonian_ci, __pyx_k_ucs2_estonian_ci, sizeof(__pyx_k_ucs2_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_general_ci, __pyx_k_ucs2_general_ci, sizeof(__pyx_k_ucs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_general_mysql500_ci, __pyx_k_ucs2_general_mysql500_ci, sizeof(__pyx_k_ucs2_general_mysql500_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_german2_ci, __pyx_k_ucs2_german2_ci, sizeof(__pyx_k_ucs2_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_hungarian_ci, __pyx_k_ucs2_hungarian_ci, sizeof(__pyx_k_ucs2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_icelandic_ci, __pyx_k_ucs2_icelandic_ci, sizeof(__pyx_k_ucs2_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_latvian_ci, __pyx_k_ucs2_latvian_ci, sizeof(__pyx_k_ucs2_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_lithuanian_ci, __pyx_k_ucs2_lithuanian_ci, sizeof(__pyx_k_ucs2_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_persian_ci, __pyx_k_ucs2_persian_ci, sizeof(__pyx_k_ucs2_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_polish_ci, __pyx_k_ucs2_polish_ci, sizeof(__pyx_k_ucs2_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_roman_ci, __pyx_k_ucs2_roman_ci, sizeof(__pyx_k_ucs2_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_romanian_ci, __pyx_k_ucs2_romanian_ci, sizeof(__pyx_k_ucs2_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_sinhala_ci, __pyx_k_ucs2_sinhala_ci, sizeof(__pyx_k_ucs2_sinhala_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_slovak_ci, __pyx_k_ucs2_slovak_ci, sizeof(__pyx_k_ucs2_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_slovenian_ci, __pyx_k_ucs2_slovenian_ci, sizeof(__pyx_k_ucs2_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_spanish2_ci, __pyx_k_ucs2_spanish2_ci, sizeof(__pyx_k_ucs2_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_spanish_ci, __pyx_k_ucs2_spanish_ci, sizeof(__pyx_k_ucs2_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_swedish_ci, __pyx_k_ucs2_swedish_ci, sizeof(__pyx_k_ucs2_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_turkish_ci, __pyx_k_ucs2_turkish_ci, sizeof(__pyx_k_ucs2_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_unicode_520_ci, __pyx_k_ucs2_unicode_520_ci, sizeof(__pyx_k_ucs2_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_unicode_ci, __pyx_k_ucs2_unicode_ci, sizeof(__pyx_k_ucs2_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_vietnamese_ci, __pyx_k_ucs2_vietnamese_ci, sizeof(__pyx_k_ucs2_vietnamese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ujis, __pyx_k_ujis, sizeof(__pyx_k_ujis), 0, 0, 1, 1},
  {&__pyx_n_s_ujis_bin, __pyx_k_ujis_bin, sizeof(__pyx_k_ujis_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ujis_japanese_ci, __pyx_k_ujis_japanese_ci, sizeof(__pyx_k_ujis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_utf16, __pyx_k_utf16, sizeof(__pyx_k_utf16), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_bin, __pyx_k_utf16_bin, sizeof(__pyx_k_utf16_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_croatian_ci, __pyx_k_utf16_croatian_ci, sizeof(__pyx_k_utf16_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_czech_ci, __pyx_k_utf16_czech_ci, sizeof(__pyx_k_utf16_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_danish_ci, __pyx_k_utf16_danish_ci, sizeof(__pyx_k_utf16_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_esperanto_ci, __pyx_k_utf16_esperanto_ci, sizeof(__pyx_k_utf16_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_estonian_ci, __pyx_k_utf16_estonian_ci, sizeof(__pyx_k_utf16_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_general_ci, __pyx_k_utf16_general_ci, sizeof(__pyx_k_utf16_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_german2_ci, __pyx_k_utf16_german2_ci, sizeof(__pyx_k_utf16_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_hungarian_ci, __pyx_k_utf16_hungarian_ci, sizeof(__pyx_k_utf16_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_icelandic_ci, __pyx_k_utf16_icelandic_ci, sizeof(__pyx_k_utf16_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_latvian_ci, __pyx_k_utf16_latvian_ci, sizeof(__pyx_k_utf16_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_lithuanian_ci, __pyx_k_utf16_lithuanian_ci, sizeof(__pyx_k_utf16_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_persian_ci, __pyx_k_utf16_persian_ci, sizeof(__pyx_k_utf16_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_polish_ci, __pyx_k_utf16_polish_ci, sizeof(__pyx_k_utf16_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_roman_ci, __pyx_k_utf16_roman_ci, sizeof(__pyx_k_utf16_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_romanian_ci, __pyx_k_utf16_romanian_ci, sizeof(__pyx_k_utf16_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_sinhala_ci, __pyx_k_utf16_sinhala_ci, sizeof(__pyx_k_utf16_sinhala_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_slovak_ci, __pyx_k_utf16_slovak_ci, sizeof(__pyx_k_utf16_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_slovenian_ci, __pyx_k_utf16_slovenian_ci, sizeof(__pyx_k_utf16_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_spanish2_ci, __pyx_k_utf16_spanish2_ci, sizeof(__pyx_k_utf16_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_spanish_ci, __pyx_k_utf16_spanish_ci, sizeof(__pyx_k_utf16_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_swedish_ci, __pyx_k_utf16_swedish_ci, sizeof(__pyx_k_utf16_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_turkish_ci, __pyx_k_utf16_turkish_ci, sizeof(__pyx_k_utf16_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_unicode_520_ci, __pyx_k_utf16_unicode_520_ci, sizeof(__pyx_k_utf16_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_unicode_ci, __pyx_k_utf16_unicode_ci, sizeof(__pyx_k_utf16_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16_vietnamese_ci, __pyx_k_utf16_vietnamese_ci, sizeof(__pyx_k_utf16_vietnamese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf16le, __pyx_k_utf16le, sizeof(__pyx_k_utf16le), 0, 0, 1, 1},
  {&__pyx_n_s_utf16le_bin, __pyx_k_utf16le_bin, sizeof(__pyx_k_utf16le_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf16le_general_ci, __pyx_k_utf16le_general_ci, sizeof(__pyx_k_utf16le_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32, __pyx_k_utf32, sizeof(__pyx_k_utf32), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_bin, __pyx_k_utf32_bin, sizeof(__pyx_k_utf32_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_croatian_ci, __pyx_k_utf32_croatian_ci, sizeof(__pyx_k_utf32_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_czech_ci, __pyx_k_utf32_czech_ci, sizeof(__pyx_k_utf32_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_danish_ci, __pyx_k_utf32_danish_ci, sizeof(__pyx_k_utf32_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_esperanto_ci, __pyx_k_utf32_esperanto_ci, sizeof(__pyx_k_utf32_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_estonian_ci, __pyx_k_utf32_estonian_ci, sizeof(__pyx_k_utf32_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_general_ci, __pyx_k_utf32_general_ci, sizeof(__pyx_k_utf32_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_german2_ci, __pyx_k_utf32_german2_ci, sizeof(__pyx_k_utf32_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_hungarian_ci, __pyx_k_utf32_hungarian_ci, sizeof(__pyx_k_utf32_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_icelandic_ci, __pyx_k_utf32_icelandic_ci, sizeof(__pyx_k_utf32_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_latvian_ci, __pyx_k_utf32_latvian_ci, sizeof(__pyx_k_utf32_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_lithuanian_ci, __pyx_k_utf32_lithuanian_ci, sizeof(__pyx_k_utf32_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_persian_ci, __pyx_k_utf32_persian_ci, sizeof(__pyx_k_utf32_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_polish_ci, __pyx_k_utf32_polish_ci, sizeof(__pyx_k_utf32_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_roman_ci, __pyx_k_utf32_roman_ci, sizeof(__pyx_k_utf32_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_romanian_ci, __pyx_k_utf32_romanian_ci, sizeof(__pyx_k_utf32_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_sinhala_ci, __pyx_k_utf32_sinhala_ci, sizeof(__pyx_k_utf32_sinhala_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_slovak_ci, __pyx_k_utf32_slovak_ci, sizeof(__pyx_k_utf32_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_slovenian_ci, __pyx_k_utf32_slovenian_ci, sizeof(__pyx_k_utf32_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_spanish2_ci, __pyx_k_utf32_spanish2_ci, sizeof(__pyx_k_utf32_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_spanish_ci, __pyx_k_utf32_spanish_ci, sizeof(__pyx_k_utf32_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_swedish_ci, __pyx_k_utf32_swedish_ci, sizeof(__pyx_k_utf32_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_turkish_ci, __pyx_k_utf32_turkish_ci, sizeof(__pyx_k_utf32_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_unicode_520_ci, __pyx_k_utf32_unicode_520_ci, sizeof(__pyx_k_utf32_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_unicode_ci, __pyx_k_utf32_unicode_ci, sizeof(__pyx_k_utf32_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf32_vietnamese_ci, __pyx_k_utf32_vietnamese_ci, sizeof(__pyx_k_utf32_vietnamese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8, __pyx_k_utf8, sizeof(__pyx_k_utf8), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_bin, __pyx_k_utf8_bin, sizeof(__pyx_k_utf8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_croatian_ci, __pyx_k_utf8_croatian_ci, sizeof(__pyx_k_utf8_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_czech_ci, __pyx_k_utf8_czech_ci, sizeof(__pyx_k_utf8_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_danish_ci, __pyx_k_utf8_danish_ci, sizeof(__pyx_k_utf8_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_esperanto_ci, __pyx_k_utf8_esperanto_ci, sizeof(__pyx_k_utf8_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_estonian_ci, __pyx_k_utf8_estonian_ci, sizeof(__pyx_k_utf8_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_general_ci, __pyx_k_utf8_general_ci, sizeof(__pyx_k_utf8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_general_mysql500_ci, __pyx_k_utf8_general_mysql500_ci, sizeof(__pyx_k_utf8_general_mysql500_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_german2_ci, __pyx_k_utf8_german2_ci, sizeof(__pyx_k_utf8_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_hungarian_ci, __pyx_k_utf8_hungarian_ci, sizeof(__pyx_k_utf8_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_icelandic_ci, __pyx_k_utf8_icelandic_ci, sizeof(__pyx_k_utf8_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_latvian_ci, __pyx_k_utf8_latvian_ci, sizeof(__pyx_k_utf8_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_lithuanian_ci, __pyx_k_utf8_lithuanian_ci, sizeof(__pyx_k_utf8_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_persian_ci, __pyx_k_utf8_persian_ci, sizeof(__pyx_k_utf8_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_polish_ci, __pyx_k_utf8_polish_ci, sizeof(__pyx_k_utf8_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_roman_ci, __pyx_k_utf8_roman_ci, sizeof(__pyx_k_utf8_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_romanian_ci, __pyx_k_utf8_romanian_ci, sizeof(__pyx_k_utf8_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_sinhala_ci, __pyx_k_utf8_sinhala_ci, sizeof(__pyx_k_utf8_sinhala_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_slovak_ci, __pyx_k_utf8_slovak_ci, sizeof(__pyx_k_utf8_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_slovenian_ci, __pyx_k_utf8_slovenian_ci, sizeof(__pyx_k_utf8_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_spanish2_ci, __pyx_k_utf8_spanish2_ci, sizeof(__pyx_k_utf8_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_spanish_ci, __pyx_k_utf8_spanish_ci, sizeof(__pyx_k_utf8_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_swedish_ci, __pyx_k_utf8_swedish_ci, sizeof(__pyx_k_utf8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_tolower_ci, __pyx_k_utf8_tolower_ci, sizeof(__pyx_k_utf8_tolower_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_turkish_ci, __pyx_k_utf8_turkish_ci, sizeof(__pyx_k_utf8_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_unicode_520_ci, __pyx_k_utf8_unicode_520_ci, sizeof(__pyx_k_utf8_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_unicode_ci, __pyx_k_utf8_unicode_ci, sizeof(__pyx_k_utf8_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_vietnamese_ci, __pyx_k_utf8_vietnamese_ci, sizeof(__pyx_k_utf8_vietnamese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4, __pyx_k_utf8mb4, sizeof(__pyx_k_utf8mb4), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_0900_ai_ci, __pyx_k_utf8mb4_0900_ai_ci, sizeof(__pyx_k_utf8mb4_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_0900_as_ci, __pyx_k_utf8mb4_0900_as_ci, sizeof(__pyx_k_utf8mb4_0900_as_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_0900_as_cs, __pyx_k_utf8mb4_0900_as_cs, sizeof(__pyx_k_utf8mb4_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_bin, __pyx_k_utf8mb4_bin, sizeof(__pyx_k_utf8mb4_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_croatian_ci, __pyx_k_utf8mb4_croatian_ci, sizeof(__pyx_k_utf8mb4_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_cs_0900_ai_ci, __pyx_k_utf8mb4_cs_0900_ai_ci, sizeof(__pyx_k_utf8mb4_cs_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_cs_0900_as_cs, __pyx_k_utf8mb4_cs_0900_as_cs, sizeof(__pyx_k_utf8mb4_cs_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_czech_ci, __pyx_k_utf8mb4_czech_ci, sizeof(__pyx_k_utf8mb4_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_da_0900_ai_ci, __pyx_k_utf8mb4_da_0900_ai_ci, sizeof(__pyx_k_utf8mb4_da_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_da_0900_as_cs, __pyx_k_utf8mb4_da_0900_as_cs, sizeof(__pyx_k_utf8mb4_da_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_danish_ci, __pyx_k_utf8mb4_danish_ci, sizeof(__pyx_k_utf8mb4_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_de_pb_0900_ai_ci, __pyx_k_utf8mb4_de_pb_0900_ai_ci, sizeof(__pyx_k_utf8mb4_de_pb_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_de_pb_0900_as_cs, __pyx_k_utf8mb4_de_pb_0900_as_cs, sizeof(__pyx_k_utf8mb4_de_pb_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_eo_0900_ai_ci, __pyx_k_utf8mb4_eo_0900_ai_ci, sizeof(__pyx_k_utf8mb4_eo_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_eo_0900_as_cs, __pyx_k_utf8mb4_eo_0900_as_cs, sizeof(__pyx_k_utf8mb4_eo_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_es_0900_ai_ci, __pyx_k_utf8mb4_es_0900_ai_ci, sizeof(__pyx_k_utf8mb4_es_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_es_0900_as_cs, __pyx_k_utf8mb4_es_0900_as_cs, sizeof(__pyx_k_utf8mb4_es_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_es_trad_0900_ai_ci, __pyx_k_utf8mb4_es_trad_0900_ai_ci, sizeof(__pyx_k_utf8mb4_es_trad_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_es_trad_0900_as_cs, __pyx_k_utf8mb4_es_trad_0900_as_cs, sizeof(__pyx_k_utf8mb4_es_trad_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_esperanto_ci, __pyx_k_utf8mb4_esperanto_ci, sizeof(__pyx_k_utf8mb4_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_estonian_ci, __pyx_k_utf8mb4_estonian_ci, sizeof(__pyx_k_utf8mb4_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_et_0900_ai_ci, __pyx_k_utf8mb4_et_0900_ai_ci, sizeof(__pyx_k_utf8mb4_et_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_et_0900_as_cs, __pyx_k_utf8mb4_et_0900_as_cs, sizeof(__pyx_k_utf8mb4_et_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_general_ci, __pyx_k_utf8mb4_general_ci, sizeof(__pyx_k_utf8mb4_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_german2_ci, __pyx_k_utf8mb4_german2_ci, sizeof(__pyx_k_utf8mb4_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_hr_0900_ai_ci, __pyx_k_utf8mb4_hr_0900_ai_ci, sizeof(__pyx_k_utf8mb4_hr_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_hr_0900_as_cs, __pyx_k_utf8mb4_hr_0900_as_cs, sizeof(__pyx_k_utf8mb4_hr_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_hu_0900_ai_ci, __pyx_k_utf8mb4_hu_0900_ai_ci, sizeof(__pyx_k_utf8mb4_hu_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_hu_0900_as_cs, __pyx_k_utf8mb4_hu_0900_as_cs, sizeof(__pyx_k_utf8mb4_hu_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_hungarian_ci, __pyx_k_utf8mb4_hungarian_ci, sizeof(__pyx_k_utf8mb4_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_icelandic_ci, __pyx_k_utf8mb4_icelandic_ci, sizeof(__pyx_k_utf8mb4_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_is_0900_ai_ci, __pyx_k_utf8mb4_is_0900_ai_ci, sizeof(__pyx_k_utf8mb4_is_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_is_0900_as_cs, __pyx_k_utf8mb4_is_0900_as_cs, sizeof(__pyx_k_utf8mb4_is_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ja_0900_as_cs, __pyx_k_utf8mb4_ja_0900_as_cs, sizeof(__pyx_k_utf8mb4_ja_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ja_0900_as_cs_ks, __pyx_k_utf8mb4_ja_0900_as_cs_ks, sizeof(__pyx_k_utf8mb4_ja_0900_as_cs_ks), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_la_0900_ai_ci, __pyx_k_utf8mb4_la_0900_ai_ci, sizeof(__pyx_k_utf8mb4_la_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_la_0900_as_cs, __pyx_k_utf8mb4_la_0900_as_cs, sizeof(__pyx_k_utf8mb4_la_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_latvian_ci, __pyx_k_utf8mb4_latvian_ci, sizeof(__pyx_k_utf8mb4_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_lithuanian_ci, __pyx_k_utf8mb4_lithuanian_ci, sizeof(__pyx_k_utf8mb4_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_lt_0900_ai_ci, __pyx_k_utf8mb4_lt_0900_ai_ci, sizeof(__pyx_k_utf8mb4_lt_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_lt_0900_as_cs, __pyx_k_utf8mb4_lt_0900_as_cs, sizeof(__pyx_k_utf8mb4_lt_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_lv_0900_ai_ci, __pyx_k_utf8mb4_lv_0900_ai_ci, sizeof(__pyx_k_utf8mb4_lv_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_lv_0900_as_cs, __pyx_k_utf8mb4_lv_0900_as_cs, sizeof(__pyx_k_utf8mb4_lv_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_persian_ci, __pyx_k_utf8mb4_persian_ci, sizeof(__pyx_k_utf8mb4_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_pl_0900_ai_ci, __pyx_k_utf8mb4_pl_0900_ai_ci, sizeof(__pyx_k_utf8mb4_pl_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_pl_0900_as_cs, __pyx_k_utf8mb4_pl_0900_as_cs, sizeof(__pyx_k_utf8mb4_pl_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_polish_ci, __pyx_k_utf8mb4_polish_ci, sizeof(__pyx_k_utf8mb4_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ro_0900_ai_ci, __pyx_k_utf8mb4_ro_0900_ai_ci, sizeof(__pyx_k_utf8mb4_ro_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ro_0900_as_cs, __pyx_k_utf8mb4_ro_0900_as_cs, sizeof(__pyx_k_utf8mb4_ro_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_roman_ci, __pyx_k_utf8mb4_roman_ci, sizeof(__pyx_k_utf8mb4_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_romanian_ci, __pyx_k_utf8mb4_romanian_ci, sizeof(__pyx_k_utf8mb4_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ru_0900_ai_ci, __pyx_k_utf8mb4_ru_0900_ai_ci, sizeof(__pyx_k_utf8mb4_ru_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_ru_0900_as_cs, __pyx_k_utf8mb4_ru_0900_as_cs, sizeof(__pyx_k_utf8mb4_ru_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sinhala_ci, __pyx_k_utf8mb4_sinhala_ci, sizeof(__pyx_k_utf8mb4_sinhala_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sk_0900_ai_ci, __pyx_k_utf8mb4_sk_0900_ai_ci, sizeof(__pyx_k_utf8mb4_sk_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sk_0900_as_cs, __pyx_k_utf8mb4_sk_0900_as_cs, sizeof(__pyx_k_utf8mb4_sk_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sl_0900_ai_ci, __pyx_k_utf8mb4_sl_0900_ai_ci, sizeof(__pyx_k_utf8mb4_sl_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sl_0900_as_cs, __pyx_k_utf8mb4_sl_0900_as_cs, sizeof(__pyx_k_utf8mb4_sl_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_slovak_ci, __pyx_k_utf8mb4_slovak_ci, sizeof(__pyx_k_utf8mb4_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_slovenian_ci, __pyx_k_utf8mb4_slovenian_ci, sizeof(__pyx_k_utf8mb4_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_spanish2_ci, __pyx_k_utf8mb4_spanish2_ci, sizeof(__pyx_k_utf8mb4_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_spanish_ci, __pyx_k_utf8mb4_spanish_ci, sizeof(__pyx_k_utf8mb4_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sv_0900_ai_ci, __pyx_k_utf8mb4_sv_0900_ai_ci, sizeof(__pyx_k_utf8mb4_sv_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_sv_0900_as_cs, __pyx_k_utf8mb4_sv_0900_as_cs, sizeof(__pyx_k_utf8mb4_sv_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_swedish_ci, __pyx_k_utf8mb4_swedish_ci, sizeof(__pyx_k_utf8mb4_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_tr_0900_ai_ci, __pyx_k_utf8mb4_tr_0900_ai_ci, sizeof(__pyx_k_utf8mb4_tr_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_tr_0900_as_cs, __pyx_k_utf8mb4_tr_0900_as_cs, sizeof(__pyx_k_utf8mb4_tr_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_turkish_ci, __pyx_k_utf8mb4_turkish_ci, sizeof(__pyx_k_utf8mb4_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_unicode_520_ci, __pyx_k_utf8mb4_unicode_520_ci, sizeof(__pyx_k_utf8mb4_unicode_520_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_unicode_ci, __pyx_k_utf8mb4_unicode_ci, sizeof(__pyx_k_utf8mb4_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_vi_0900_ai_ci, __pyx_k_utf8mb4_vi_0900_ai_ci, sizeof(__pyx_k_utf8mb4_vi_0900_ai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_vi_0900_as_cs, __pyx_k_utf8mb4_vi_0900_as_cs, sizeof(__pyx_k_utf8mb4_vi_0900_as_cs), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_vietnamese_ci, __pyx_k_utf8mb4_vietnamese_ci, sizeof(__pyx_k_utf8mb4_vietnamese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  return 0;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)
 */
  __pyx_tuple_ = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_use_setstate, __pyx_n_s_state, __pyx_n_s_dict_2); if (unlikely(!__pyx_tuple_)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);
  __pyx_codeobj__2 = (PyObject*)__Pyx_PyCode_New(1, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple_, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__2)) __PYX_ERR(2, 1, __pyx_L1_error)

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)
 */
  __pyx_tuple__3 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);
  __pyx_codeobj__4 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__3, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 14, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__4)) __PYX_ERR(2, 14, __pyx_L1_error)

  /* "cymysql/charset.py":14
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */
  __pyx_tuple__5 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_name); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__5, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cymysql_charset_py, __pyx_n_s_by_name, 14, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 14, __pyx_L1_error)

  /* "cymysql/charset.py":19
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */
  __pyx_tuple__7 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_id); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);
  __pyx_codeobj__8 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__7, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cymysql_charset_py, __pyx_n_s_by_id, 19, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__8)) __PYX_ERR(0, 19, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._by_id,)
 */
  __pyx_tuple__9 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_use_setstate, __pyx_n_s_state, __pyx_n_s_dict_2); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);
  __pyx_codeobj__10 = (PyObject*)__Pyx_PyCode_New(1, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__9, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__10)) __PYX_ERR(2, 1, __pyx_L1_error)

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)
 */
  __pyx_tuple__11 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 14, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(2, 14, __pyx_L1_error)

  /* "cymysql/charset.py":39
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_tuple__13 = PyTuple_Pack(4, __pyx_int_1, __pyx_n_s_big5, __pyx_n_s_big5_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "cymysql/charset.py":40
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_tuple__15 = PyTuple_Pack(4, __pyx_int_2, __pyx_n_s_latin2, __pyx_n_s_latin2_czech_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "cymysql/charset.py":41
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_tuple__16 = PyTuple_Pack(4, __pyx_int_3, __pyx_n_s_dec8, __pyx_n_s_dec8_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "cymysql/charset.py":42
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_tuple__17 = PyTuple_Pack(4, __pyx_int_4, __pyx_n_s_cp850, __pyx_n_s_cp850_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "cymysql/charset.py":43
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_tuple__18 = PyTuple_Pack(4, __pyx_int_5, __pyx_n_s_latin1, __pyx_n_s_latin1_german1_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "cymysql/charset.py":44
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_tuple__19 = PyTuple_Pack(4, __pyx_int_6, __pyx_n_s_hp8, __pyx_n_s_hp8_english_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "cymysql/charset.py":45
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_tuple__20 = PyTuple_Pack(4, __pyx_int_7, __pyx_n_s_koi8r, __pyx_n_s_koi8r_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "cymysql/charset.py":46
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_tuple__21 = PyTuple_Pack(4, __pyx_int_8, __pyx_n_s_latin1, __pyx_n_s_latin1_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "cymysql/charset.py":47
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_tuple__22 = PyTuple_Pack(4, __pyx_int_9, __pyx_n_s_latin2, __pyx_n_s_latin2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "cymysql/charset.py":48
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_tuple__23 = PyTuple_Pack(4, __pyx_int_10, __pyx_n_s_swe7, __pyx_n_s_swe7_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "cymysql/charset.py":49
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_tuple__24 = PyTuple_Pack(4, __pyx_int_11, __pyx_n_s_ascii, __pyx_n_s_ascii_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "cymysql/charset.py":50
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_tuple__25 = PyTuple_Pack(4, __pyx_int_12, __pyx_n_s_ujis, __pyx_n_s_ujis_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "cymysql/charset.py":51
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_tuple__26 = PyTuple_Pack(4, __pyx_int_13, __pyx_n_s_sjis, __pyx_n_s_sjis_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "cymysql/charset.py":52
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_tuple__27 = PyTuple_Pack(4, __pyx_int_14, __pyx_n_s_cp1251, __pyx_n_s_cp1251_bulgarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "cymysql/charset.py":53
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_tuple__28 = PyTuple_Pack(4, __pyx_int_15, __pyx_n_s_latin1, __pyx_n_s_latin1_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "cymysql/charset.py":54
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_tuple__29 = PyTuple_Pack(4, __pyx_int_16, __pyx_n_s_hebrew, __pyx_n_s_hebrew_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "cymysql/charset.py":55
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_tuple__30 = PyTuple_Pack(4, __pyx_int_18, __pyx_n_s_tis620, __pyx_n_s_tis620_thai_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "cymysql/charset.py":56
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_tuple__31 = PyTuple_Pack(4, __pyx_int_19, __pyx_n_s_euckr, __pyx_n_s_euckr_korean_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "cymysql/charset.py":57
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_tuple__32 = PyTuple_Pack(4, __pyx_int_20, __pyx_n_s_latin7, __pyx_n_s_latin7_estonian_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "cymysql/charset.py":58
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_tuple__33 = PyTuple_Pack(4, __pyx_int_21, __pyx_n_s_latin2, __pyx_n_s_latin2_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "cymysql/charset.py":59
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_tuple__34 = PyTuple_Pack(4, __pyx_int_22, __pyx_n_s_koi8u, __pyx_n_s_koi8u_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "cymysql/charset.py":60
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_tuple__35 = PyTuple_Pack(4, __pyx_int_23, __pyx_n_s_cp1251, __pyx_n_s_cp1251_ukrainian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "cymysql/charset.py":61
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_tuple__36 = PyTuple_Pack(4, __pyx_int_24, __pyx_n_s_gb2312, __pyx_n_s_gb2312_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "cymysql/charset.py":62
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_tuple__37 = PyTuple_Pack(4, __pyx_int_25, __pyx_n_s_greek, __pyx_n_s_greek_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "cymysql/charset.py":63
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_tuple__38 = PyTuple_Pack(4, __pyx_int_26, __pyx_n_s_cp1250, __pyx_n_s_cp1250_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "cymysql/charset.py":64
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_tuple__39 = PyTuple_Pack(4, __pyx_int_27, __pyx_n_s_latin2, __pyx_n_s_latin2_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "cymysql/charset.py":65
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_tuple__40 = PyTuple_Pack(4, __pyx_int_28, __pyx_n_s_gbk, __pyx_n_s_gbk_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "cymysql/charset.py":66
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_tuple__41 = PyTuple_Pack(4, __pyx_int_29, __pyx_n_s_cp1257, __pyx_n_s_cp1257_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "cymysql/charset.py":67
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_tuple__42 = PyTuple_Pack(4, __pyx_int_30, __pyx_n_s_latin5, __pyx_n_s_latin5_turkish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "cymysql/charset.py":68
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_tuple__43 = PyTuple_Pack(4, __pyx_int_31, __pyx_n_s_latin1, __pyx_n_s_latin1_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "cymysql/charset.py":69
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_tuple__44 = PyTuple_Pack(4, __pyx_int_32, __pyx_n_s_armscii8, __pyx_n_s_armscii8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "cymysql/charset.py":70
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_tuple__45 = PyTuple_Pack(4, __pyx_int_33, __pyx_n_s_utf8, __pyx_n_s_utf8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "cymysql/charset.py":71
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_tuple__46 = PyTuple_Pack(4, __pyx_int_34, __pyx_n_s_cp1250, __pyx_n_s_cp1250_czech_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "cymysql/charset.py":72
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_tuple__47 = PyTuple_Pack(4, __pyx_int_35, __pyx_n_s_ucs2, __pyx_n_s_ucs2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "cymysql/charset.py":73
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_tuple__48 = PyTuple_Pack(4, __pyx_int_36, __pyx_n_s_cp866, __pyx_n_s_cp866_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "cymysql/charset.py":74
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_tuple__49 = PyTuple_Pack(4, __pyx_int_37, __pyx_n_s_keybcs2, __pyx_n_s_keybcs2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "cymysql/charset.py":75
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_tuple__50 = PyTuple_Pack(4, __pyx_int_38, __pyx_n_s_macce, __pyx_n_s_macce_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "cymysql/charset.py":76
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_tuple__51 = PyTuple_Pack(4, __pyx_int_39, __pyx_n_s_macroman, __pyx_n_s_macroman_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "cymysql/charset.py":77
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_tuple__52 = PyTuple_Pack(4, __pyx_int_40, __pyx_n_s_cp852, __pyx_n_s_cp852_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "cymysql/charset.py":78
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_tuple__53 = PyTuple_Pack(4, __pyx_int_41, __pyx_n_s_latin7, __pyx_n_s_latin7_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "cymysql/charset.py":79
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_tuple__54 = PyTuple_Pack(4, __pyx_int_42, __pyx_n_s_latin7, __pyx_n_s_latin7_general_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "cymysql/charset.py":80
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 */
  __pyx_tuple__55 = PyTuple_Pack(4, __pyx_int_43, __pyx_n_s_macce, __pyx_n_s_macce_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "cymysql/charset.py":81
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 */
  __pyx_tuple__56 = PyTuple_Pack(4, __pyx_int_44, __pyx_n_s_cp1250, __pyx_n_s_cp1250_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "cymysql/charset.py":82
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_tuple__57 = PyTuple_Pack(4, __pyx_int_45, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_general_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "cymysql/charset.py":83
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_tuple__58 = PyTuple_Pack(4, __pyx_int_46, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "cymysql/charset.py":84
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_tuple__59 = PyTuple_Pack(4, __pyx_int_47, __pyx_n_s_latin1, __pyx_n_s_latin1_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "cymysql/charset.py":85
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_tuple__60 = PyTuple_Pack(4, __pyx_int_48, __pyx_n_s_latin1, __pyx_n_s_latin1_general_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "cymysql/charset.py":86
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_tuple__61 = PyTuple_Pack(4, __pyx_int_49, __pyx_n_s_latin1, __pyx_n_s_latin1_general_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "cymysql/charset.py":87
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_tuple__62 = PyTuple_Pack(4, __pyx_int_50, __pyx_n_s_cp1251, __pyx_n_s_cp1251_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "cymysql/charset.py":88
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_tuple__63 = PyTuple_Pack(4, __pyx_int_51, __pyx_n_s_cp1251, __pyx_n_s_cp1251_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "cymysql/charset.py":89
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 */
  __pyx_tuple__64 = PyTuple_Pack(4, __pyx_int_52, __pyx_n_s_cp1251, __pyx_n_s_cp1251_general_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "cymysql/charset.py":90
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 */
  __pyx_tuple__65 = PyTuple_Pack(4, __pyx_int_53, __pyx_n_s_macroman, __pyx_n_s_macroman_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "cymysql/charset.py":91
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 */
  __pyx_tuple__66 = PyTuple_Pack(4, __pyx_int_54, __pyx_n_s_utf16, __pyx_n_s_utf16_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "cymysql/charset.py":92
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_tuple__67 = PyTuple_Pack(4, __pyx_int_55, __pyx_n_s_utf16, __pyx_n_s_utf16_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "cymysql/charset.py":93
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_tuple__68 = PyTuple_Pack(4, __pyx_int_56, __pyx_n_s_utf16le, __pyx_n_s_utf16le_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "cymysql/charset.py":94
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_tuple__69 = PyTuple_Pack(4, __pyx_int_57, __pyx_n_s_cp1256, __pyx_n_s_cp1256_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "cymysql/charset.py":95
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 */
  __pyx_tuple__70 = PyTuple_Pack(4, __pyx_int_58, __pyx_n_s_cp1257, __pyx_n_s_cp1257_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "cymysql/charset.py":96
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 */
  __pyx_tuple__71 = PyTuple_Pack(4, __pyx_int_59, __pyx_n_s_cp1257, __pyx_n_s_cp1257_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "cymysql/charset.py":97
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 */
  __pyx_tuple__72 = PyTuple_Pack(4, __pyx_int_60, __pyx_n_s_utf32, __pyx_n_s_utf32_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "cymysql/charset.py":98
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_tuple__73 = PyTuple_Pack(4, __pyx_int_61, __pyx_n_s_utf32, __pyx_n_s_utf32_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "cymysql/charset.py":99
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_tuple__74 = PyTuple_Pack(4, __pyx_int_62, __pyx_n_s_utf16le, __pyx_n_s_utf16le_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "cymysql/charset.py":100
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_tuple__75 = PyTuple_Pack(4, __pyx_int_63, __pyx_n_s_binary, __pyx_n_s_binary, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "cymysql/charset.py":101
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_tuple__76 = PyTuple_Pack(4, __pyx_int_64, __pyx_n_s_armscii8, __pyx_n_s_armscii8_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "cymysql/charset.py":102
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_tuple__77 = PyTuple_Pack(4, __pyx_int_65, __pyx_n_s_ascii, __pyx_n_s_ascii_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "cymysql/charset.py":103
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_tuple__78 = PyTuple_Pack(4, __pyx_int_66, __pyx_n_s_cp1250, __pyx_n_s_cp1250_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "cymysql/charset.py":104
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_tuple__79 = PyTuple_Pack(4, __pyx_int_67, __pyx_n_s_cp1256, __pyx_n_s_cp1256_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "cymysql/charset.py":105
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_tuple__80 = PyTuple_Pack(4, __pyx_int_68, __pyx_n_s_cp866, __pyx_n_s_cp866_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "cymysql/charset.py":106
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_tuple__81 = PyTuple_Pack(4, __pyx_int_69, __pyx_n_s_dec8, __pyx_n_s_dec8_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "cymysql/charset.py":107
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_tuple__82 = PyTuple_Pack(4, __pyx_int_70, __pyx_n_s_greek, __pyx_n_s_greek_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "cymysql/charset.py":108
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_tuple__83 = PyTuple_Pack(4, __pyx_int_71, __pyx_n_s_hebrew, __pyx_n_s_hebrew_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "cymysql/charset.py":109
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_tuple__84 = PyTuple_Pack(4, __pyx_int_72, __pyx_n_s_hp8, __pyx_n_s_hp8_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "cymysql/charset.py":110
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_tuple__85 = PyTuple_Pack(4, __pyx_int_73, __pyx_n_s_keybcs2, __pyx_n_s_keybcs2_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "cymysql/charset.py":111
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 */
  __pyx_tuple__86 = PyTuple_Pack(4, __pyx_int_74, __pyx_n_s_koi8r, __pyx_n_s_koi8r_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "cymysql/charset.py":112
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_tuple__87 = PyTuple_Pack(4, __pyx_int_75, __pyx_n_s_koi8u, __pyx_n_s_koi8u_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "cymysql/charset.py":113
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_tuple__88 = PyTuple_Pack(4, __pyx_int_76, __pyx_n_s_utf8, __pyx_n_s_utf8_tolower_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);

  /* "cymysql/charset.py":114
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_tuple__89 = PyTuple_Pack(4, __pyx_int_77, __pyx_n_s_latin2, __pyx_n_s_latin2_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "cymysql/charset.py":115
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_tuple__90 = PyTuple_Pack(4, __pyx_int_78, __pyx_n_s_latin5, __pyx_n_s_latin5_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);

  /* "cymysql/charset.py":116
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_tuple__91 = PyTuple_Pack(4, __pyx_int_79, __pyx_n_s_latin7, __pyx_n_s_latin7_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "cymysql/charset.py":117
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_tuple__92 = PyTuple_Pack(4, __pyx_int_80, __pyx_n_s_cp850, __pyx_n_s_cp850_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "cymysql/charset.py":118
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_tuple__93 = PyTuple_Pack(4, __pyx_int_81, __pyx_n_s_cp852, __pyx_n_s_cp852_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "cymysql/charset.py":119
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_tuple__94 = PyTuple_Pack(4, __pyx_int_82, __pyx_n_s_swe7, __pyx_n_s_swe7_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "cymysql/charset.py":120
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_tuple__95 = PyTuple_Pack(4, __pyx_int_83, __pyx_n_s_utf8, __pyx_n_s_utf8_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "cymysql/charset.py":121
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_tuple__96 = PyTuple_Pack(4, __pyx_int_84, __pyx_n_s_big5, __pyx_n_s_big5_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__96)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);

  /* "cymysql/charset.py":122
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_tuple__97 = PyTuple_Pack(4, __pyx_int_85, __pyx_n_s_euckr, __pyx_n_s_euckr_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);

  /* "cymysql/charset.py":123
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_tuple__98 = PyTuple_Pack(4, __pyx_int_86, __pyx_n_s_gb2312, __pyx_n_s_gb2312_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "cymysql/charset.py":124
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_tuple__99 = PyTuple_Pack(4, __pyx_int_87, __pyx_n_s_gbk, __pyx_n_s_gbk_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "cymysql/charset.py":125
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_tuple__100 = PyTuple_Pack(4, __pyx_int_88, __pyx_n_s_sjis, __pyx_n_s_sjis_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "cymysql/charset.py":126
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_tuple__101 = PyTuple_Pack(4, __pyx_int_89, __pyx_n_s_tis620, __pyx_n_s_tis620_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "cymysql/charset.py":127
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_tuple__102 = PyTuple_Pack(4, __pyx_int_90, __pyx_n_s_ucs2, __pyx_n_s_ucs2_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "cymysql/charset.py":128
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_tuple__103 = PyTuple_Pack(4, __pyx_int_91, __pyx_n_s_ujis, __pyx_n_s_ujis_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "cymysql/charset.py":129
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_tuple__104 = PyTuple_Pack(4, __pyx_int_92, __pyx_n_s_geostd8, __pyx_n_s_geostd8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "cymysql/charset.py":130
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_tuple__105 = PyTuple_Pack(4, __pyx_int_93, __pyx_n_s_geostd8, __pyx_n_s_geostd8_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "cymysql/charset.py":131
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_tuple__106 = PyTuple_Pack(4, __pyx_int_94, __pyx_n_s_latin1, __pyx_n_s_latin1_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "cymysql/charset.py":132
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_tuple__107 = PyTuple_Pack(4, __pyx_int_95, __pyx_n_s_cp932, __pyx_n_s_cp932_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "cymysql/charset.py":133
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_tuple__108 = PyTuple_Pack(4, __pyx_int_96, __pyx_n_s_cp932, __pyx_n_s_cp932_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "cymysql/charset.py":134
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_tuple__109 = PyTuple_Pack(4, __pyx_int_97, __pyx_n_s_eucjpms, __pyx_n_s_eucjpms_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "cymysql/charset.py":135
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 */
  __pyx_tuple__110 = PyTuple_Pack(4, __pyx_int_98, __pyx_n_s_eucjpms, __pyx_n_s_eucjpms_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "cymysql/charset.py":136
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 */
  __pyx_tuple__111 = PyTuple_Pack(4, __pyx_int_99, __pyx_n_s_cp1250, __pyx_n_s_cp1250_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "cymysql/charset.py":137
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 */
  __pyx_tuple__112 = PyTuple_Pack(4, __pyx_int_101, __pyx_n_s_utf16, __pyx_n_s_utf16_unicode_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "cymysql/charset.py":138
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 */
  __pyx_tuple__113 = PyTuple_Pack(4, __pyx_int_102, __pyx_n_s_utf16, __pyx_n_s_utf16_icelandic_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);

  /* "cymysql/charset.py":139
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 */
  __pyx_tuple__114 = PyTuple_Pack(4, __pyx_int_103, __pyx_n_s_utf16, __pyx_n_s_utf16_latvian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "cymysql/charset.py":140
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 */
  __pyx_tuple__115 = PyTuple_Pack(4, __pyx_int_104, __pyx_n_s_utf16, __pyx_n_s_utf16_romanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);

  /* "cymysql/charset.py":141
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 */
  __pyx_tuple__116 = PyTuple_Pack(4, __pyx_int_105, __pyx_n_s_utf16, __pyx_n_s_utf16_slovenian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "cymysql/charset.py":142
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 */
  __pyx_tuple__117 = PyTuple_Pack(4, __pyx_int_106, __pyx_n_s_utf16, __pyx_n_s_utf16_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "cymysql/charset.py":143
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 */
  __pyx_tuple__118 = PyTuple_Pack(4, __pyx_int_107, __pyx_n_s_utf16, __pyx_n_s_utf16_estonian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "cymysql/charset.py":144
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 */
  __pyx_tuple__119 = PyTuple_Pack(4, __pyx_int_108, __pyx_n_s_utf16, __pyx_n_s_utf16_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "cymysql/charset.py":145
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 */
  __pyx_tuple__120 = PyTuple_Pack(4, __pyx_int_109, __pyx_n_s_utf16, __pyx_n_s_utf16_swedish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "cymysql/charset.py":146
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 */
  __pyx_tuple__121 = PyTuple_Pack(4, __pyx_int_110, __pyx_n_s_utf16, __pyx_n_s_utf16_turkish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "cymysql/charset.py":147
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 */
  __pyx_tuple__122 = PyTuple_Pack(4, __pyx_int_111, __pyx_n_s_utf16, __pyx_n_s_utf16_czech_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "cymysql/charset.py":148
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 */
  __pyx_tuple__123 = PyTuple_Pack(4, __pyx_int_112, __pyx_n_s_utf16, __pyx_n_s_utf16_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "cymysql/charset.py":149
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 */
  __pyx_tuple__124 = PyTuple_Pack(4, __pyx_int_113, __pyx_n_s_utf16, __pyx_n_s_utf16_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__124)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "cymysql/charset.py":150
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 */
  __pyx_tuple__125 = PyTuple_Pack(4, __pyx_int_114, __pyx_n_s_utf16, __pyx_n_s_utf16_slovak_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);

  /* "cymysql/charset.py":151
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 */
  __pyx_tuple__126 = PyTuple_Pack(4, __pyx_int_115, __pyx_n_s_utf16, __pyx_n_s_utf16_spanish2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);

  /* "cymysql/charset.py":152
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 */
  __pyx_tuple__127 = PyTuple_Pack(4, __pyx_int_116, __pyx_n_s_utf16, __pyx_n_s_utf16_roman_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "cymysql/charset.py":153
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 */
  __pyx_tuple__128 = PyTuple_Pack(4, __pyx_int_117, __pyx_n_s_utf16, __pyx_n_s_utf16_persian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__128)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);

  /* "cymysql/charset.py":154
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 */
  __pyx_tuple__129 = PyTuple_Pack(4, __pyx_int_118, __pyx_n_s_utf16, __pyx_n_s_utf16_esperanto_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);

  /* "cymysql/charset.py":155
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 */
  __pyx_tuple__130 = PyTuple_Pack(4, __pyx_int_119, __pyx_n_s_utf16, __pyx_n_s_utf16_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);

  /* "cymysql/charset.py":156
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 */
  __pyx_tuple__131 = PyTuple_Pack(4, __pyx_int_120, __pyx_n_s_utf16, __pyx_n_s_utf16_sinhala_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);

  /* "cymysql/charset.py":157
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 */
  __pyx_tuple__132 = PyTuple_Pack(4, __pyx_int_121, __pyx_n_s_utf16, __pyx_n_s_utf16_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);

  /* "cymysql/charset.py":158
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 */
  __pyx_tuple__133 = PyTuple_Pack(4, __pyx_int_122, __pyx_n_s_utf16, __pyx_n_s_utf16_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);

  /* "cymysql/charset.py":159
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_tuple__134 = PyTuple_Pack(4, __pyx_int_123, __pyx_n_s_utf16, __pyx_n_s_utf16_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);

  /* "cymysql/charset.py":160
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_tuple__135 = PyTuple_Pack(4, __pyx_int_124, __pyx_n_s_utf16, __pyx_n_s_utf16_vietnamese_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "cymysql/charset.py":161
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_tuple__136 = PyTuple_Pack(4, __pyx_int_128, __pyx_n_s_ucs2, __pyx_n_s_ucs2_unicode_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__136)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__136);
  __Pyx_GIVEREF(__pyx_tuple__136);

  /* "cymysql/charset.py":162
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_tuple__137 = PyTuple_Pack(4, __pyx_int_129, __pyx_n_s_ucs2, __pyx_n_s_ucs2_icelandic_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);

  /* "cymysql/charset.py":163
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_tuple__138 = PyTuple_Pack(4, __pyx_int_130, __pyx_n_s_ucs2, __pyx_n_s_ucs2_latvian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);

  /* "cymysql/charset.py":164
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_tuple__139 = PyTuple_Pack(4, __pyx_int_131, __pyx_n_s_ucs2, __pyx_n_s_ucs2_romanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);

  /* "cymysql/charset.py":165
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_tuple__140 = PyTuple_Pack(4, __pyx_int_132, __pyx_n_s_ucs2, __pyx_n_s_ucs2_slovenian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);

  /* "cymysql/charset.py":166
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_tuple__141 = PyTuple_Pack(4, __pyx_int_133, __pyx_n_s_ucs2, __pyx_n_s_ucs2_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);

  /* "cymysql/charset.py":167
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_tuple__142 = PyTuple_Pack(4, __pyx_int_134, __pyx_n_s_ucs2, __pyx_n_s_ucs2_estonian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);

  /* "cymysql/charset.py":168
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_tuple__143 = PyTuple_Pack(4, __pyx_int_135, __pyx_n_s_ucs2, __pyx_n_s_ucs2_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__143)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__143);
  __Pyx_GIVEREF(__pyx_tuple__143);

  /* "cymysql/charset.py":169
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_tuple__144 = PyTuple_Pack(4, __pyx_int_136, __pyx_n_s_ucs2, __pyx_n_s_ucs2_swedish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);

  /* "cymysql/charset.py":170
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_tuple__145 = PyTuple_Pack(4, __pyx_int_137, __pyx_n_s_ucs2, __pyx_n_s_ucs2_turkish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);

  /* "cymysql/charset.py":171
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_tuple__146 = PyTuple_Pack(4, __pyx_int_138, __pyx_n_s_ucs2, __pyx_n_s_ucs2_czech_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__146)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__146);
  __Pyx_GIVEREF(__pyx_tuple__146);

  /* "cymysql/charset.py":172
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_tuple__147 = PyTuple_Pack(4, __pyx_int_139, __pyx_n_s_ucs2, __pyx_n_s_ucs2_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);

  /* "cymysql/charset.py":173
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_tuple__148 = PyTuple_Pack(4, __pyx_int_140, __pyx_n_s_ucs2, __pyx_n_s_ucs2_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__148)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__148);
  __Pyx_GIVEREF(__pyx_tuple__148);

  /* "cymysql/charset.py":174
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_tuple__149 = PyTuple_Pack(4, __pyx_int_141, __pyx_n_s_ucs2, __pyx_n_s_ucs2_slovak_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);

  /* "cymysql/charset.py":175
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_tuple__150 = PyTuple_Pack(4, __pyx_int_142, __pyx_n_s_ucs2, __pyx_n_s_ucs2_spanish2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);

  /* "cymysql/charset.py":176
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_tuple__151 = PyTuple_Pack(4, __pyx_int_143, __pyx_n_s_ucs2, __pyx_n_s_ucs2_roman_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "cymysql/charset.py":177
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_tuple__152 = PyTuple_Pack(4, __pyx_int_144, __pyx_n_s_ucs2, __pyx_n_s_ucs2_persian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__152)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__152);
  __Pyx_GIVEREF(__pyx_tuple__152);

  /* "cymysql/charset.py":178
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 */
  __pyx_tuple__153 = PyTuple_Pack(4, __pyx_int_145, __pyx_n_s_ucs2, __pyx_n_s_ucs2_esperanto_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);

  /* "cymysql/charset.py":179
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 */
  __pyx_tuple__154 = PyTuple_Pack(4, __pyx_int_146, __pyx_n_s_ucs2, __pyx_n_s_ucs2_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__154)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__154);
  __Pyx_GIVEREF(__pyx_tuple__154);

  /* "cymysql/charset.py":180
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 */
  __pyx_tuple__155 = PyTuple_Pack(4, __pyx_int_147, __pyx_n_s_ucs2, __pyx_n_s_ucs2_sinhala_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);

  /* "cymysql/charset.py":181
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 */
  __pyx_tuple__156 = PyTuple_Pack(4, __pyx_int_148, __pyx_n_s_ucs2, __pyx_n_s_ucs2_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);

  /* "cymysql/charset.py":182
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 */
  __pyx_tuple__157 = PyTuple_Pack(4, __pyx_int_149, __pyx_n_s_ucs2, __pyx_n_s_ucs2_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);

  /* "cymysql/charset.py":183
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 */
  __pyx_tuple__158 = PyTuple_Pack(4, __pyx_int_150, __pyx_n_s_ucs2, __pyx_n_s_ucs2_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "cymysql/charset.py":184
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 */
  __pyx_tuple__159 = PyTuple_Pack(4, __pyx_int_151, __pyx_n_s_ucs2, __pyx_n_s_ucs2_vietnamese_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);

  /* "cymysql/charset.py":185
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 */
  __pyx_tuple__160 = PyTuple_Pack(4, __pyx_int_159, __pyx_n_s_ucs2, __pyx_n_s_ucs2_general_mysql500_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__160)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__160);
  __Pyx_GIVEREF(__pyx_tuple__160);

  /* "cymysql/charset.py":186
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 */
  __pyx_tuple__161 = PyTuple_Pack(4, __pyx_int_160, __pyx_n_s_utf32, __pyx_n_s_utf32_unicode_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);

  /* "cymysql/charset.py":187
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 */
  __pyx_tuple__162 = PyTuple_Pack(4, __pyx_int_161, __pyx_n_s_utf32, __pyx_n_s_utf32_icelandic_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);

  /* "cymysql/charset.py":188
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 */
  __pyx_tuple__163 = PyTuple_Pack(4, __pyx_int_162, __pyx_n_s_utf32, __pyx_n_s_utf32_latvian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__163)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__163);
  __Pyx_GIVEREF(__pyx_tuple__163);

  /* "cymysql/charset.py":189
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 */
  __pyx_tuple__164 = PyTuple_Pack(4, __pyx_int_163, __pyx_n_s_utf32, __pyx_n_s_utf32_romanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__164)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__164);
  __Pyx_GIVEREF(__pyx_tuple__164);

  /* "cymysql/charset.py":190
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 */
  __pyx_tuple__165 = PyTuple_Pack(4, __pyx_int_164, __pyx_n_s_utf32, __pyx_n_s_utf32_slovenian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);

  /* "cymysql/charset.py":191
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 */
  __pyx_tuple__166 = PyTuple_Pack(4, __pyx_int_165, __pyx_n_s_utf32, __pyx_n_s_utf32_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__166)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__166);
  __Pyx_GIVEREF(__pyx_tuple__166);

  /* "cymysql/charset.py":192
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 */
  __pyx_tuple__167 = PyTuple_Pack(4, __pyx_int_166, __pyx_n_s_utf32, __pyx_n_s_utf32_estonian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);

  /* "cymysql/charset.py":193
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 */
  __pyx_tuple__168 = PyTuple_Pack(4, __pyx_int_167, __pyx_n_s_utf32, __pyx_n_s_utf32_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);

  /* "cymysql/charset.py":194
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 */
  __pyx_tuple__169 = PyTuple_Pack(4, __pyx_int_168, __pyx_n_s_utf32, __pyx_n_s_utf32_swedish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);

  /* "cymysql/charset.py":195
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 */
  __pyx_tuple__170 = PyTuple_Pack(4, __pyx_int_169, __pyx_n_s_utf32, __pyx_n_s_utf32_turkish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__170)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__170);
  __Pyx_GIVEREF(__pyx_tuple__170);

  /* "cymysql/charset.py":196
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 */
  __pyx_tuple__171 = PyTuple_Pack(4, __pyx_int_170, __pyx_n_s_utf32, __pyx_n_s_utf32_czech_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "cymysql/charset.py":197
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 */
  __pyx_tuple__172 = PyTuple_Pack(4, __pyx_int_171, __pyx_n_s_utf32, __pyx_n_s_utf32_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);

  /* "cymysql/charset.py":198
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 */
  __pyx_tuple__173 = PyTuple_Pack(4, __pyx_int_172, __pyx_n_s_utf32, __pyx_n_s_utf32_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);

  /* "cymysql/charset.py":199
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 */
  __pyx_tuple__174 = PyTuple_Pack(4, __pyx_int_173, __pyx_n_s_utf32, __pyx_n_s_utf32_slovak_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);

  /* "cymysql/charset.py":200
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 */
  __pyx_tuple__175 = PyTuple_Pack(4, __pyx_int_174, __pyx_n_s_utf32, __pyx_n_s_utf32_spanish2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);

  /* "cymysql/charset.py":201
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 */
  __pyx_tuple__176 = PyTuple_Pack(4, __pyx_int_175, __pyx_n_s_utf32, __pyx_n_s_utf32_roman_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__176)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__176);
  __Pyx_GIVEREF(__pyx_tuple__176);

  /* "cymysql/charset.py":202
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 */
  __pyx_tuple__177 = PyTuple_Pack(4, __pyx_int_176, __pyx_n_s_utf32, __pyx_n_s_utf32_persian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "cymysql/charset.py":203
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 */
  __pyx_tuple__178 = PyTuple_Pack(4, __pyx_int_177, __pyx_n_s_utf32, __pyx_n_s_utf32_esperanto_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);

  /* "cymysql/charset.py":204
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 */
  __pyx_tuple__179 = PyTuple_Pack(4, __pyx_int_178, __pyx_n_s_utf32, __pyx_n_s_utf32_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);

  /* "cymysql/charset.py":205
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 */
  __pyx_tuple__180 = PyTuple_Pack(4, __pyx_int_179, __pyx_n_s_utf32, __pyx_n_s_utf32_sinhala_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "cymysql/charset.py":206
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 */
  __pyx_tuple__181 = PyTuple_Pack(4, __pyx_int_180, __pyx_n_s_utf32, __pyx_n_s_utf32_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);

  /* "cymysql/charset.py":207
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 */
  __pyx_tuple__182 = PyTuple_Pack(4, __pyx_int_181, __pyx_n_s_utf32, __pyx_n_s_utf32_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__182)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__182);
  __Pyx_GIVEREF(__pyx_tuple__182);

  /* "cymysql/charset.py":208
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_tuple__183 = PyTuple_Pack(4, __pyx_int_182, __pyx_n_s_utf32, __pyx_n_s_utf32_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "cymysql/charset.py":209
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_tuple__184 = PyTuple_Pack(4, __pyx_int_183, __pyx_n_s_utf32, __pyx_n_s_utf32_vietnamese_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "cymysql/charset.py":210
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_tuple__185 = PyTuple_Pack(4, __pyx_int_192, __pyx_n_s_utf8, __pyx_n_s_utf8_unicode_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);

  /* "cymysql/charset.py":211
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_tuple__186 = PyTuple_Pack(4, __pyx_int_193, __pyx_n_s_utf8, __pyx_n_s_utf8_icelandic_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__186)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__186);
  __Pyx_GIVEREF(__pyx_tuple__186);

  /* "cymysql/charset.py":212
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_tuple__187 = PyTuple_Pack(4, __pyx_int_194, __pyx_n_s_utf8, __pyx_n_s_utf8_latvian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "cymysql/charset.py":213
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_tuple__188 = PyTuple_Pack(4, __pyx_int_195, __pyx_n_s_utf8, __pyx_n_s_utf8_romanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);

  /* "cymysql/charset.py":214
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_tuple__189 = PyTuple_Pack(4, __pyx_int_196, __pyx_n_s_utf8, __pyx_n_s_utf8_slovenian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);

  /* "cymysql/charset.py":215
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_tuple__190 = PyTuple_Pack(4, __pyx_int_197, __pyx_n_s_utf8, __pyx_n_s_utf8_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);

  /* "cymysql/charset.py":216
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_tuple__191 = PyTuple_Pack(4, __pyx_int_198, __pyx_n_s_utf8, __pyx_n_s_utf8_estonian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__191)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__191);
  __Pyx_GIVEREF(__pyx_tuple__191);

  /* "cymysql/charset.py":217
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_tuple__192 = PyTuple_Pack(4, __pyx_int_199, __pyx_n_s_utf8, __pyx_n_s_utf8_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);

  /* "cymysql/charset.py":218
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_tuple__193 = PyTuple_Pack(4, __pyx_int_200, __pyx_n_s_utf8, __pyx_n_s_utf8_swedish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);

  /* "cymysql/charset.py":219
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_tuple__194 = PyTuple_Pack(4, __pyx_int_201, __pyx_n_s_utf8, __pyx_n_s_utf8_turkish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);

  /* "cymysql/charset.py":220
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_tuple__195 = PyTuple_Pack(4, __pyx_int_202, __pyx_n_s_utf8, __pyx_n_s_utf8_czech_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);

  /* "cymysql/charset.py":221
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_tuple__196 = PyTuple_Pack(4, __pyx_int_203, __pyx_n_s_utf8, __pyx_n_s_utf8_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__196)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__196);
  __Pyx_GIVEREF(__pyx_tuple__196);

  /* "cymysql/charset.py":222
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_tuple__197 = PyTuple_Pack(4, __pyx_int_204, __pyx_n_s_utf8, __pyx_n_s_utf8_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);

  /* "cymysql/charset.py":223
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_tuple__198 = PyTuple_Pack(4, __pyx_int_205, __pyx_n_s_utf8, __pyx_n_s_utf8_slovak_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "cymysql/charset.py":224
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_tuple__199 = PyTuple_Pack(4, __pyx_int_206, __pyx_n_s_utf8, __pyx_n_s_utf8_spanish2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);

  /* "cymysql/charset.py":225
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_tuple__200 = PyTuple_Pack(4, __pyx_int_207, __pyx_n_s_utf8, __pyx_n_s_utf8_roman_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__200)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__200);
  __Pyx_GIVEREF(__pyx_tuple__200);

  /* "cymysql/charset.py":226
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_tuple__201 = PyTuple_Pack(4, __pyx_int_208, __pyx_n_s_utf8, __pyx_n_s_utf8_persian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);

  /* "cymysql/charset.py":227
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 */
  __pyx_tuple__202 = PyTuple_Pack(4, __pyx_int_209, __pyx_n_s_utf8, __pyx_n_s_utf8_esperanto_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);

  /* "cymysql/charset.py":228
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 */
  __pyx_tuple__203 = PyTuple_Pack(4, __pyx_int_210, __pyx_n_s_utf8, __pyx_n_s_utf8_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);

  /* "cymysql/charset.py":229
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 */
  __pyx_tuple__204 = PyTuple_Pack(4, __pyx_int_211, __pyx_n_s_utf8, __pyx_n_s_utf8_sinhala_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__204)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__204);
  __Pyx_GIVEREF(__pyx_tuple__204);

  /* "cymysql/charset.py":230
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 */
  __pyx_tuple__205 = PyTuple_Pack(4, __pyx_int_212, __pyx_n_s_utf8, __pyx_n_s_utf8_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__205)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__205);
  __Pyx_GIVEREF(__pyx_tuple__205);

  /* "cymysql/charset.py":231
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 */
  __pyx_tuple__206 = PyTuple_Pack(4, __pyx_int_213, __pyx_n_s_utf8, __pyx_n_s_utf8_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);

  /* "cymysql/charset.py":232
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 */
  __pyx_tuple__207 = PyTuple_Pack(4, __pyx_int_214, __pyx_n_s_utf8, __pyx_n_s_utf8_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);

  /* "cymysql/charset.py":233
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 */
  __pyx_tuple__208 = PyTuple_Pack(4, __pyx_int_215, __pyx_n_s_utf8, __pyx_n_s_utf8_vietnamese_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);

  /* "cymysql/charset.py":234
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 */
  __pyx_tuple__209 = PyTuple_Pack(4, __pyx_int_223, __pyx_n_s_utf8, __pyx_n_s_utf8_general_mysql500_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);

  /* "cymysql/charset.py":235
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 */
  __pyx_tuple__210 = PyTuple_Pack(4, __pyx_int_224, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_unicode_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__210)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__210);
  __Pyx_GIVEREF(__pyx_tuple__210);

  /* "cymysql/charset.py":236
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 */
  __pyx_tuple__211 = PyTuple_Pack(4, __pyx_int_225, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_icelandic_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);

  /* "cymysql/charset.py":237
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 */
  __pyx_tuple__212 = PyTuple_Pack(4, __pyx_int_226, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_latvian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__212)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__212);
  __Pyx_GIVEREF(__pyx_tuple__212);

  /* "cymysql/charset.py":238
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 */
  __pyx_tuple__213 = PyTuple_Pack(4, __pyx_int_227, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_romanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);

  /* "cymysql/charset.py":239
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 */
  __pyx_tuple__214 = PyTuple_Pack(4, __pyx_int_228, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_slovenian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__214)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__214);
  __Pyx_GIVEREF(__pyx_tuple__214);

  /* "cymysql/charset.py":240
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 */
  __pyx_tuple__215 = PyTuple_Pack(4, __pyx_int_229, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_polish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);

  /* "cymysql/charset.py":241
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 */
  __pyx_tuple__216 = PyTuple_Pack(4, __pyx_int_230, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_estonian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__216)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__216);
  __Pyx_GIVEREF(__pyx_tuple__216);

  /* "cymysql/charset.py":242
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 */
  __pyx_tuple__217 = PyTuple_Pack(4, __pyx_int_231, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_spanish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);

  /* "cymysql/charset.py":243
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 */
  __pyx_tuple__218 = PyTuple_Pack(4, __pyx_int_232, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_swedish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__218)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__218);
  __Pyx_GIVEREF(__pyx_tuple__218);

  /* "cymysql/charset.py":244
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 */
  __pyx_tuple__219 = PyTuple_Pack(4, __pyx_int_233, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_turkish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);

  /* "cymysql/charset.py":245
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 */
  __pyx_tuple__220 = PyTuple_Pack(4, __pyx_int_234, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_czech_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__220)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__220);
  __Pyx_GIVEREF(__pyx_tuple__220);

  /* "cymysql/charset.py":246
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 */
  __pyx_tuple__221 = PyTuple_Pack(4, __pyx_int_235, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_danish_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);

  /* "cymysql/charset.py":247
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 */
  __pyx_tuple__222 = PyTuple_Pack(4, __pyx_int_236, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_lithuanian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__222)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__222);
  __Pyx_GIVEREF(__pyx_tuple__222);

  /* "cymysql/charset.py":248
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 */
  __pyx_tuple__223 = PyTuple_Pack(4, __pyx_int_237, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_slovak_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);

  /* "cymysql/charset.py":249
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 */
  __pyx_tuple__224 = PyTuple_Pack(4, __pyx_int_238, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_spanish2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__224)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__224);
  __Pyx_GIVEREF(__pyx_tuple__224);

  /* "cymysql/charset.py":250
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 */
  __pyx_tuple__225 = PyTuple_Pack(4, __pyx_int_239, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_roman_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);

  /* "cymysql/charset.py":251
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 */
  __pyx_tuple__226 = PyTuple_Pack(4, __pyx_int_240, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_persian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);

  /* "cymysql/charset.py":252
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 */
  __pyx_tuple__227 = PyTuple_Pack(4, __pyx_int_241, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_esperanto_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);

  /* "cymysql/charset.py":253
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 */
  __pyx_tuple__228 = PyTuple_Pack(4, __pyx_int_242, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_hungarian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__228)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__228);
  __Pyx_GIVEREF(__pyx_tuple__228);

  /* "cymysql/charset.py":254
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 */
  __pyx_tuple__229 = PyTuple_Pack(4, __pyx_int_243, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sinhala_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);

  /* "cymysql/charset.py":255
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 */
  __pyx_tuple__230 = PyTuple_Pack(4, __pyx_int_244, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_german2_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__230)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__230);
  __Pyx_GIVEREF(__pyx_tuple__230);

  /* "cymysql/charset.py":256
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 */
  __pyx_tuple__231 = PyTuple_Pack(4, __pyx_int_245, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_croatian_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);

  /* "cymysql/charset.py":257
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 */
  __pyx_tuple__232 = PyTuple_Pack(4, __pyx_int_246, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__232)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__232);
  __Pyx_GIVEREF(__pyx_tuple__232);

  /* "cymysql/charset.py":258
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 */
  __pyx_tuple__233 = PyTuple_Pack(4, __pyx_int_247, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_vietnamese_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(0, 258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);

  /* "cymysql/charset.py":259
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 */
  __pyx_tuple__234 = PyTuple_Pack(4, __pyx_int_248, __pyx_n_s_gb18030, __pyx_n_s_gb18030_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__234)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__234);
  __Pyx_GIVEREF(__pyx_tuple__234);

  /* "cymysql/charset.py":260
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 */
  __pyx_tuple__235 = PyTuple_Pack(4, __pyx_int_249, __pyx_n_s_gb18030, __pyx_n_s_gb18030_bin, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);

  /* "cymysql/charset.py":261
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 */
  __pyx_tuple__236 = PyTuple_Pack(4, __pyx_int_250, __pyx_n_s_gb18030, __pyx_n_s_gb18030_unicode_520_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__236)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__236);
  __Pyx_GIVEREF(__pyx_tuple__236);

  /* "cymysql/charset.py":262
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 */
  __pyx_tuple__237 = PyTuple_Pack(4, __pyx_int_255, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_0900_ai_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__237)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__237);
  __Pyx_GIVEREF(__pyx_tuple__237);

  /* "cymysql/charset.py":263
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 */
  __pyx_tuple__238 = PyTuple_Pack(4, __pyx_int_256, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_de_pb_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__238)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__238);
  __Pyx_GIVEREF(__pyx_tuple__238);

  /* "cymysql/charset.py":264
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 */
  __pyx_tuple__239 = PyTuple_Pack(4, __pyx_int_257, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_is_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__239)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__239);
  __Pyx_GIVEREF(__pyx_tuple__239);

  /* "cymysql/charset.py":265
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 */
  __pyx_tuple__240 = PyTuple_Pack(4, __pyx_int_258, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_lv_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__240)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__240);
  __Pyx_GIVEREF(__pyx_tuple__240);

  /* "cymysql/charset.py":266
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 */
  __pyx_tuple__241 = PyTuple_Pack(4, __pyx_int_259, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ro_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);

  /* "cymysql/charset.py":267
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 */
  __pyx_tuple__242 = PyTuple_Pack(4, __pyx_int_260, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sl_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);

  /* "cymysql/charset.py":268
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 */
  __pyx_tuple__243 = PyTuple_Pack(4, __pyx_int_261, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_pl_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);

  /* "cymysql/charset.py":269
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 */
  __pyx_tuple__244 = PyTuple_Pack(4, __pyx_int_262, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_et_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);

  /* "cymysql/charset.py":270
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 */
  __pyx_tuple__245 = PyTuple_Pack(4, __pyx_int_263, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_es_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);

  /* "cymysql/charset.py":271
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 */
  __pyx_tuple__246 = PyTuple_Pack(4, __pyx_int_264, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sv_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__246)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__246);
  __Pyx_GIVEREF(__pyx_tuple__246);

  /* "cymysql/charset.py":272
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 */
  __pyx_tuple__247 = PyTuple_Pack(4, __pyx_int_265, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_tr_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);

  /* "cymysql/charset.py":273
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 */
  __pyx_tuple__248 = PyTuple_Pack(4, __pyx_int_266, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_cs_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);

  /* "cymysql/charset.py":274
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 */
  __pyx_tuple__249 = PyTuple_Pack(4, __pyx_int_267, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_da_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__249)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__249);
  __Pyx_GIVEREF(__pyx_tuple__249);

  /* "cymysql/charset.py":275
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 */
  __pyx_tuple__250 = PyTuple_Pack(4, __pyx_int_268, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_lt_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);

  /* "cymysql/charset.py":276
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 */
  __pyx_tuple__251 = PyTuple_Pack(4, __pyx_int_269, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sk_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__251)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__251);
  __Pyx_GIVEREF(__pyx_tuple__251);

  /* "cymysql/charset.py":277
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 */
  __pyx_tuple__252 = PyTuple_Pack(4, __pyx_int_270, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_es_trad_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);

  /* "cymysql/charset.py":278
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 */
  __pyx_tuple__253 = PyTuple_Pack(4, __pyx_int_271, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_la_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);

  /* "cymysql/charset.py":279
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 */
  __pyx_tuple__254 = PyTuple_Pack(4, __pyx_int_273, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_eo_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__254)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__254);
  __Pyx_GIVEREF(__pyx_tuple__254);

  /* "cymysql/charset.py":280
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 */
  __pyx_tuple__255 = PyTuple_Pack(4, __pyx_int_274, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_hu_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__255)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__255);
  __Pyx_GIVEREF(__pyx_tuple__255);

  /* "cymysql/charset.py":281
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 */
  __pyx_tuple__256 = PyTuple_Pack(4, __pyx_int_275, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_hr_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);

  /* "cymysql/charset.py":282
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 */
  __pyx_tuple__257 = PyTuple_Pack(4, __pyx_int_277, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_vi_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__257)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__257);
  __Pyx_GIVEREF(__pyx_tuple__257);

  /* "cymysql/charset.py":283
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 */
  __pyx_tuple__258 = PyTuple_Pack(4, __pyx_int_278, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__258)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__258);
  __Pyx_GIVEREF(__pyx_tuple__258);

  /* "cymysql/charset.py":284
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 */
  __pyx_tuple__259 = PyTuple_Pack(4, __pyx_int_279, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_de_pb_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);

  /* "cymysql/charset.py":285
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 */
  __pyx_tuple__260 = PyTuple_Pack(4, __pyx_int_280, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_is_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__260)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__260);
  __Pyx_GIVEREF(__pyx_tuple__260);

  /* "cymysql/charset.py":286
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 */
  __pyx_tuple__261 = PyTuple_Pack(4, __pyx_int_281, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_lv_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);

  /* "cymysql/charset.py":287
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 */
  __pyx_tuple__262 = PyTuple_Pack(4, __pyx_int_282, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ro_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);

  /* "cymysql/charset.py":288
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 */
  __pyx_tuple__263 = PyTuple_Pack(4, __pyx_int_283, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sl_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);

  /* "cymysql/charset.py":289
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 */
  __pyx_tuple__264 = PyTuple_Pack(4, __pyx_int_284, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_pl_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);

  /* "cymysql/charset.py":290
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 */
  __pyx_tuple__265 = PyTuple_Pack(4, __pyx_int_285, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_et_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);

  /* "cymysql/charset.py":291
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 */
  __pyx_tuple__266 = PyTuple_Pack(4, __pyx_int_286, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_es_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__266)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__266);
  __Pyx_GIVEREF(__pyx_tuple__266);

  /* "cymysql/charset.py":292
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 */
  __pyx_tuple__267 = PyTuple_Pack(4, __pyx_int_287, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sv_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);

  /* "cymysql/charset.py":293
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 */
  __pyx_tuple__268 = PyTuple_Pack(4, __pyx_int_288, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_tr_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);

  /* "cymysql/charset.py":294
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 */
  __pyx_tuple__269 = PyTuple_Pack(4, __pyx_int_289, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_cs_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);

  /* "cymysql/charset.py":295
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 */
  __pyx_tuple__270 = PyTuple_Pack(4, __pyx_int_290, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_da_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__270)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__270);
  __Pyx_GIVEREF(__pyx_tuple__270);

  /* "cymysql/charset.py":296
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 */
  __pyx_tuple__271 = PyTuple_Pack(4, __pyx_int_291, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_lt_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);

  /* "cymysql/charset.py":297
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 */
  __pyx_tuple__272 = PyTuple_Pack(4, __pyx_int_292, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_sk_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__272)) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__272);
  __Pyx_GIVEREF(__pyx_tuple__272);

  /* "cymysql/charset.py":298
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 */
  __pyx_tuple__273 = PyTuple_Pack(4, __pyx_int_293, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_es_trad_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);

  /* "cymysql/charset.py":299
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 */
  __pyx_tuple__274 = PyTuple_Pack(4, __pyx_int_294, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_la_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__274)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__274);
  __Pyx_GIVEREF(__pyx_tuple__274);

  /* "cymysql/charset.py":300
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 */
  __pyx_tuple__275 = PyTuple_Pack(4, __pyx_int_296, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_eo_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);

  /* "cymysql/charset.py":301
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 */
  __pyx_tuple__276 = PyTuple_Pack(4, __pyx_int_297, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_hu_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__276)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__276);
  __Pyx_GIVEREF(__pyx_tuple__276);

  /* "cymysql/charset.py":302
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 */
  __pyx_tuple__277 = PyTuple_Pack(4, __pyx_int_298, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_hr_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);

  /* "cymysql/charset.py":303
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 */
  __pyx_tuple__278 = PyTuple_Pack(4, __pyx_int_300, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_vi_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__278)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__278);
  __Pyx_GIVEREF(__pyx_tuple__278);

  /* "cymysql/charset.py":304
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 */
  __pyx_tuple__279 = PyTuple_Pack(4, __pyx_int_303, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ja_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);

  /* "cymysql/charset.py":305
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 */
  __pyx_tuple__280 = PyTuple_Pack(4, __pyx_int_304, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ja_0900_as_cs_ks, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__280)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__280);
  __Pyx_GIVEREF(__pyx_tuple__280);

  /* "cymysql/charset.py":306
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))
 */
  __pyx_tuple__281 = PyTuple_Pack(4, __pyx_int_305, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_0900_as_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);

  /* "cymysql/charset.py":307
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))
 */
  __pyx_tuple__282 = PyTuple_Pack(4, __pyx_int_306, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ru_0900_ai_ci, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__282)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__282);
  __Pyx_GIVEREF(__pyx_tuple__282);

  /* "cymysql/charset.py":308
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__283 = PyTuple_Pack(4, __pyx_int_307, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_ru_0900_as_cs, __pyx_kp_s__14); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_tuple__284 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__284)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__284);
  __Pyx_GIVEREF(__pyx_tuple__284);
  __pyx_codeobj__285 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__284, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Charset, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__285)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_tuple__286 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__286)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__286);
  __Pyx_GIVEREF(__pyx_tuple__286);
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__286, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Charsets, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9 = PyInt_FromLong(9); if (unlikely(!__pyx_int_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_13 = PyInt_FromLong(13); if (unlikely(!__pyx_int_13)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_14 = PyInt_FromLong(14); if (unlikely(!__pyx_int_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_19 = PyInt_FromLong(19); if (unlikely(!__pyx_int_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_20 = PyInt_FromLong(20); if (unlikely(!__pyx_int_20)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_21 = PyInt_FromLong(21); if (unlikely(!__pyx_int_21)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_22 = PyInt_FromLong(22); if (unlikely(!__pyx_int_22)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_23 = PyInt_FromLong(23); if (unlikely(!__pyx_int_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_25 = PyInt_FromLong(25); if (unlikely(!__pyx_int_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_26 = PyInt_FromLong(26); if (unlikely(!__pyx_int_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_27 = PyInt_FromLong(27); if (unlikely(!__pyx_int_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_29 = PyInt_FromLong(29); if (unlikely(!__pyx_int_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_30 = PyInt_FromLong(30); if (unlikely(!__pyx_int_30)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_31 = PyInt_FromLong(31); if (unlikely(!__pyx_int_31)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_33 = PyInt_FromLong(33); if (unlikely(!__pyx_int_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_34 = PyInt_FromLong(34); if (unlikely(!__pyx_int_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_35 = PyInt_FromLong(35); if (unlikely(!__pyx_int_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_36 = PyInt_FromLong(36); if (unlikely(!__pyx_int_36)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_37 = PyInt_FromLong(37); if (unlikely(!__pyx_int_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_39 = PyInt_FromLong(39); if (unlikely(!__pyx_int_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_40 = PyInt_FromLong(40); if (unlikely(!__pyx_int_40)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_41 = PyInt_FromLong(41); if (unlikely(!__pyx_int_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_42 = PyInt_FromLong(42); if (unlikely(!__pyx_int_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_43 = PyInt_FromLong(43); if (unlikely(!__pyx_int_43)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_44 = PyInt_FromLong(44); if (unlikely(!__pyx_int_44)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_45 = PyInt_FromLong(45); if (unlikely(!__pyx_int_45)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_46 = PyInt_FromLong(46); if (unlikely(!__pyx_int_46)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_47 = PyInt_FromLong(47); if (unlikely(!__pyx_int_47)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_49 = PyInt_FromLong(49); if (unlikely(!__pyx_int_49)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_50 = PyInt_FromLong(50); if (unlikely(!__pyx_int_50)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_51 = PyInt_FromLong(51); if (unlikely(!__pyx_int_51)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_52 = PyInt_FromLong(52); if (unlikely(!__pyx_int_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_53 = PyInt_FromLong(53); if (unlikely(!__pyx_int_53)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_54 = PyInt_FromLong(54); if (unlikely(!__pyx_int_54)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_55 = PyInt_FromLong(55); if (unlikely(!__pyx_int_55)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_56 = PyInt_FromLong(56); if (unlikely(!__pyx_int_56)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_57 = PyInt_FromLong(57); if (unlikely(!__pyx_int_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_59 = PyInt_FromLong(59); if (unlikely(!__pyx_int_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_61 = PyInt_FromLong(61); if (unlikely(!__pyx_int_61)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_62 = PyInt_FromLong(62); if (unlikely(!__pyx_int_62)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_63 = PyInt_FromLong(63); if (unlikely(!__pyx_int_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_64 = PyInt_FromLong(64); if (unlikely(!__pyx_int_64)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_65 = PyInt_FromLong(65); if (unlikely(!__pyx_int_65)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_66 = PyInt_FromLong(66); if (unlikely(!__pyx_int_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_67 = PyInt_FromLong(67); if (unlikely(!__pyx_int_67)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_69 = PyInt_FromLong(69); if (unlikely(!__pyx_int_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_70 = PyInt_FromLong(70); if (unlikely(!__pyx_int_70)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_71 = PyInt_FromLong(71); if (unlikely(!__pyx_int_71)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_72 = PyInt_FromLong(72); if (unlikely(!__pyx_int_72)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_73 = PyInt_FromLong(73); if (unlikely(!__pyx_int_73)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_74 = PyInt_FromLong(74); if (unlikely(!__pyx_int_74)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_75 = PyInt_FromLong(75); if (unlikely(!__pyx_int_75)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_76 = PyInt_FromLong(76); if (unlikely(!__pyx_int_76)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_77 = PyInt_FromLong(77); if (unlikely(!__pyx_int_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_79 = PyInt_FromLong(79); if (unlikely(!__pyx_int_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_80 = PyInt_FromLong(80); if (unlikely(!__pyx_int_80)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_81 = PyInt_FromLong(81); if (unlikely(!__pyx_int_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_82 = PyInt_FromLong(82); if (unlikely(!__pyx_int_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_83 = PyInt_FromLong(83); if (unlikely(!__pyx_int_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_84 = PyInt_FromLong(84); if (unlikely(!__pyx_int_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_85 = PyInt_FromLong(85); if (unlikely(!__pyx_int_85)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_86 = PyInt_FromLong(86); if (unlikely(!__pyx_int_86)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_87 = PyInt_FromLong(87); if (unlikely(!__pyx_int_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_89 = PyInt_FromLong(89); if (unlikely(!__pyx_int_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_90 = PyInt_FromLong(90); if (unlikely(!__pyx_int_90)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_91 = PyInt_FromLong(91); if (unlikely(!__pyx_int_91)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_92 = PyInt_FromLong(92); if (unlikely(!__pyx_int_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_93 = PyInt_FromLong(93); if (unlikely(!__pyx_int_93)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_94 = PyInt_FromLong(94); if (unlikely(!__pyx_int_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_96 = PyInt_FromLong(96); if (unlikely(!__pyx_int_96)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_97 = PyInt_FromLong(97); if (unlikely(!__pyx_int_97)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_99 = PyInt_FromLong(99); if (unlikely(!__pyx_int_99)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_101 = PyInt_FromLong(101); if (unlikely(!__pyx_int_101)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_102 = PyInt_FromLong(102); if (unlikely(!__pyx_int_102)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_103 = PyInt_FromLong(103); if (unlikely(!__pyx_int_103)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_104 = PyInt_FromLong(104); if (unlikely(!__pyx_int_104)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_105 = PyInt_FromLong(105); if (unlikely(!__pyx_int_105)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_106 = PyInt_FromLong(106); if (unlikely(!__pyx_int_106)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_107 = PyInt_FromLong(107); if (unlikely(!__pyx_int_107)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_108 = PyInt_FromLong(108); if (unlikely(!__pyx_int_108)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_109 = PyInt_FromLong(109); if (unlikely(!__pyx_int_109)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_110 = PyInt_FromLong(110); if (unlikely(!__pyx_int_110)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_111 = PyInt_FromLong(111); if (unlikely(!__pyx_int_111)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_112 = PyInt_FromLong(112); if (unlikely(!__pyx_int_112)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_113 = PyInt_FromLong(113); if (unlikely(!__pyx_int_113)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_114 = PyInt_FromLong(114); if (unlikely(!__pyx_int_114)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_115 = PyInt_FromLong(115); if (unlikely(!__pyx_int_115)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_116 = PyInt_FromLong(116); if (unlikely(!__pyx_int_116)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_117 = PyInt_FromLong(117); if (unlikely(!__pyx_int_117)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_118 = PyInt_FromLong(118); if (unlikely(!__pyx_int_118)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_119 = PyInt_FromLong(119); if (unlikely(!__pyx_int_119)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_120 = PyInt_FromLong(120); if (unlikely(!__pyx_int_120)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_121 = PyInt_FromLong(121); if (unlikely(!__pyx_int_121)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_122 = PyInt_FromLong(122); if (unlikely(!__pyx_int_122)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_123 = PyInt_FromLong(123); if (unlikely(!__pyx_int_123)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_124 = PyInt_FromLong(124); if (unlikely(!__pyx_int_124)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_129 = PyInt_FromLong(129); if (unlikely(!__pyx_int_129)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_130 = PyInt_FromLong(130); if (unlikely(!__pyx_int_130)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_131 = PyInt_FromLong(131); if (unlikely(!__pyx_int_131)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_132 = PyInt_FromLong(132); if (unlikely(!__pyx_int_132)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_133 = PyInt_FromLong(133); if (unlikely(!__pyx_int_133)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_134 = PyInt_FromLong(134); if (unlikely(!__pyx_int_134)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_136 = PyInt_FromLong(136); if (unlikely(!__pyx_int_136)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_137 = PyInt_FromLong(137); if (unlikely(!__pyx_int_137)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_139 = PyInt_FromLong(139); if (unlikely(!__pyx_int_139)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_140 = PyInt_FromLong(140); if (unlikely(!__pyx_int_140)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_141 = PyInt_FromLong(141); if (unlikely(!__pyx_int_141)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_142 = PyInt_FromLong(142); if (unlikely(!__pyx_int_142)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_143 = PyInt_FromLong(143); if (unlikely(!__pyx_int_143)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_144 = PyInt_FromLong(144); if (unlikely(!__pyx_int_144)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_145 = PyInt_FromLong(145); if (unlikely(!__pyx_int_145)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_146 = PyInt_FromLong(146); if (unlikely(!__pyx_int_146)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_147 = PyInt_FromLong(147); if (unlikely(!__pyx_int_147)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_148 = PyInt_FromLong(148); if (unlikely(!__pyx_int_148)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_149 = PyInt_FromLong(149); if (unlikely(!__pyx_int_149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_150 = PyInt_FromLong(150); if (unlikely(!__pyx_int_150)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_151 = PyInt_FromLong(151); if (unlikely(!__pyx_int_151)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_159 = PyInt_FromLong(159); if (unlikely(!__pyx_int_159)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_160 = PyInt_FromLong(160); if (unlikely(!__pyx_int_160)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_161 = PyInt_FromLong(161); if (unlikely(!__pyx_int_161)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_162 = PyInt_FromLong(162); if (unlikely(!__pyx_int_162)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_163 = PyInt_FromLong(163); if (unlikely(!__pyx_int_163)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_164 = PyInt_FromLong(164); if (unlikely(!__pyx_int_164)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_165 = PyInt_FromLong(165); if (unlikely(!__pyx_int_165)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_166 = PyInt_FromLong(166); if (unlikely(!__pyx_int_166)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_167 = PyInt_FromLong(167); if (unlikely(!__pyx_int_167)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_168 = PyInt_FromLong(168); if (unlikely(!__pyx_int_168)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_169 = PyInt_FromLong(169); if (unlikely(!__pyx_int_169)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_170 = PyInt_FromLong(170); if (unlikely(!__pyx_int_170)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_171 = PyInt_FromLong(171); if (unlikely(!__pyx_int_171)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_172 = PyInt_FromLong(172); if (unlikely(!__pyx_int_172)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_173 = PyInt_FromLong(173); if (unlikely(!__pyx_int_173)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_174 = PyInt_FromLong(174); if (unlikely(!__pyx_int_174)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_175 = PyInt_FromLong(175); if (unlikely(!__pyx_int_175)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_176 = PyInt_FromLong(176); if (unlikely(!__pyx_int_176)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_177 = PyInt_FromLong(177); if (unlikely(!__pyx_int_177)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_178 = PyInt_FromLong(178); if (unlikely(!__pyx_int_178)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_179 = PyInt_FromLong(179); if (unlikely(!__pyx_int_179)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_180 = PyInt_FromLong(180); if (unlikely(!__pyx_int_180)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_181 = PyInt_FromLong(181); if (unlikely(!__pyx_int_181)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_182 = PyInt_FromLong(182); if (unlikely(!__pyx_int_182)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_183 = PyInt_FromLong(183); if (unlikely(!__pyx_int_183)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_193 = PyInt_FromLong(193); if (unlikely(!__pyx_int_193)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_194 = PyInt_FromLong(194); if (unlikely(!__pyx_int_194)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_195 = PyInt_FromLong(195); if (unlikely(!__pyx_int_195)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_196 = PyInt_FromLong(196); if (unlikely(!__pyx_int_196)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_197 = PyInt_FromLong(197); if (unlikely(!__pyx_int_197)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_199 = PyInt_FromLong(199); if (unlikely(!__pyx_int_199)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_200 = PyInt_FromLong(200); if (unlikely(!__pyx_int_200)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_201 = PyInt_FromLong(201); if (unlikely(!__pyx_int_201)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_202 = PyInt_FromLong(202); if (unlikely(!__pyx_int_202)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_203 = PyInt_FromLong(203); if (unlikely(!__pyx_int_203)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_204 = PyInt_FromLong(204); if (unlikely(!__pyx_int_204)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_205 = PyInt_FromLong(205); if (unlikely(!__pyx_int_205)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_206 = PyInt_FromLong(206); if (unlikely(!__pyx_int_206)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_207 = PyInt_FromLong(207); if (unlikely(!__pyx_int_207)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_209 = PyInt_FromLong(209); if (unlikely(!__pyx_int_209)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_210 = PyInt_FromLong(210); if (unlikely(!__pyx_int_210)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_211 = PyInt_FromLong(211); if (unlikely(!__pyx_int_211)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_212 = PyInt_FromLong(212); if (unlikely(!__pyx_int_212)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_213 = PyInt_FromLong(213); if (unlikely(!__pyx_int_213)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_214 = PyInt_FromLong(214); if (unlikely(!__pyx_int_214)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_215 = PyInt_FromLong(215); if (unlikely(!__pyx_int_215)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_223 = PyInt_FromLong(223); if (unlikely(!__pyx_int_223)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_224 = PyInt_FromLong(224); if (unlikely(!__pyx_int_224)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_225 = PyInt_FromLong(225); if (unlikely(!__pyx_int_225)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_226 = PyInt_FromLong(226); if (unlikely(!__pyx_int_226)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_227 = PyInt_FromLong(227); if (unlikely(!__pyx_int_227)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228 = PyInt_FromLong(228); if (unlikely(!__pyx_int_228)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_229 = PyInt_FromLong(229); if (unlikely(!__pyx_int_229)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_230 = PyInt_FromLong(230); if (unlikely(!__pyx_int_230)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_231 = PyInt_FromLong(231); if (unlikely(!__pyx_int_231)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_232 = PyInt_FromLong(232); if (unlikely(!__pyx_int_232)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_233 = PyInt_FromLong(233); if (unlikely(!__pyx_int_233)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_234 = PyInt_FromLong(234); if (unlikely(!__pyx_int_234)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_235 = PyInt_FromLong(235); if (unlikely(!__pyx_int_235)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_236 = PyInt_FromLong(236); if (unlikely(!__pyx_int_236)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_237 = PyInt_FromLong(237); if (unlikely(!__pyx_int_237)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_238 = PyInt_FromLong(238); if (unlikely(!__pyx_int_238)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_239 = PyInt_FromLong(239); if (unlikely(!__pyx_int_239)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_240 = PyInt_FromLong(240); if (unlikely(!__pyx_int_240)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_241 = PyInt_FromLong(241); if (unlikely(!__pyx_int_241)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_242 = PyInt_FromLong(242); if (unlikely(!__pyx_int_242)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_243 = PyInt_FromLong(243); if (unlikely(!__pyx_int_243)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_244 = PyInt_FromLong(244); if (unlikely(!__pyx_int_244)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_245 = PyInt_FromLong(245); if (unlikely(!__pyx_int_245)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_246 = PyInt_FromLong(246); if (unlikely(!__pyx_int_246)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_247 = PyInt_FromLong(247); if (unlikely(!__pyx_int_247)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_248 = PyInt_FromLong(248); if (unlikely(!__pyx_int_248)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_249 = PyInt_FromLong(249); if (unlikely(!__pyx_int_249)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_250 = PyInt_FromLong(250); if (unlikely(!__pyx_int_250)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_255 = PyInt_FromLong(255); if (unlikely(!__pyx_int_255)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_256 = PyInt_FromLong(256); if (unlikely(!__pyx_int_256)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_257 = PyInt_FromLong(257); if (unlikely(!__pyx_int_257)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_258 = PyInt_FromLong(258); if (unlikely(!__pyx_int_258)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_259 = PyInt_FromLong(259); if (unlikely(!__pyx_int_259)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_260 = PyInt_FromLong(260); if (unlikely(!__pyx_int_260)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_261 = PyInt_FromLong(261); if (unlikely(!__pyx_int_261)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_262 = PyInt_FromLong(262); if (unlikely(!__pyx_int_262)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_263 = PyInt_FromLong(263); if (unlikely(!__pyx_int_263)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_264 = PyInt_FromLong(264); if (unlikely(!__pyx_int_264)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_265 = PyInt_FromLong(265); if (unlikely(!__pyx_int_265)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_266 = PyInt_FromLong(266); if (unlikely(!__pyx_int_266)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_267 = PyInt_FromLong(267); if (unlikely(!__pyx_int_267)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_268 = PyInt_FromLong(268); if (unlikely(!__pyx_int_268)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_269 = PyInt_FromLong(269); if (unlikely(!__pyx_int_269)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_270 = PyInt_FromLong(270); if (unlikely(!__pyx_int_270)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_271 = PyInt_FromLong(271); if (unlikely(!__pyx_int_271)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_273 = PyInt_FromLong(273); if (unlikely(!__pyx_int_273)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_274 = PyInt_FromLong(274); if (unlikely(!__pyx_int_274)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_275 = PyInt_FromLong(275); if (unlikely(!__pyx_int_275)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_277 = PyInt_FromLong(277); if (unlikely(!__pyx_int_277)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_278 = PyInt_FromLong(278); if (unlikely(!__pyx_int_278)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_279 = PyInt_FromLong(279); if (unlikely(!__pyx_int_279)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_280 = PyInt_FromLong(280); if (unlikely(!__pyx_int_280)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_281 = PyInt_FromLong(281); if (unlikely(!__pyx_int_281)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_282 = PyInt_FromLong(282); if (unlikely(!__pyx_int_282)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_283 = PyInt_FromLong(283); if (unlikely(!__pyx_int_283)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_284 = PyInt_FromLong(284); if (unlikely(!__pyx_int_284)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_285 = PyInt_FromLong(285); if (unlikely(!__pyx_int_285)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_286 = PyInt_FromLong(286); if (unlikely(!__pyx_int_286)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_287 = PyInt_FromLong(287); if (unlikely(!__pyx_int_287)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_288 = PyInt_FromLong(288); if (unlikely(!__pyx_int_288)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_289 = PyInt_FromLong(289); if (unlikely(!__pyx_int_289)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_290 = PyInt_FromLong(290); if (unlikely(!__pyx_int_290)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_291 = PyInt_FromLong(291); if (unlikely(!__pyx_int_291)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_292 = PyInt_FromLong(292); if (unlikely(!__pyx_int_292)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_293 = PyInt_FromLong(293); if (unlikely(!__pyx_int_293)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_294 = PyInt_FromLong(294); if (unlikely(!__pyx_int_294)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_296 = PyInt_FromLong(296); if (unlikely(!__pyx_int_296)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_297 = PyInt_FromLong(297); if (unlikely(!__pyx_int_297)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_298 = PyInt_FromLong(298); if (unlikely(!__pyx_int_298)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_300 = PyInt_FromLong(300); if (unlikely(!__pyx_int_300)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_303 = PyInt_FromLong(303); if (unlikely(!__pyx_int_303)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_304 = PyInt_FromLong(304); if (unlikely(!__pyx_int_304)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_305 = PyInt_FromLong(305); if (unlikely(!__pyx_int_305)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_306 = PyInt_FromLong(306); if (unlikely(!__pyx_int_306)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_307 = PyInt_FromLong(307); if (unlikely(!__pyx_int_307)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100352957 = PyInt_FromLong(100352957L); if (unlikely(!__pyx_int_100352957)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_125328330 = PyInt_FromLong(125328330L); if (unlikely(!__pyx_int_125328330)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initcharset(void); /*proto*/
PyMODINIT_FUNC initcharset(void)
#else
PyMODINIT_FUNC PyInit_charset(void); /*proto*/
PyMODINIT_FUNC PyInit_charset(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_charset(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("charset", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_cymysql__charset) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "cymysql.charset")) {
      if (unlikely(PyDict_SetItemString(modules, "cymysql.charset", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  __pyx_v_7cymysql_7charset__charsets = ((struct __pyx_obj_7cymysql_7charset_Charsets *)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_charsets, (void *)&__pyx_v_7cymysql_7charset__charsets, "struct __pyx_obj_7cymysql_7charset_Charsets *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_7cymysql_7charset_Charset) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_type_7cymysql_7charset_Charset.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "Charset", (PyObject *)&__pyx_type_7cymysql_7charset_Charset) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_7cymysql_7charset_Charset) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_ptype_7cymysql_7charset_Charset = &__pyx_type_7cymysql_7charset_Charset;
  __pyx_vtabptr_7cymysql_7charset_Charsets = &__pyx_vtable_7cymysql_7charset_Charsets;
  __pyx_vtable_7cymysql_7charset_Charsets.add = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, struct __pyx_obj_7cymysql_7charset_Charset *))__pyx_f_7cymysql_7charset_8Charsets_add;
  __pyx_vtable_7cymysql_7charset_Charsets.by_name = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7cymysql_7charset_8Charsets_by_name;
  __pyx_vtable_7cymysql_7charset_Charsets.by_id = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7cymysql_7charset_8Charsets_by_id;
  if (PyType_Ready(&__pyx_type_7cymysql_7charset_Charsets) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_type_7cymysql_7charset_Charsets.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_7cymysql_7charset_Charsets.tp_dict, __pyx_vtabptr_7cymysql_7charset_Charsets) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "Charsets", (PyObject *)&__pyx_type_7cymysql_7charset_Charsets) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_7cymysql_7charset_Charsets) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_ptype_7cymysql_7charset_Charsets = &__pyx_type_7cymysql_7charset_Charsets;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self.collation, self.id, self.is_default, self.name)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_7Charset_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charset___reduce_cython, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_1) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charset, (type(self), 0x7785bca, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charset__set_state(self, __pyx_state)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_7Charset_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charset___setstate_cython, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__4)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_1) < 0) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":14
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_8Charsets_3by_name, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charsets_by_name, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_7cymysql_7charset_Charsets->tp_dict, __pyx_n_s_by_name, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_7cymysql_7charset_Charsets);

  /* "cymysql/charset.py":19
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_8Charsets_5by_id, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charsets_by_id, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_7cymysql_7charset_Charsets->tp_dict, __pyx_n_s_by_id, __pyx_t_1) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_7cymysql_7charset_Charsets);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._by_id,)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_8Charsets_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charsets___reduce_cython, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__10)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_1) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_Charsets, (type(self), 0x5fb43bd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Charsets__set_state(self, __pyx_state)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_8Charsets_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Charsets___setstate_cython, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__12)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_1) < 0) __PYX_ERR(2, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":23
 * 
 * 
 * _charsets = Charsets()             # <<<<<<<<<<<<<<
 * charset_by_name = _charsets.by_name
 * charset_by_id = _charsets.by_id
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charsets), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(((PyObject *)__pyx_v_7cymysql_7charset__charsets));
  __Pyx_DECREF_SET(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/charset.py":24
 * 
 * _charsets = Charsets()
 * charset_by_name = _charsets.by_name             # <<<<<<<<<<<<<<
 * charset_by_id = _charsets.by_id
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_7cymysql_7charset__charsets), __pyx_n_s_by_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charset_by_name, __pyx_t_1) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":25
 * _charsets = Charsets()
 * charset_by_name = _charsets.by_name
 * charset_by_id = _charsets.by_id             # <<<<<<<<<<<<<<
 * 
 * """
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_7cymysql_7charset__charsets), __pyx_n_s_by_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charset_by_id, __pyx_t_1) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":39
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":40
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":41
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":42
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":43
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":44
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":45
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":46
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":47
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":48
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":49
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":50
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":51
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":52
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":53
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":54
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":55
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":56
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":57
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":58
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":59
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":60
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":61
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":62
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":63
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":64
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":65
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":66
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":67
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":68
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":69
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":70
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":71
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":72
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":73
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":74
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":75
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":76
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":77
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":78
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":79
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":80
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":81
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":82
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":83
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":84
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', ''))
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":85
 * _charsets.add(Charset(46, 'utf8mb4', 'utf8mb4_bin', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":86
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":87
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":88
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":89
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":90
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":91
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":92
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":93
 * _charsets.add(Charset(54, 'utf16', 'utf16_general_ci', 'Yes'))
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":94
 * _charsets.add(Charset(55, 'utf16', 'utf16_bin', ''))
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":95
 * _charsets.add(Charset(56, 'utf16le', 'utf16le_general_ci', 'Yes'))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":96
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":97
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":98
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":99
 * _charsets.add(Charset(60, 'utf32', 'utf32_general_ci', 'Yes'))
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":100
 * _charsets.add(Charset(61, 'utf32', 'utf32_bin', ''))
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":101
 * _charsets.add(Charset(62, 'utf16le', 'utf16le_bin', ''))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":102
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__77, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":103
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":104
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":105
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__80, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":106
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":107
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__82, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":108
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":109
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__84, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":110
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":111
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":112
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__87, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":113
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__88, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":114
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__89, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":115
 * _charsets.add(Charset(76, 'utf8', 'utf8_tolower_ci', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__90, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":116
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__91, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":117
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__92, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":118
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":119
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__94, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":120
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__95, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":121
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__96, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":122
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__97, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":123
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__98, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":124
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__99, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":125
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":126
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":127
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__102, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":128
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":129
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__104, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":130
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":131
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":132
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":133
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":134
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__109, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":135
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":136
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__111, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":137
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__112, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":138
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__113, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":139
 * _charsets.add(Charset(101, 'utf16', 'utf16_unicode_ci', ''))
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__114, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":140
 * _charsets.add(Charset(102, 'utf16', 'utf16_icelandic_ci', ''))
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__115, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":141
 * _charsets.add(Charset(103, 'utf16', 'utf16_latvian_ci', ''))
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__116, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":142
 * _charsets.add(Charset(104, 'utf16', 'utf16_romanian_ci', ''))
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__117, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":143
 * _charsets.add(Charset(105, 'utf16', 'utf16_slovenian_ci', ''))
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":144
 * _charsets.add(Charset(106, 'utf16', 'utf16_polish_ci', ''))
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__119, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":145
 * _charsets.add(Charset(107, 'utf16', 'utf16_estonian_ci', ''))
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":146
 * _charsets.add(Charset(108, 'utf16', 'utf16_spanish_ci', ''))
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":147
 * _charsets.add(Charset(109, 'utf16', 'utf16_swedish_ci', ''))
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":148
 * _charsets.add(Charset(110, 'utf16', 'utf16_turkish_ci', ''))
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__123, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":149
 * _charsets.add(Charset(111, 'utf16', 'utf16_czech_ci', ''))
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__124, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":150
 * _charsets.add(Charset(112, 'utf16', 'utf16_danish_ci', ''))
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__125, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":151
 * _charsets.add(Charset(113, 'utf16', 'utf16_lithuanian_ci', ''))
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__126, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":152
 * _charsets.add(Charset(114, 'utf16', 'utf16_slovak_ci', ''))
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__127, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":153
 * _charsets.add(Charset(115, 'utf16', 'utf16_spanish2_ci', ''))
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__128, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":154
 * _charsets.add(Charset(116, 'utf16', 'utf16_roman_ci', ''))
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__129, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":155
 * _charsets.add(Charset(117, 'utf16', 'utf16_persian_ci', ''))
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__130, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":156
 * _charsets.add(Charset(118, 'utf16', 'utf16_esperanto_ci', ''))
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__131, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":157
 * _charsets.add(Charset(119, 'utf16', 'utf16_hungarian_ci', ''))
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__132, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":158
 * _charsets.add(Charset(120, 'utf16', 'utf16_sinhala_ci', ''))
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__133, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":159
 * _charsets.add(Charset(121, 'utf16', 'utf16_german2_ci', ''))
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__134, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":160
 * _charsets.add(Charset(122, 'utf16', 'utf16_croatian_ci', ''))
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__135, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":161
 * _charsets.add(Charset(123, 'utf16', 'utf16_unicode_520_ci', ''))
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__136, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":162
 * _charsets.add(Charset(124, 'utf16', 'utf16_vietnamese_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__137, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":163
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__138, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":164
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__139, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":165
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__140, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":166
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__141, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":167
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__142, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":168
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__143, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":169
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__144, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":170
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__145, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":171
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__146, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":172
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__147, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":173
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__148, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":174
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__149, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":175
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__150, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":176
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__151, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":177
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__152, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":178
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__153, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":179
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__154, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":180
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__155, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":181
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__156, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":182
 * _charsets.add(Charset(147, 'ucs2', 'ucs2_sinhala_ci', ''))
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":183
 * _charsets.add(Charset(148, 'ucs2', 'ucs2_german2_ci', ''))
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__158, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":184
 * _charsets.add(Charset(149, 'ucs2', 'ucs2_croatian_ci', ''))
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__159, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":185
 * _charsets.add(Charset(150, 'ucs2', 'ucs2_unicode_520_ci', ''))
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__160, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":186
 * _charsets.add(Charset(151, 'ucs2', 'ucs2_vietnamese_ci', ''))
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__161, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":187
 * _charsets.add(Charset(159, 'ucs2', 'ucs2_general_mysql500_ci', ''))
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__162, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":188
 * _charsets.add(Charset(160, 'utf32', 'utf32_unicode_ci', ''))
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__163, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":189
 * _charsets.add(Charset(161, 'utf32', 'utf32_icelandic_ci', ''))
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__164, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":190
 * _charsets.add(Charset(162, 'utf32', 'utf32_latvian_ci', ''))
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__165, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":191
 * _charsets.add(Charset(163, 'utf32', 'utf32_romanian_ci', ''))
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__166, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":192
 * _charsets.add(Charset(164, 'utf32', 'utf32_slovenian_ci', ''))
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__167, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":193
 * _charsets.add(Charset(165, 'utf32', 'utf32_polish_ci', ''))
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__168, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":194
 * _charsets.add(Charset(166, 'utf32', 'utf32_estonian_ci', ''))
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__169, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":195
 * _charsets.add(Charset(167, 'utf32', 'utf32_spanish_ci', ''))
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__170, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":196
 * _charsets.add(Charset(168, 'utf32', 'utf32_swedish_ci', ''))
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__171, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":197
 * _charsets.add(Charset(169, 'utf32', 'utf32_turkish_ci', ''))
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__172, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":198
 * _charsets.add(Charset(170, 'utf32', 'utf32_czech_ci', ''))
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__173, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":199
 * _charsets.add(Charset(171, 'utf32', 'utf32_danish_ci', ''))
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__174, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":200
 * _charsets.add(Charset(172, 'utf32', 'utf32_lithuanian_ci', ''))
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__175, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":201
 * _charsets.add(Charset(173, 'utf32', 'utf32_slovak_ci', ''))
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__176, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":202
 * _charsets.add(Charset(174, 'utf32', 'utf32_spanish2_ci', ''))
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__177, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":203
 * _charsets.add(Charset(175, 'utf32', 'utf32_roman_ci', ''))
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__178, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":204
 * _charsets.add(Charset(176, 'utf32', 'utf32_persian_ci', ''))
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__179, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":205
 * _charsets.add(Charset(177, 'utf32', 'utf32_esperanto_ci', ''))
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__180, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":206
 * _charsets.add(Charset(178, 'utf32', 'utf32_hungarian_ci', ''))
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__181, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":207
 * _charsets.add(Charset(179, 'utf32', 'utf32_sinhala_ci', ''))
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__182, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":208
 * _charsets.add(Charset(180, 'utf32', 'utf32_german2_ci', ''))
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__183, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":209
 * _charsets.add(Charset(181, 'utf32', 'utf32_croatian_ci', ''))
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__184, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":210
 * _charsets.add(Charset(182, 'utf32', 'utf32_unicode_520_ci', ''))
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__185, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":211
 * _charsets.add(Charset(183, 'utf32', 'utf32_vietnamese_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__186, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":212
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__187, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":213
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__188, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":214
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__189, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":215
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__190, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":216
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__191, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":217
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__192, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":218
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__193, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":219
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__194, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":220
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__195, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":221
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__196, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":222
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__197, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":223
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__198, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":224
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__199, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":225
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__200, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":226
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__201, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":227
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__202, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":228
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__203, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":229
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__204, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":230
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__205, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":231
 * _charsets.add(Charset(211, 'utf8', 'utf8_sinhala_ci', ''))
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__206, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":232
 * _charsets.add(Charset(212, 'utf8', 'utf8_german2_ci', ''))
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__207, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":233
 * _charsets.add(Charset(213, 'utf8', 'utf8_croatian_ci', ''))
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__208, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":234
 * _charsets.add(Charset(214, 'utf8', 'utf8_unicode_520_ci', ''))
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__209, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":235
 * _charsets.add(Charset(215, 'utf8', 'utf8_vietnamese_ci', ''))
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__210, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":236
 * _charsets.add(Charset(223, 'utf8', 'utf8_general_mysql500_ci', ''))
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__211, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":237
 * _charsets.add(Charset(224, 'utf8mb4', 'utf8mb4_unicode_ci', ''))
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__212, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":238
 * _charsets.add(Charset(225, 'utf8mb4', 'utf8mb4_icelandic_ci', ''))
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__213, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":239
 * _charsets.add(Charset(226, 'utf8mb4', 'utf8mb4_latvian_ci', ''))
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__214, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":240
 * _charsets.add(Charset(227, 'utf8mb4', 'utf8mb4_romanian_ci', ''))
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__215, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":241
 * _charsets.add(Charset(228, 'utf8mb4', 'utf8mb4_slovenian_ci', ''))
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__216, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":242
 * _charsets.add(Charset(229, 'utf8mb4', 'utf8mb4_polish_ci', ''))
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__217, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":243
 * _charsets.add(Charset(230, 'utf8mb4', 'utf8mb4_estonian_ci', ''))
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__218, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":244
 * _charsets.add(Charset(231, 'utf8mb4', 'utf8mb4_spanish_ci', ''))
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__219, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":245
 * _charsets.add(Charset(232, 'utf8mb4', 'utf8mb4_swedish_ci', ''))
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__220, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":246
 * _charsets.add(Charset(233, 'utf8mb4', 'utf8mb4_turkish_ci', ''))
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__221, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":247
 * _charsets.add(Charset(234, 'utf8mb4', 'utf8mb4_czech_ci', ''))
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__222, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":248
 * _charsets.add(Charset(235, 'utf8mb4', 'utf8mb4_danish_ci', ''))
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__223, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":249
 * _charsets.add(Charset(236, 'utf8mb4', 'utf8mb4_lithuanian_ci', ''))
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__224, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":250
 * _charsets.add(Charset(237, 'utf8mb4', 'utf8mb4_slovak_ci', ''))
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__225, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":251
 * _charsets.add(Charset(238, 'utf8mb4', 'utf8mb4_spanish2_ci', ''))
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__226, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":252
 * _charsets.add(Charset(239, 'utf8mb4', 'utf8mb4_roman_ci', ''))
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__227, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":253
 * _charsets.add(Charset(240, 'utf8mb4', 'utf8mb4_persian_ci', ''))
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__228, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":254
 * _charsets.add(Charset(241, 'utf8mb4', 'utf8mb4_esperanto_ci', ''))
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__229, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":255
 * _charsets.add(Charset(242, 'utf8mb4', 'utf8mb4_hungarian_ci', ''))
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__230, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":256
 * _charsets.add(Charset(243, 'utf8mb4', 'utf8mb4_sinhala_ci', ''))
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__231, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":257
 * _charsets.add(Charset(244, 'utf8mb4', 'utf8mb4_german2_ci', ''))
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__232, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":258
 * _charsets.add(Charset(245, 'utf8mb4', 'utf8mb4_croatian_ci', ''))
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__233, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":259
 * _charsets.add(Charset(246, 'utf8mb4', 'utf8mb4_unicode_520_ci', ''))
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__234, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":260
 * _charsets.add(Charset(247, 'utf8mb4', 'utf8mb4_vietnamese_ci', ''))
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__235, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":261
 * _charsets.add(Charset(248, 'gb18030', 'gb18030_chinese_ci', 'Yes'))
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__236, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":262
 * _charsets.add(Charset(249, 'gb18030', 'gb18030_bin', ''))
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__237, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":263
 * _charsets.add(Charset(250, 'gb18030', 'gb18030_unicode_520_ci', ''))
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__238, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":264
 * _charsets.add(Charset(255, 'utf8mb4', 'utf8mb4_0900_ai_ci', 'Yes'))
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__239, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":265
 * _charsets.add(Charset(256, 'utf8mb4', 'utf8mb4_de_pb_0900_ai_ci', ''))
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__240, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":266
 * _charsets.add(Charset(257, 'utf8mb4', 'utf8mb4_is_0900_ai_ci', ''))
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__241, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":267
 * _charsets.add(Charset(258, 'utf8mb4', 'utf8mb4_lv_0900_ai_ci', ''))
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__242, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":268
 * _charsets.add(Charset(259, 'utf8mb4', 'utf8mb4_ro_0900_ai_ci', ''))
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__243, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":269
 * _charsets.add(Charset(260, 'utf8mb4', 'utf8mb4_sl_0900_ai_ci', ''))
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__244, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":270
 * _charsets.add(Charset(261, 'utf8mb4', 'utf8mb4_pl_0900_ai_ci', ''))
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__245, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":271
 * _charsets.add(Charset(262, 'utf8mb4', 'utf8mb4_et_0900_ai_ci', ''))
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__246, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":272
 * _charsets.add(Charset(263, 'utf8mb4', 'utf8mb4_es_0900_ai_ci', ''))
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__247, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":273
 * _charsets.add(Charset(264, 'utf8mb4', 'utf8mb4_sv_0900_ai_ci', ''))
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__248, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":274
 * _charsets.add(Charset(265, 'utf8mb4', 'utf8mb4_tr_0900_ai_ci', ''))
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__249, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":275
 * _charsets.add(Charset(266, 'utf8mb4', 'utf8mb4_cs_0900_ai_ci', ''))
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__250, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":276
 * _charsets.add(Charset(267, 'utf8mb4', 'utf8mb4_da_0900_ai_ci', ''))
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__251, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":277
 * _charsets.add(Charset(268, 'utf8mb4', 'utf8mb4_lt_0900_ai_ci', ''))
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__252, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":278
 * _charsets.add(Charset(269, 'utf8mb4', 'utf8mb4_sk_0900_ai_ci', ''))
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__253, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":279
 * _charsets.add(Charset(270, 'utf8mb4', 'utf8mb4_es_trad_0900_ai_ci', ''))
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__254, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":280
 * _charsets.add(Charset(271, 'utf8mb4', 'utf8mb4_la_0900_ai_ci', ''))
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__255, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":281
 * _charsets.add(Charset(273, 'utf8mb4', 'utf8mb4_eo_0900_ai_ci', ''))
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__256, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":282
 * _charsets.add(Charset(274, 'utf8mb4', 'utf8mb4_hu_0900_ai_ci', ''))
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__257, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":283
 * _charsets.add(Charset(275, 'utf8mb4', 'utf8mb4_hr_0900_ai_ci', ''))
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__258, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":284
 * _charsets.add(Charset(277, 'utf8mb4', 'utf8mb4_vi_0900_ai_ci', ''))
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__259, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":285
 * _charsets.add(Charset(278, 'utf8mb4', 'utf8mb4_0900_as_cs', ''))
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__260, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":286
 * _charsets.add(Charset(279, 'utf8mb4', 'utf8mb4_de_pb_0900_as_cs', ''))
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__261, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":287
 * _charsets.add(Charset(280, 'utf8mb4', 'utf8mb4_is_0900_as_cs', ''))
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__262, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":288
 * _charsets.add(Charset(281, 'utf8mb4', 'utf8mb4_lv_0900_as_cs', ''))
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__263, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":289
 * _charsets.add(Charset(282, 'utf8mb4', 'utf8mb4_ro_0900_as_cs', ''))
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__264, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":290
 * _charsets.add(Charset(283, 'utf8mb4', 'utf8mb4_sl_0900_as_cs', ''))
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__265, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":291
 * _charsets.add(Charset(284, 'utf8mb4', 'utf8mb4_pl_0900_as_cs', ''))
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__266, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":292
 * _charsets.add(Charset(285, 'utf8mb4', 'utf8mb4_et_0900_as_cs', ''))
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__267, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":293
 * _charsets.add(Charset(286, 'utf8mb4', 'utf8mb4_es_0900_as_cs', ''))
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__268, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":294
 * _charsets.add(Charset(287, 'utf8mb4', 'utf8mb4_sv_0900_as_cs', ''))
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__269, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":295
 * _charsets.add(Charset(288, 'utf8mb4', 'utf8mb4_tr_0900_as_cs', ''))
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__270, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":296
 * _charsets.add(Charset(289, 'utf8mb4', 'utf8mb4_cs_0900_as_cs', ''))
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__271, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":297
 * _charsets.add(Charset(290, 'utf8mb4', 'utf8mb4_da_0900_as_cs', ''))
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__272, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":298
 * _charsets.add(Charset(291, 'utf8mb4', 'utf8mb4_lt_0900_as_cs', ''))
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__273, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":299
 * _charsets.add(Charset(292, 'utf8mb4', 'utf8mb4_sk_0900_as_cs', ''))
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__274, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":300
 * _charsets.add(Charset(293, 'utf8mb4', 'utf8mb4_es_trad_0900_as_cs', ''))
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__275, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":301
 * _charsets.add(Charset(294, 'utf8mb4', 'utf8mb4_la_0900_as_cs', ''))
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__276, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":302
 * _charsets.add(Charset(296, 'utf8mb4', 'utf8mb4_eo_0900_as_cs', ''))
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__277, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":303
 * _charsets.add(Charset(297, 'utf8mb4', 'utf8mb4_hu_0900_as_cs', ''))
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__278, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":304
 * _charsets.add(Charset(298, 'utf8mb4', 'utf8mb4_hr_0900_as_cs', ''))
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__279, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":305
 * _charsets.add(Charset(300, 'utf8mb4', 'utf8mb4_vi_0900_as_cs', ''))
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__280, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":306
 * _charsets.add(Charset(303, 'utf8mb4', 'utf8mb4_ja_0900_as_cs', ''))
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__281, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":307
 * _charsets.add(Charset(304, 'utf8mb4', 'utf8mb4_ja_0900_as_cs_ks', ''))
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__282, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":308
 * _charsets.add(Charset(305, 'utf8mb4', 'utf8mb4_0900_as_ci', ''))
 * _charsets.add(Charset(306, 'utf8mb4', 'utf8mb4_ru_0900_ai_ci', ''))
 * _charsets.add(Charset(307, 'utf8mb4', 'utf8mb4_ru_0900_as_cs', ''))             # <<<<<<<<<<<<<<
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cymysql_7charset_Charset), __pyx_tuple__283, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Charset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x7785bca:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_1__pyx_unpickle_Charset, 0, __pyx_n_s_pyx_unpickle_Charset, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__285)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Charset, __pyx_t_1) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":9
 *         __pyx_unpickle_Charset__set_state(<Charset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Charset__set_state(Charset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.collation = __pyx_state[0]; __pyx_result.id = __pyx_state[1]; __pyx_result.is_default = __pyx_state[2]; __pyx_result.name = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_7cymysql_7charset_3__pyx_unpickle_Charsets, 0, __pyx_n_s_pyx_unpickle_Charsets, NULL, __pyx_n_s_cymysql_charset, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Charsets, __pyx_t_1) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":1
 * class Charset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init cymysql.charset", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cymysql.charset");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError))
            goto bad;
        PyErr_Clear();
        r = d;
        Py_INCREF(d);
    }
    return r;
bad:
    return NULL;
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* KeywordStringCheck */
  static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* PyCFunctionFastCall */
  #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
  #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = PyThreadState_GET();
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
  #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* UnpackUnboundCMethod */
  static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(PyObject_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
  static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_values */
  static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_values, d);
    else
        return PyDict_Values(d);
}

/* ExtTypeTest */
  static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* BytesEquals */
  static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
  static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* Import */
  static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* PyErrFetchRestore */
  #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
  #if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetItemInt */
    static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* HasAttr */
    static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* SetupReduce */
    static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_COMPILING_IN_CPYTHON
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* SetVTable */
    static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* FetchCommonType */
    static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
    static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0 = PySequence_ITEM(arg, 0);
                if (unlikely(!arg0)) return NULL;
                result = (*meth)(self, arg0);
                Py_DECREF(arg0);
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CLineInTraceback */
        static int __Pyx_CLineForTraceback(int c_line) {
#ifdef CYTHON_CLINE_IN_TRACEBACK
    return ((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0;
#else
    PyObject *use_cline;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = PyDict_GetItem(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *ptype, *pvalue, *ptraceback;
      PyObject *use_cline_obj;
      PyErr_Fetch(&ptype, &pvalue, &ptraceback);
      use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        use_cline = NULL;
      }
      PyErr_Restore(ptype, pvalue, ptraceback);
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    return c_line;
#endif
}

/* CodeObjectCache */
        static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
        #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
        #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
        static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
        static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
        static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CheckBinaryVersion */
        static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* VoidPtrExport */
        static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* InitStrings */
        static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            PyErr_Clear();
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if CYTHON_COMPILING_IN_CPYTHON && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
  #else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
  #endif
#else
  res = PyNumber_Int(x);
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
